## api-gest@2.1.0

### Building

To install the required dependencies and to build the typescript sources run:
```
npm install
npm run build
```

### publishing

First build the package than run ```npm publish dist``` (don't forget to specify the `dist` folder!)

### consuming

Navigate to the folder of your consuming project and run this command.


```
npm install api-gest@2.1.0 --save
```

_without publishing (not recommended):_

```
npm install PATH_TO_GENERATED_PACKAGE/dist.tgz --save
It's important to take the tgz file, otherwise you'll get trouble with links on windows.  

_using `npm link`:_

In PATH_TO_GENERATED_PACKAGE/dist:
```
npm link
```

In your project:
```
npm link api-gest
```

__Note for Windows users:__ The Angular CLI has troubles to use linked npm packages.
Please refer to this issue https://github.com/angular/angular-cli/issues/8284 for a solution / workaround.
Published packages are not effected by this issue.


#### General usage

In your Angular project:


```
// without configuring providers
import { ApiGestModule } from 'api-gest';
import { HttpClientModule } from '@angular/common/http';


@NgModule({
    imports: [
        ApiGestModule,
        // make sure to import the HttpClientModule in the AppModule only,
        // see https://github.com/angular/angular/issues/20575
        HttpClientModule
    ],
    declarations: [ AppComponent ],
    providers: [],
    bootstrap: [ AppComponent ]
})
export class AppModule {}
```

```
// configuring providers
import { ApiGestModule, Configuration, ConfigurationParameters } from 'api-gest';

export function apiConfigFactory (): Configuration => {
  const params: ConfigurationParameters = {
    // set configuration parameters here.
  }
  return new Configuration(params);
}

@NgModule({
    imports: [ ApiGestModule.forRoot(apiConfigFactory) ],
    declarations: [ AppComponent ],
    providers: [],
    bootstrap: [ AppComponent ]
})
export class AppModule {}
```

```
import { DefaultApi } from 'api-gest';

export class AppComponent {
	 constructor(private apiGateway: DefaultApi) { }
}
```

Note: The ApiGestModule is restricted to being instantiated once app wide.
This is to ensure that all services are treated as singletons.


### Set service base path
If different than the generated base path, during app bootstrap, you can provide the base path to your service. 

```
import { AIG_PATH } from 'api-gest';

bootstrap(AppComponent, [
    { provide: AIG_PATH, useValue: 'https://your-web-service.com' },
]);
```
or

```
import { AIG_PATH } from 'api-gest';

@NgModule({
    imports: [],
    declarations: [ AppComponent ],
    providers: [ provide: AIG_PATH, useValue: 'https://your-web-service.com' ],
    bootstrap: [ AppComponent ]
})
export class AppModule {}
```


#### Using @angular/cli
First extend your `src/environments/*.ts` files by adding the corresponding base path:

```
export const environment = {
  production: false,
  API_AIG_PATH: 'http://127.0.0.1:8080'
};
```

In the src/app/app.module.ts:
```
import { AIG_PATH } from 'api-gest';
import { environment } from '../environments/environment';

@NgModule({
  declarations: [
    AppComponent
  ],
  imports: [ ],
  providers: [{ provide: AIG_PATH, useValue: environment.API_AIG_PATH }],
  bootstrap: [ AppComponent ]
})
export class AppModule { }
```  
