import { __values, __decorate, __param, __extends } from 'tslib';
import { InjectionToken, Optional, Inject, Injectable, SkipSelf, NgModule } from '@angular/core';
import { HttpHeaders, HttpClient, HttpUrlEncodingCodec, HttpParams } from '@angular/common/http';

var AIG_PATH = new InjectionToken('basePath');
var COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

var Configuration = /** @class */ (function () {
    function Configuration(configurationParameters) {
        if (configurationParameters === void 0) { configurationParameters = {}; }
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param contentTypes - the array of content types that are available for selection
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    Configuration.prototype.selectHeaderContentType = function (contentTypes) {
        var _this = this;
        if (contentTypes.length == 0) {
            return undefined;
        }
        var type = contentTypes.find(function (x) { return _this.isJsonMime(x); });
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    };
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param accepts - the array of content types that are available for selection.
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    Configuration.prototype.selectHeaderAccept = function (accepts) {
        var _this = this;
        if (accepts.length == 0) {
            return undefined;
        }
        var type = accepts.find(function (x) { return _this.isJsonMime(x); });
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    };
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param mime - MIME (Multipurpose Internet Mail Extensions)
     * @return True if the given MIME is JSON, false otherwise.
     */
    Configuration.prototype.isJsonMime = function (mime) {
        var jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    };
    return Configuration;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ApolloDocumentService = /** @class */ (function () {
    function ApolloDocumentService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ApolloDocumentService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ApolloDocumentService.prototype.addDocument = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling addDocument.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/ws/apollo-document", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ApolloDocumentService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ApolloDocumentService);
    return ApolloDocumentService;
}());

/**
* CustomHttpUrlEncodingCodec
* Fix plus sign (+) not encoding, so sent as blank space
* See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
*/
var CustomHttpUrlEncodingCodec = /** @class */ (function (_super) {
    __extends(CustomHttpUrlEncodingCodec, _super);
    function CustomHttpUrlEncodingCodec() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomHttpUrlEncodingCodec.prototype.encodeKey = function (k) {
        k = _super.prototype.encodeKey.call(this, k);
        return k.replace(/\+/gi, '%2B');
    };
    CustomHttpUrlEncodingCodec.prototype.encodeValue = function (v) {
        v = _super.prototype.encodeValue.call(this, v);
        return v.replace(/\+/gi, '%2B');
    };
    return CustomHttpUrlEncodingCodec;
}(HttpUrlEncodingCodec));

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ApolloDocumentLineResourceService = /** @class */ (function () {
    function ApolloDocumentLineResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ApolloDocumentLineResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ApolloDocumentLineResourceService.prototype.countApolloDocumentLinesUsingGET = function (aliquotaEquals, aliquotaGreaterThan, aliquotaGreaterThanOrEqual, aliquotaIn, aliquotaLessThan, aliquotaLessThanOrEqual, aliquotaNotEquals, aliquotaSpecified, apolloDocumentIdEquals, apolloDocumentIdGreaterThan, apolloDocumentIdGreaterThanOrEqual, apolloDocumentIdIn, apolloDocumentIdLessThan, apolloDocumentIdLessThanOrEqual, apolloDocumentIdNotEquals, apolloDocumentIdSpecified, contrintegpercEquals, contrintegpercGreaterThan, contrintegpercGreaterThanOrEqual, contrintegpercIn, contrintegpercLessThan, contrintegpercLessThanOrEqual, contrintegpercNotEquals, contrintegpercSpecified, contrintegvalEquals, contrintegvalGreaterThan, contrintegvalGreaterThanOrEqual, contrintegvalIn, contrintegvalLessThan, contrintegvalLessThanOrEqual, contrintegvalNotEquals, contrintegvalSpecified, descrizioneContains, descrizioneDoesNotContain, descrizioneEquals, descrizioneIn, descrizioneNotEquals, descrizioneSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, idarticoloEquals, idarticoloGreaterThan, idarticoloGreaterThanOrEqual, idarticoloIn, idarticoloLessThan, idarticoloLessThanOrEqual, idarticoloNotEquals, idarticoloSpecified, iddettfatturaEquals, iddettfatturaGreaterThan, iddettfatturaGreaterThanOrEqual, iddettfatturaIn, iddettfatturaLessThan, iddettfatturaLessThanOrEqual, iddettfatturaNotEquals, iddettfatturaSpecified, iddocEquals, iddocGreaterThan, iddocGreaterThanOrEqual, iddocIn, iddocLessThan, iddocLessThanOrEqual, iddocNotEquals, iddocSpecified, importoEquals, importoGreaterThan, importoGreaterThanOrEqual, importoIn, importoLessThan, importoLessThanOrEqual, importoNotEquals, importoSpecified, ivaEquals, ivaGreaterThan, ivaGreaterThanOrEqual, ivaIn, ivaLessThan, ivaLessThanOrEqual, ivaNotEquals, ivaSpecified, prezzoEquals, prezzoGreaterThan, prezzoGreaterThanOrEqual, prezzoIn, prezzoLessThan, prezzoLessThanOrEqual, prezzoNotEquals, prezzoSpecified, qtaEquals, qtaGreaterThan, qtaGreaterThanOrEqual, qtaIn, qtaLessThan, qtaLessThanOrEqual, qtaNotEquals, qtaSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (aliquotaEquals !== undefined && aliquotaEquals !== null) {
            queryParameters = queryParameters.set('aliquota.equals', aliquotaEquals);
        }
        if (aliquotaGreaterThan !== undefined && aliquotaGreaterThan !== null) {
            queryParameters = queryParameters.set('aliquota.greaterThan', aliquotaGreaterThan);
        }
        if (aliquotaGreaterThanOrEqual !== undefined && aliquotaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('aliquota.greaterThanOrEqual', aliquotaGreaterThanOrEqual);
        }
        if (aliquotaIn) {
            aliquotaIn.forEach(function (element) {
                queryParameters = queryParameters.append('aliquota.in', element);
            });
        }
        if (aliquotaLessThan !== undefined && aliquotaLessThan !== null) {
            queryParameters = queryParameters.set('aliquota.lessThan', aliquotaLessThan);
        }
        if (aliquotaLessThanOrEqual !== undefined && aliquotaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('aliquota.lessThanOrEqual', aliquotaLessThanOrEqual);
        }
        if (aliquotaNotEquals !== undefined && aliquotaNotEquals !== null) {
            queryParameters = queryParameters.set('aliquota.notEquals', aliquotaNotEquals);
        }
        if (aliquotaSpecified !== undefined && aliquotaSpecified !== null) {
            queryParameters = queryParameters.set('aliquota.specified', aliquotaSpecified);
        }
        if (apolloDocumentIdEquals !== undefined && apolloDocumentIdEquals !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.equals', apolloDocumentIdEquals);
        }
        if (apolloDocumentIdGreaterThan !== undefined && apolloDocumentIdGreaterThan !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.greaterThan', apolloDocumentIdGreaterThan);
        }
        if (apolloDocumentIdGreaterThanOrEqual !== undefined && apolloDocumentIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.greaterThanOrEqual', apolloDocumentIdGreaterThanOrEqual);
        }
        if (apolloDocumentIdIn) {
            apolloDocumentIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('apolloDocumentId.in', element);
            });
        }
        if (apolloDocumentIdLessThan !== undefined && apolloDocumentIdLessThan !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.lessThan', apolloDocumentIdLessThan);
        }
        if (apolloDocumentIdLessThanOrEqual !== undefined && apolloDocumentIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.lessThanOrEqual', apolloDocumentIdLessThanOrEqual);
        }
        if (apolloDocumentIdNotEquals !== undefined && apolloDocumentIdNotEquals !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.notEquals', apolloDocumentIdNotEquals);
        }
        if (apolloDocumentIdSpecified !== undefined && apolloDocumentIdSpecified !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.specified', apolloDocumentIdSpecified);
        }
        if (contrintegpercEquals !== undefined && contrintegpercEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.equals', contrintegpercEquals);
        }
        if (contrintegpercGreaterThan !== undefined && contrintegpercGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThan', contrintegpercGreaterThan);
        }
        if (contrintegpercGreaterThanOrEqual !== undefined && contrintegpercGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThanOrEqual', contrintegpercGreaterThanOrEqual);
        }
        if (contrintegpercIn) {
            contrintegpercIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegperc.in', element);
            });
        }
        if (contrintegpercLessThan !== undefined && contrintegpercLessThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThan', contrintegpercLessThan);
        }
        if (contrintegpercLessThanOrEqual !== undefined && contrintegpercLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThanOrEqual', contrintegpercLessThanOrEqual);
        }
        if (contrintegpercNotEquals !== undefined && contrintegpercNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.notEquals', contrintegpercNotEquals);
        }
        if (contrintegpercSpecified !== undefined && contrintegpercSpecified !== null) {
            queryParameters = queryParameters.set('contrintegperc.specified', contrintegpercSpecified);
        }
        if (contrintegvalEquals !== undefined && contrintegvalEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.equals', contrintegvalEquals);
        }
        if (contrintegvalGreaterThan !== undefined && contrintegvalGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThan', contrintegvalGreaterThan);
        }
        if (contrintegvalGreaterThanOrEqual !== undefined && contrintegvalGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThanOrEqual', contrintegvalGreaterThanOrEqual);
        }
        if (contrintegvalIn) {
            contrintegvalIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegval.in', element);
            });
        }
        if (contrintegvalLessThan !== undefined && contrintegvalLessThan !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThan', contrintegvalLessThan);
        }
        if (contrintegvalLessThanOrEqual !== undefined && contrintegvalLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThanOrEqual', contrintegvalLessThanOrEqual);
        }
        if (contrintegvalNotEquals !== undefined && contrintegvalNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.notEquals', contrintegvalNotEquals);
        }
        if (contrintegvalSpecified !== undefined && contrintegvalSpecified !== null) {
            queryParameters = queryParameters.set('contrintegval.specified', contrintegvalSpecified);
        }
        if (descrizioneContains !== undefined && descrizioneContains !== null) {
            queryParameters = queryParameters.set('descrizione.contains', descrizioneContains);
        }
        if (descrizioneDoesNotContain !== undefined && descrizioneDoesNotContain !== null) {
            queryParameters = queryParameters.set('descrizione.doesNotContain', descrizioneDoesNotContain);
        }
        if (descrizioneEquals !== undefined && descrizioneEquals !== null) {
            queryParameters = queryParameters.set('descrizione.equals', descrizioneEquals);
        }
        if (descrizioneIn) {
            descrizioneIn.forEach(function (element) {
                queryParameters = queryParameters.append('descrizione.in', element);
            });
        }
        if (descrizioneNotEquals !== undefined && descrizioneNotEquals !== null) {
            queryParameters = queryParameters.set('descrizione.notEquals', descrizioneNotEquals);
        }
        if (descrizioneSpecified !== undefined && descrizioneSpecified !== null) {
            queryParameters = queryParameters.set('descrizione.specified', descrizioneSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (idarticoloEquals !== undefined && idarticoloEquals !== null) {
            queryParameters = queryParameters.set('idarticolo.equals', idarticoloEquals);
        }
        if (idarticoloGreaterThan !== undefined && idarticoloGreaterThan !== null) {
            queryParameters = queryParameters.set('idarticolo.greaterThan', idarticoloGreaterThan);
        }
        if (idarticoloGreaterThanOrEqual !== undefined && idarticoloGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('idarticolo.greaterThanOrEqual', idarticoloGreaterThanOrEqual);
        }
        if (idarticoloIn) {
            idarticoloIn.forEach(function (element) {
                queryParameters = queryParameters.append('idarticolo.in', element);
            });
        }
        if (idarticoloLessThan !== undefined && idarticoloLessThan !== null) {
            queryParameters = queryParameters.set('idarticolo.lessThan', idarticoloLessThan);
        }
        if (idarticoloLessThanOrEqual !== undefined && idarticoloLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('idarticolo.lessThanOrEqual', idarticoloLessThanOrEqual);
        }
        if (idarticoloNotEquals !== undefined && idarticoloNotEquals !== null) {
            queryParameters = queryParameters.set('idarticolo.notEquals', idarticoloNotEquals);
        }
        if (idarticoloSpecified !== undefined && idarticoloSpecified !== null) {
            queryParameters = queryParameters.set('idarticolo.specified', idarticoloSpecified);
        }
        if (iddettfatturaEquals !== undefined && iddettfatturaEquals !== null) {
            queryParameters = queryParameters.set('iddettfattura.equals', iddettfatturaEquals);
        }
        if (iddettfatturaGreaterThan !== undefined && iddettfatturaGreaterThan !== null) {
            queryParameters = queryParameters.set('iddettfattura.greaterThan', iddettfatturaGreaterThan);
        }
        if (iddettfatturaGreaterThanOrEqual !== undefined && iddettfatturaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddettfattura.greaterThanOrEqual', iddettfatturaGreaterThanOrEqual);
        }
        if (iddettfatturaIn) {
            iddettfatturaIn.forEach(function (element) {
                queryParameters = queryParameters.append('iddettfattura.in', element);
            });
        }
        if (iddettfatturaLessThan !== undefined && iddettfatturaLessThan !== null) {
            queryParameters = queryParameters.set('iddettfattura.lessThan', iddettfatturaLessThan);
        }
        if (iddettfatturaLessThanOrEqual !== undefined && iddettfatturaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddettfattura.lessThanOrEqual', iddettfatturaLessThanOrEqual);
        }
        if (iddettfatturaNotEquals !== undefined && iddettfatturaNotEquals !== null) {
            queryParameters = queryParameters.set('iddettfattura.notEquals', iddettfatturaNotEquals);
        }
        if (iddettfatturaSpecified !== undefined && iddettfatturaSpecified !== null) {
            queryParameters = queryParameters.set('iddettfattura.specified', iddettfatturaSpecified);
        }
        if (iddocEquals !== undefined && iddocEquals !== null) {
            queryParameters = queryParameters.set('iddoc.equals', iddocEquals);
        }
        if (iddocGreaterThan !== undefined && iddocGreaterThan !== null) {
            queryParameters = queryParameters.set('iddoc.greaterThan', iddocGreaterThan);
        }
        if (iddocGreaterThanOrEqual !== undefined && iddocGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddoc.greaterThanOrEqual', iddocGreaterThanOrEqual);
        }
        if (iddocIn) {
            iddocIn.forEach(function (element) {
                queryParameters = queryParameters.append('iddoc.in', element);
            });
        }
        if (iddocLessThan !== undefined && iddocLessThan !== null) {
            queryParameters = queryParameters.set('iddoc.lessThan', iddocLessThan);
        }
        if (iddocLessThanOrEqual !== undefined && iddocLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddoc.lessThanOrEqual', iddocLessThanOrEqual);
        }
        if (iddocNotEquals !== undefined && iddocNotEquals !== null) {
            queryParameters = queryParameters.set('iddoc.notEquals', iddocNotEquals);
        }
        if (iddocSpecified !== undefined && iddocSpecified !== null) {
            queryParameters = queryParameters.set('iddoc.specified', iddocSpecified);
        }
        if (importoEquals !== undefined && importoEquals !== null) {
            queryParameters = queryParameters.set('importo.equals', importoEquals);
        }
        if (importoGreaterThan !== undefined && importoGreaterThan !== null) {
            queryParameters = queryParameters.set('importo.greaterThan', importoGreaterThan);
        }
        if (importoGreaterThanOrEqual !== undefined && importoGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('importo.greaterThanOrEqual', importoGreaterThanOrEqual);
        }
        if (importoIn) {
            importoIn.forEach(function (element) {
                queryParameters = queryParameters.append('importo.in', element);
            });
        }
        if (importoLessThan !== undefined && importoLessThan !== null) {
            queryParameters = queryParameters.set('importo.lessThan', importoLessThan);
        }
        if (importoLessThanOrEqual !== undefined && importoLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('importo.lessThanOrEqual', importoLessThanOrEqual);
        }
        if (importoNotEquals !== undefined && importoNotEquals !== null) {
            queryParameters = queryParameters.set('importo.notEquals', importoNotEquals);
        }
        if (importoSpecified !== undefined && importoSpecified !== null) {
            queryParameters = queryParameters.set('importo.specified', importoSpecified);
        }
        if (ivaEquals !== undefined && ivaEquals !== null) {
            queryParameters = queryParameters.set('iva.equals', ivaEquals);
        }
        if (ivaGreaterThan !== undefined && ivaGreaterThan !== null) {
            queryParameters = queryParameters.set('iva.greaterThan', ivaGreaterThan);
        }
        if (ivaGreaterThanOrEqual !== undefined && ivaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.greaterThanOrEqual', ivaGreaterThanOrEqual);
        }
        if (ivaIn) {
            ivaIn.forEach(function (element) {
                queryParameters = queryParameters.append('iva.in', element);
            });
        }
        if (ivaLessThan !== undefined && ivaLessThan !== null) {
            queryParameters = queryParameters.set('iva.lessThan', ivaLessThan);
        }
        if (ivaLessThanOrEqual !== undefined && ivaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.lessThanOrEqual', ivaLessThanOrEqual);
        }
        if (ivaNotEquals !== undefined && ivaNotEquals !== null) {
            queryParameters = queryParameters.set('iva.notEquals', ivaNotEquals);
        }
        if (ivaSpecified !== undefined && ivaSpecified !== null) {
            queryParameters = queryParameters.set('iva.specified', ivaSpecified);
        }
        if (prezzoEquals !== undefined && prezzoEquals !== null) {
            queryParameters = queryParameters.set('prezzo.equals', prezzoEquals);
        }
        if (prezzoGreaterThan !== undefined && prezzoGreaterThan !== null) {
            queryParameters = queryParameters.set('prezzo.greaterThan', prezzoGreaterThan);
        }
        if (prezzoGreaterThanOrEqual !== undefined && prezzoGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('prezzo.greaterThanOrEqual', prezzoGreaterThanOrEqual);
        }
        if (prezzoIn) {
            prezzoIn.forEach(function (element) {
                queryParameters = queryParameters.append('prezzo.in', element);
            });
        }
        if (prezzoLessThan !== undefined && prezzoLessThan !== null) {
            queryParameters = queryParameters.set('prezzo.lessThan', prezzoLessThan);
        }
        if (prezzoLessThanOrEqual !== undefined && prezzoLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('prezzo.lessThanOrEqual', prezzoLessThanOrEqual);
        }
        if (prezzoNotEquals !== undefined && prezzoNotEquals !== null) {
            queryParameters = queryParameters.set('prezzo.notEquals', prezzoNotEquals);
        }
        if (prezzoSpecified !== undefined && prezzoSpecified !== null) {
            queryParameters = queryParameters.set('prezzo.specified', prezzoSpecified);
        }
        if (qtaEquals !== undefined && qtaEquals !== null) {
            queryParameters = queryParameters.set('qta.equals', qtaEquals);
        }
        if (qtaGreaterThan !== undefined && qtaGreaterThan !== null) {
            queryParameters = queryParameters.set('qta.greaterThan', qtaGreaterThan);
        }
        if (qtaGreaterThanOrEqual !== undefined && qtaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('qta.greaterThanOrEqual', qtaGreaterThanOrEqual);
        }
        if (qtaIn) {
            qtaIn.forEach(function (element) {
                queryParameters = queryParameters.append('qta.in', element);
            });
        }
        if (qtaLessThan !== undefined && qtaLessThan !== null) {
            queryParameters = queryParameters.set('qta.lessThan', qtaLessThan);
        }
        if (qtaLessThanOrEqual !== undefined && qtaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('qta.lessThanOrEqual', qtaLessThanOrEqual);
        }
        if (qtaNotEquals !== undefined && qtaNotEquals !== null) {
            queryParameters = queryParameters.set('qta.notEquals', qtaNotEquals);
        }
        if (qtaSpecified !== undefined && qtaSpecified !== null) {
            queryParameters = queryParameters.set('qta.specified', qtaSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/apollo-document-lines/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentLineResourceService.prototype.createApolloDocumentLineUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createApolloDocumentLineUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/apollo-document-lines", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentLineResourceService.prototype.deleteApolloDocumentLineUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteApolloDocumentLineUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/apollo-document-lines/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentLineResourceService.prototype.getAllApolloDocumentLinesUsingGET = function (aliquotaEquals, aliquotaGreaterThan, aliquotaGreaterThanOrEqual, aliquotaIn, aliquotaLessThan, aliquotaLessThanOrEqual, aliquotaNotEquals, aliquotaSpecified, apolloDocumentIdEquals, apolloDocumentIdGreaterThan, apolloDocumentIdGreaterThanOrEqual, apolloDocumentIdIn, apolloDocumentIdLessThan, apolloDocumentIdLessThanOrEqual, apolloDocumentIdNotEquals, apolloDocumentIdSpecified, contrintegpercEquals, contrintegpercGreaterThan, contrintegpercGreaterThanOrEqual, contrintegpercIn, contrintegpercLessThan, contrintegpercLessThanOrEqual, contrintegpercNotEquals, contrintegpercSpecified, contrintegvalEquals, contrintegvalGreaterThan, contrintegvalGreaterThanOrEqual, contrintegvalIn, contrintegvalLessThan, contrintegvalLessThanOrEqual, contrintegvalNotEquals, contrintegvalSpecified, descrizioneContains, descrizioneDoesNotContain, descrizioneEquals, descrizioneIn, descrizioneNotEquals, descrizioneSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, idarticoloEquals, idarticoloGreaterThan, idarticoloGreaterThanOrEqual, idarticoloIn, idarticoloLessThan, idarticoloLessThanOrEqual, idarticoloNotEquals, idarticoloSpecified, iddettfatturaEquals, iddettfatturaGreaterThan, iddettfatturaGreaterThanOrEqual, iddettfatturaIn, iddettfatturaLessThan, iddettfatturaLessThanOrEqual, iddettfatturaNotEquals, iddettfatturaSpecified, iddocEquals, iddocGreaterThan, iddocGreaterThanOrEqual, iddocIn, iddocLessThan, iddocLessThanOrEqual, iddocNotEquals, iddocSpecified, importoEquals, importoGreaterThan, importoGreaterThanOrEqual, importoIn, importoLessThan, importoLessThanOrEqual, importoNotEquals, importoSpecified, ivaEquals, ivaGreaterThan, ivaGreaterThanOrEqual, ivaIn, ivaLessThan, ivaLessThanOrEqual, ivaNotEquals, ivaSpecified, page, prezzoEquals, prezzoGreaterThan, prezzoGreaterThanOrEqual, prezzoIn, prezzoLessThan, prezzoLessThanOrEqual, prezzoNotEquals, prezzoSpecified, qtaEquals, qtaGreaterThan, qtaGreaterThanOrEqual, qtaIn, qtaLessThan, qtaLessThanOrEqual, qtaNotEquals, qtaSpecified, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (aliquotaEquals !== undefined && aliquotaEquals !== null) {
            queryParameters = queryParameters.set('aliquota.equals', aliquotaEquals);
        }
        if (aliquotaGreaterThan !== undefined && aliquotaGreaterThan !== null) {
            queryParameters = queryParameters.set('aliquota.greaterThan', aliquotaGreaterThan);
        }
        if (aliquotaGreaterThanOrEqual !== undefined && aliquotaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('aliquota.greaterThanOrEqual', aliquotaGreaterThanOrEqual);
        }
        if (aliquotaIn) {
            aliquotaIn.forEach(function (element) {
                queryParameters = queryParameters.append('aliquota.in', element);
            });
        }
        if (aliquotaLessThan !== undefined && aliquotaLessThan !== null) {
            queryParameters = queryParameters.set('aliquota.lessThan', aliquotaLessThan);
        }
        if (aliquotaLessThanOrEqual !== undefined && aliquotaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('aliquota.lessThanOrEqual', aliquotaLessThanOrEqual);
        }
        if (aliquotaNotEquals !== undefined && aliquotaNotEquals !== null) {
            queryParameters = queryParameters.set('aliquota.notEquals', aliquotaNotEquals);
        }
        if (aliquotaSpecified !== undefined && aliquotaSpecified !== null) {
            queryParameters = queryParameters.set('aliquota.specified', aliquotaSpecified);
        }
        if (apolloDocumentIdEquals !== undefined && apolloDocumentIdEquals !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.equals', apolloDocumentIdEquals);
        }
        if (apolloDocumentIdGreaterThan !== undefined && apolloDocumentIdGreaterThan !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.greaterThan', apolloDocumentIdGreaterThan);
        }
        if (apolloDocumentIdGreaterThanOrEqual !== undefined && apolloDocumentIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.greaterThanOrEqual', apolloDocumentIdGreaterThanOrEqual);
        }
        if (apolloDocumentIdIn) {
            apolloDocumentIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('apolloDocumentId.in', element);
            });
        }
        if (apolloDocumentIdLessThan !== undefined && apolloDocumentIdLessThan !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.lessThan', apolloDocumentIdLessThan);
        }
        if (apolloDocumentIdLessThanOrEqual !== undefined && apolloDocumentIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.lessThanOrEqual', apolloDocumentIdLessThanOrEqual);
        }
        if (apolloDocumentIdNotEquals !== undefined && apolloDocumentIdNotEquals !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.notEquals', apolloDocumentIdNotEquals);
        }
        if (apolloDocumentIdSpecified !== undefined && apolloDocumentIdSpecified !== null) {
            queryParameters = queryParameters.set('apolloDocumentId.specified', apolloDocumentIdSpecified);
        }
        if (contrintegpercEquals !== undefined && contrintegpercEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.equals', contrintegpercEquals);
        }
        if (contrintegpercGreaterThan !== undefined && contrintegpercGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThan', contrintegpercGreaterThan);
        }
        if (contrintegpercGreaterThanOrEqual !== undefined && contrintegpercGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThanOrEqual', contrintegpercGreaterThanOrEqual);
        }
        if (contrintegpercIn) {
            contrintegpercIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegperc.in', element);
            });
        }
        if (contrintegpercLessThan !== undefined && contrintegpercLessThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThan', contrintegpercLessThan);
        }
        if (contrintegpercLessThanOrEqual !== undefined && contrintegpercLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThanOrEqual', contrintegpercLessThanOrEqual);
        }
        if (contrintegpercNotEquals !== undefined && contrintegpercNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.notEquals', contrintegpercNotEquals);
        }
        if (contrintegpercSpecified !== undefined && contrintegpercSpecified !== null) {
            queryParameters = queryParameters.set('contrintegperc.specified', contrintegpercSpecified);
        }
        if (contrintegvalEquals !== undefined && contrintegvalEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.equals', contrintegvalEquals);
        }
        if (contrintegvalGreaterThan !== undefined && contrintegvalGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThan', contrintegvalGreaterThan);
        }
        if (contrintegvalGreaterThanOrEqual !== undefined && contrintegvalGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThanOrEqual', contrintegvalGreaterThanOrEqual);
        }
        if (contrintegvalIn) {
            contrintegvalIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegval.in', element);
            });
        }
        if (contrintegvalLessThan !== undefined && contrintegvalLessThan !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThan', contrintegvalLessThan);
        }
        if (contrintegvalLessThanOrEqual !== undefined && contrintegvalLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThanOrEqual', contrintegvalLessThanOrEqual);
        }
        if (contrintegvalNotEquals !== undefined && contrintegvalNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.notEquals', contrintegvalNotEquals);
        }
        if (contrintegvalSpecified !== undefined && contrintegvalSpecified !== null) {
            queryParameters = queryParameters.set('contrintegval.specified', contrintegvalSpecified);
        }
        if (descrizioneContains !== undefined && descrizioneContains !== null) {
            queryParameters = queryParameters.set('descrizione.contains', descrizioneContains);
        }
        if (descrizioneDoesNotContain !== undefined && descrizioneDoesNotContain !== null) {
            queryParameters = queryParameters.set('descrizione.doesNotContain', descrizioneDoesNotContain);
        }
        if (descrizioneEquals !== undefined && descrizioneEquals !== null) {
            queryParameters = queryParameters.set('descrizione.equals', descrizioneEquals);
        }
        if (descrizioneIn) {
            descrizioneIn.forEach(function (element) {
                queryParameters = queryParameters.append('descrizione.in', element);
            });
        }
        if (descrizioneNotEquals !== undefined && descrizioneNotEquals !== null) {
            queryParameters = queryParameters.set('descrizione.notEquals', descrizioneNotEquals);
        }
        if (descrizioneSpecified !== undefined && descrizioneSpecified !== null) {
            queryParameters = queryParameters.set('descrizione.specified', descrizioneSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (idarticoloEquals !== undefined && idarticoloEquals !== null) {
            queryParameters = queryParameters.set('idarticolo.equals', idarticoloEquals);
        }
        if (idarticoloGreaterThan !== undefined && idarticoloGreaterThan !== null) {
            queryParameters = queryParameters.set('idarticolo.greaterThan', idarticoloGreaterThan);
        }
        if (idarticoloGreaterThanOrEqual !== undefined && idarticoloGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('idarticolo.greaterThanOrEqual', idarticoloGreaterThanOrEqual);
        }
        if (idarticoloIn) {
            idarticoloIn.forEach(function (element) {
                queryParameters = queryParameters.append('idarticolo.in', element);
            });
        }
        if (idarticoloLessThan !== undefined && idarticoloLessThan !== null) {
            queryParameters = queryParameters.set('idarticolo.lessThan', idarticoloLessThan);
        }
        if (idarticoloLessThanOrEqual !== undefined && idarticoloLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('idarticolo.lessThanOrEqual', idarticoloLessThanOrEqual);
        }
        if (idarticoloNotEquals !== undefined && idarticoloNotEquals !== null) {
            queryParameters = queryParameters.set('idarticolo.notEquals', idarticoloNotEquals);
        }
        if (idarticoloSpecified !== undefined && idarticoloSpecified !== null) {
            queryParameters = queryParameters.set('idarticolo.specified', idarticoloSpecified);
        }
        if (iddettfatturaEquals !== undefined && iddettfatturaEquals !== null) {
            queryParameters = queryParameters.set('iddettfattura.equals', iddettfatturaEquals);
        }
        if (iddettfatturaGreaterThan !== undefined && iddettfatturaGreaterThan !== null) {
            queryParameters = queryParameters.set('iddettfattura.greaterThan', iddettfatturaGreaterThan);
        }
        if (iddettfatturaGreaterThanOrEqual !== undefined && iddettfatturaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddettfattura.greaterThanOrEqual', iddettfatturaGreaterThanOrEqual);
        }
        if (iddettfatturaIn) {
            iddettfatturaIn.forEach(function (element) {
                queryParameters = queryParameters.append('iddettfattura.in', element);
            });
        }
        if (iddettfatturaLessThan !== undefined && iddettfatturaLessThan !== null) {
            queryParameters = queryParameters.set('iddettfattura.lessThan', iddettfatturaLessThan);
        }
        if (iddettfatturaLessThanOrEqual !== undefined && iddettfatturaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddettfattura.lessThanOrEqual', iddettfatturaLessThanOrEqual);
        }
        if (iddettfatturaNotEquals !== undefined && iddettfatturaNotEquals !== null) {
            queryParameters = queryParameters.set('iddettfattura.notEquals', iddettfatturaNotEquals);
        }
        if (iddettfatturaSpecified !== undefined && iddettfatturaSpecified !== null) {
            queryParameters = queryParameters.set('iddettfattura.specified', iddettfatturaSpecified);
        }
        if (iddocEquals !== undefined && iddocEquals !== null) {
            queryParameters = queryParameters.set('iddoc.equals', iddocEquals);
        }
        if (iddocGreaterThan !== undefined && iddocGreaterThan !== null) {
            queryParameters = queryParameters.set('iddoc.greaterThan', iddocGreaterThan);
        }
        if (iddocGreaterThanOrEqual !== undefined && iddocGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddoc.greaterThanOrEqual', iddocGreaterThanOrEqual);
        }
        if (iddocIn) {
            iddocIn.forEach(function (element) {
                queryParameters = queryParameters.append('iddoc.in', element);
            });
        }
        if (iddocLessThan !== undefined && iddocLessThan !== null) {
            queryParameters = queryParameters.set('iddoc.lessThan', iddocLessThan);
        }
        if (iddocLessThanOrEqual !== undefined && iddocLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iddoc.lessThanOrEqual', iddocLessThanOrEqual);
        }
        if (iddocNotEquals !== undefined && iddocNotEquals !== null) {
            queryParameters = queryParameters.set('iddoc.notEquals', iddocNotEquals);
        }
        if (iddocSpecified !== undefined && iddocSpecified !== null) {
            queryParameters = queryParameters.set('iddoc.specified', iddocSpecified);
        }
        if (importoEquals !== undefined && importoEquals !== null) {
            queryParameters = queryParameters.set('importo.equals', importoEquals);
        }
        if (importoGreaterThan !== undefined && importoGreaterThan !== null) {
            queryParameters = queryParameters.set('importo.greaterThan', importoGreaterThan);
        }
        if (importoGreaterThanOrEqual !== undefined && importoGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('importo.greaterThanOrEqual', importoGreaterThanOrEqual);
        }
        if (importoIn) {
            importoIn.forEach(function (element) {
                queryParameters = queryParameters.append('importo.in', element);
            });
        }
        if (importoLessThan !== undefined && importoLessThan !== null) {
            queryParameters = queryParameters.set('importo.lessThan', importoLessThan);
        }
        if (importoLessThanOrEqual !== undefined && importoLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('importo.lessThanOrEqual', importoLessThanOrEqual);
        }
        if (importoNotEquals !== undefined && importoNotEquals !== null) {
            queryParameters = queryParameters.set('importo.notEquals', importoNotEquals);
        }
        if (importoSpecified !== undefined && importoSpecified !== null) {
            queryParameters = queryParameters.set('importo.specified', importoSpecified);
        }
        if (ivaEquals !== undefined && ivaEquals !== null) {
            queryParameters = queryParameters.set('iva.equals', ivaEquals);
        }
        if (ivaGreaterThan !== undefined && ivaGreaterThan !== null) {
            queryParameters = queryParameters.set('iva.greaterThan', ivaGreaterThan);
        }
        if (ivaGreaterThanOrEqual !== undefined && ivaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.greaterThanOrEqual', ivaGreaterThanOrEqual);
        }
        if (ivaIn) {
            ivaIn.forEach(function (element) {
                queryParameters = queryParameters.append('iva.in', element);
            });
        }
        if (ivaLessThan !== undefined && ivaLessThan !== null) {
            queryParameters = queryParameters.set('iva.lessThan', ivaLessThan);
        }
        if (ivaLessThanOrEqual !== undefined && ivaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.lessThanOrEqual', ivaLessThanOrEqual);
        }
        if (ivaNotEquals !== undefined && ivaNotEquals !== null) {
            queryParameters = queryParameters.set('iva.notEquals', ivaNotEquals);
        }
        if (ivaSpecified !== undefined && ivaSpecified !== null) {
            queryParameters = queryParameters.set('iva.specified', ivaSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (prezzoEquals !== undefined && prezzoEquals !== null) {
            queryParameters = queryParameters.set('prezzo.equals', prezzoEquals);
        }
        if (prezzoGreaterThan !== undefined && prezzoGreaterThan !== null) {
            queryParameters = queryParameters.set('prezzo.greaterThan', prezzoGreaterThan);
        }
        if (prezzoGreaterThanOrEqual !== undefined && prezzoGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('prezzo.greaterThanOrEqual', prezzoGreaterThanOrEqual);
        }
        if (prezzoIn) {
            prezzoIn.forEach(function (element) {
                queryParameters = queryParameters.append('prezzo.in', element);
            });
        }
        if (prezzoLessThan !== undefined && prezzoLessThan !== null) {
            queryParameters = queryParameters.set('prezzo.lessThan', prezzoLessThan);
        }
        if (prezzoLessThanOrEqual !== undefined && prezzoLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('prezzo.lessThanOrEqual', prezzoLessThanOrEqual);
        }
        if (prezzoNotEquals !== undefined && prezzoNotEquals !== null) {
            queryParameters = queryParameters.set('prezzo.notEquals', prezzoNotEquals);
        }
        if (prezzoSpecified !== undefined && prezzoSpecified !== null) {
            queryParameters = queryParameters.set('prezzo.specified', prezzoSpecified);
        }
        if (qtaEquals !== undefined && qtaEquals !== null) {
            queryParameters = queryParameters.set('qta.equals', qtaEquals);
        }
        if (qtaGreaterThan !== undefined && qtaGreaterThan !== null) {
            queryParameters = queryParameters.set('qta.greaterThan', qtaGreaterThan);
        }
        if (qtaGreaterThanOrEqual !== undefined && qtaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('qta.greaterThanOrEqual', qtaGreaterThanOrEqual);
        }
        if (qtaIn) {
            qtaIn.forEach(function (element) {
                queryParameters = queryParameters.append('qta.in', element);
            });
        }
        if (qtaLessThan !== undefined && qtaLessThan !== null) {
            queryParameters = queryParameters.set('qta.lessThan', qtaLessThan);
        }
        if (qtaLessThanOrEqual !== undefined && qtaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('qta.lessThanOrEqual', qtaLessThanOrEqual);
        }
        if (qtaNotEquals !== undefined && qtaNotEquals !== null) {
            queryParameters = queryParameters.set('qta.notEquals', qtaNotEquals);
        }
        if (qtaSpecified !== undefined && qtaSpecified !== null) {
            queryParameters = queryParameters.set('qta.specified', qtaSpecified);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/apollo-document-lines", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentLineResourceService.prototype.getApolloDocumentLineUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getApolloDocumentLineUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/apollo-document-lines/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentLineResourceService.prototype.updateApolloDocumentLineUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateApolloDocumentLineUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/apollo-document-lines", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentLineResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ApolloDocumentLineResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ApolloDocumentLineResourceService);
    return ApolloDocumentLineResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ApolloDocumentResourceService = /** @class */ (function () {
    function ApolloDocumentResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ApolloDocumentResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ApolloDocumentResourceService.prototype.countApolloDocumentsUsingGET = function (capContains, capDoesNotContain, capEquals, capIn, capNotEquals, capSpecified, cittContains, cittDoesNotContain, cittEquals, cittIn, cittNotEquals, cittSpecified, clienteEquals, clienteIn, clienteNotEquals, clienteSpecified, codfiscContains, codfiscDoesNotContain, codfiscEquals, codfiscIn, codfiscNotEquals, codfiscSpecified, codiceInvioContains, codiceInvioDoesNotContain, codiceInvioEquals, codiceInvioIn, codiceInvioNotEquals, codiceInvioSpecified, contoEquals, contoGreaterThan, contoGreaterThanOrEqual, contoIn, contoLessThan, contoLessThanOrEqual, contoNotEquals, contoSpecified, contrintegpercEquals, contrintegpercGreaterThan, contrintegpercGreaterThanOrEqual, contrintegpercIn, contrintegpercLessThan, contrintegpercLessThanOrEqual, contrintegpercNotEquals, contrintegpercSpecified, contrintegvalEquals, contrintegvalGreaterThan, contrintegvalGreaterThanOrEqual, contrintegvalIn, contrintegvalLessThan, contrintegvalLessThanOrEqual, contrintegvalNotEquals, contrintegvalSpecified, dataEquals, dataGreaterThan, dataGreaterThanOrEqual, dataIn0ChronologyCalendarType, dataIn0ChronologyId, dataIn0DayOfMonth, dataIn0DayOfWeek, dataIn0DayOfYear, dataIn0EraValue, dataIn0LeapYear, dataIn0Month, dataIn0MonthValue, dataIn0Year, dataLessThan, dataLessThanOrEqual, dataNotEquals, dataSpecified, datainsEquals, datainsGreaterThan, datainsGreaterThanOrEqual, datainsIn0DayOfMonth, datainsIn0DayOfWeek, datainsIn0DayOfYear, datainsIn0Hour, datainsIn0Minute, datainsIn0Month, datainsIn0MonthValue, datainsIn0Nano, datainsIn0OffsetId, datainsIn0OffsetRulesFixedOffset, datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator, datainsIn0OffsetRulesTransitionRules0DayOfWeek, datainsIn0OffsetRulesTransitionRules0LocalTimeHour, datainsIn0OffsetRulesTransitionRules0LocalTimeMinute, datainsIn0OffsetRulesTransitionRules0LocalTimeNano, datainsIn0OffsetRulesTransitionRules0LocalTimeSecond, datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay, datainsIn0OffsetRulesTransitionRules0Month, datainsIn0OffsetRulesTransitionRules0TimeDefinition, datainsIn0OffsetRulesTransitions0DateTimeAfter, datainsIn0OffsetRulesTransitions0DateTimeBefore, datainsIn0OffsetRulesTransitions0DurationNano, datainsIn0OffsetRulesTransitions0DurationNegative, datainsIn0OffsetRulesTransitions0DurationSeconds, datainsIn0OffsetRulesTransitions0DurationUnits0DateBased, datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated, datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased, datainsIn0OffsetRulesTransitions0DurationZero, datainsIn0OffsetRulesTransitions0Gap, datainsIn0OffsetRulesTransitions0Instant, datainsIn0OffsetRulesTransitions0Overlap, datainsIn0OffsetTotalSeconds, datainsIn0Second, datainsIn0Year, datainsIn0ZoneId, datainsIn0ZoneRulesFixedOffset, datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator, datainsIn0ZoneRulesTransitionRules0DayOfWeek, datainsIn0ZoneRulesTransitionRules0LocalTimeHour, datainsIn0ZoneRulesTransitionRules0LocalTimeMinute, datainsIn0ZoneRulesTransitionRules0LocalTimeNano, datainsIn0ZoneRulesTransitionRules0LocalTimeSecond, datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay, datainsIn0ZoneRulesTransitionRules0Month, datainsIn0ZoneRulesTransitionRules0OffsetAfterId, datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds, datainsIn0ZoneRulesTransitionRules0OffsetBeforeId, datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds, datainsIn0ZoneRulesTransitionRules0StandardOffsetId, datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds, datainsIn0ZoneRulesTransitionRules0TimeDefinition, datainsIn0ZoneRulesTransitions0DateTimeAfter, datainsIn0ZoneRulesTransitions0DateTimeBefore, datainsIn0ZoneRulesTransitions0DurationNano, datainsIn0ZoneRulesTransitions0DurationNegative, datainsIn0ZoneRulesTransitions0DurationSeconds, datainsIn0ZoneRulesTransitions0DurationUnits0DateBased, datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated, datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased, datainsIn0ZoneRulesTransitions0DurationZero, datainsIn0ZoneRulesTransitions0Gap, datainsIn0ZoneRulesTransitions0Instant, datainsIn0ZoneRulesTransitions0OffsetAfterId, datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds, datainsIn0ZoneRulesTransitions0OffsetBeforeId, datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds, datainsIn0ZoneRulesTransitions0Overlap, datainsLessThan, datainsLessThanOrEqual, datainsNotEquals, datainsSpecified, dataregistrazioneEquals, dataregistrazioneGreaterThan, dataregistrazioneGreaterThanOrEqual, dataregistrazioneIn0ChronologyCalendarType, dataregistrazioneIn0ChronologyId, dataregistrazioneIn0DayOfMonth, dataregistrazioneIn0DayOfWeek, dataregistrazioneIn0DayOfYear, dataregistrazioneIn0EraValue, dataregistrazioneIn0LeapYear, dataregistrazioneIn0Month, dataregistrazioneIn0MonthValue, dataregistrazioneIn0Year, dataregistrazioneLessThan, dataregistrazioneLessThanOrEqual, dataregistrazioneNotEquals, dataregistrazioneSpecified, fornitoreEquals, fornitoreIn, fornitoreNotEquals, fornitoreSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, idanagraficaEquals, idanagraficaGreaterThan, idanagraficaGreaterThanOrEqual, idanagraficaIn, idanagraficaLessThan, idanagraficaLessThanOrEqual, idanagraficaNotEquals, idanagraficaSpecified, idaziendaEquals, idaziendaGreaterThan, idaziendaGreaterThanOrEqual, idaziendaIn, idaziendaLessThan, idaziendaLessThanOrEqual, idaziendaNotEquals, idaziendaSpecified, iddocumentoContains, iddocumentoDoesNotContain, iddocumentoEquals, iddocumentoIn, iddocumentoNotEquals, iddocumentoSpecified, idsottocontoContains, idsottocontoDoesNotContain, idsottocontoEquals, idsottocontoIn, idsottocontoNotEquals, idsottocontoSpecified, indirizzoContains, indirizzoDoesNotContain, indirizzoEquals, indirizzoIn, indirizzoNotEquals, indirizzoSpecified, intestazioneContains, intestazioneDoesNotContain, intestazioneEquals, intestazioneIn, intestazioneNotEquals, intestazioneSpecified, ivaEquals, ivaGreaterThan, ivaGreaterThanOrEqual, ivaIn, ivaLessThan, ivaLessThanOrEqual, ivaNotEquals, ivaSpecified, ivasinoEquals, ivasinoIn, ivasinoNotEquals, ivasinoSpecified, mdopagEquals, mdopagGreaterThan, mdopagGreaterThanOrEqual, mdopagIn, mdopagLessThan, mdopagLessThanOrEqual, mdopagNotEquals, mdopagSpecified, ndocContains, ndocDoesNotContain, ndocEquals, ndocIn, ndocNotEquals, ndocSpecified, ndocSuffEquals, ndocSuffGreaterThan, ndocSuffGreaterThanOrEqual, ndocSuffIn, ndocSuffLessThan, ndocSuffLessThanOrEqual, ndocSuffNotEquals, ndocSuffSpecified, noteContains, noteDoesNotContain, noteEquals, noteIn, noteNotEquals, noteSpecified, opeinsContains, opeinsDoesNotContain, opeinsEquals, opeinsIn, opeinsNotEquals, opeinsSpecified, pecContains, pecDoesNotContain, pecEquals, pecIn, pecNotEquals, pecSpecified, percentIvaEquals, percentIvaGreaterThan, percentIvaGreaterThanOrEqual, percentIvaIn, percentIvaLessThan, percentIvaLessThanOrEqual, percentIvaNotEquals, percentIvaSpecified, percritenutaEquals, percritenutaGreaterThan, percritenutaGreaterThanOrEqual, percritenutaIn, percritenutaLessThan, percritenutaLessThanOrEqual, percritenutaNotEquals, percritenutaSpecified, pivaContains, pivaDoesNotContain, pivaEquals, pivaIn, pivaNotEquals, pivaSpecified, protSuffEquals, protSuffGreaterThan, protSuffGreaterThanOrEqual, protSuffIn, protSuffLessThan, protSuffLessThanOrEqual, protSuffNotEquals, protSuffSpecified, protocolloEquals, protocolloGreaterThan, protocolloGreaterThanOrEqual, protocolloIn, protocolloLessThan, protocolloLessThanOrEqual, protocolloNotEquals, protocolloSpecified, provContains, provDoesNotContain, provEquals, provIn, provNotEquals, provSpecified, ritenutaEquals, ritenutaGreaterThan, ritenutaGreaterThanOrEqual, ritenutaIn, ritenutaLessThan, ritenutaLessThanOrEqual, ritenutaNotEquals, ritenutaSpecified, tipoContains, tipoDoesNotContain, tipoEquals, tipoIn, tipoNotEquals, tipoSpecified, totaleEquals, totaleGreaterThan, totaleGreaterThanOrEqual, totaleIn, totaleLessThan, totaleLessThanOrEqual, totaleNotEquals, totaleSpecified, totimponibileEquals, totimponibileGreaterThan, totimponibileGreaterThanOrEqual, totimponibileIn, totimponibileLessThan, totimponibileLessThanOrEqual, totimponibileNotEquals, totimponibileSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (capContains !== undefined && capContains !== null) {
            queryParameters = queryParameters.set('cap.contains', capContains);
        }
        if (capDoesNotContain !== undefined && capDoesNotContain !== null) {
            queryParameters = queryParameters.set('cap.doesNotContain', capDoesNotContain);
        }
        if (capEquals !== undefined && capEquals !== null) {
            queryParameters = queryParameters.set('cap.equals', capEquals);
        }
        if (capIn) {
            capIn.forEach(function (element) {
                queryParameters = queryParameters.append('cap.in', element);
            });
        }
        if (capNotEquals !== undefined && capNotEquals !== null) {
            queryParameters = queryParameters.set('cap.notEquals', capNotEquals);
        }
        if (capSpecified !== undefined && capSpecified !== null) {
            queryParameters = queryParameters.set('cap.specified', capSpecified);
        }
        if (cittContains !== undefined && cittContains !== null) {
            queryParameters = queryParameters.set('citt.contains', cittContains);
        }
        if (cittDoesNotContain !== undefined && cittDoesNotContain !== null) {
            queryParameters = queryParameters.set('citt.doesNotContain', cittDoesNotContain);
        }
        if (cittEquals !== undefined && cittEquals !== null) {
            queryParameters = queryParameters.set('citt.equals', cittEquals);
        }
        if (cittIn) {
            cittIn.forEach(function (element) {
                queryParameters = queryParameters.append('citt.in', element);
            });
        }
        if (cittNotEquals !== undefined && cittNotEquals !== null) {
            queryParameters = queryParameters.set('citt.notEquals', cittNotEquals);
        }
        if (cittSpecified !== undefined && cittSpecified !== null) {
            queryParameters = queryParameters.set('citt.specified', cittSpecified);
        }
        if (clienteEquals !== undefined && clienteEquals !== null) {
            queryParameters = queryParameters.set('cliente.equals', clienteEquals);
        }
        if (clienteIn) {
            clienteIn.forEach(function (element) {
                queryParameters = queryParameters.append('cliente.in', element);
            });
        }
        if (clienteNotEquals !== undefined && clienteNotEquals !== null) {
            queryParameters = queryParameters.set('cliente.notEquals', clienteNotEquals);
        }
        if (clienteSpecified !== undefined && clienteSpecified !== null) {
            queryParameters = queryParameters.set('cliente.specified', clienteSpecified);
        }
        if (codfiscContains !== undefined && codfiscContains !== null) {
            queryParameters = queryParameters.set('codfisc.contains', codfiscContains);
        }
        if (codfiscDoesNotContain !== undefined && codfiscDoesNotContain !== null) {
            queryParameters = queryParameters.set('codfisc.doesNotContain', codfiscDoesNotContain);
        }
        if (codfiscEquals !== undefined && codfiscEquals !== null) {
            queryParameters = queryParameters.set('codfisc.equals', codfiscEquals);
        }
        if (codfiscIn) {
            codfiscIn.forEach(function (element) {
                queryParameters = queryParameters.append('codfisc.in', element);
            });
        }
        if (codfiscNotEquals !== undefined && codfiscNotEquals !== null) {
            queryParameters = queryParameters.set('codfisc.notEquals', codfiscNotEquals);
        }
        if (codfiscSpecified !== undefined && codfiscSpecified !== null) {
            queryParameters = queryParameters.set('codfisc.specified', codfiscSpecified);
        }
        if (codiceInvioContains !== undefined && codiceInvioContains !== null) {
            queryParameters = queryParameters.set('codiceInvio.contains', codiceInvioContains);
        }
        if (codiceInvioDoesNotContain !== undefined && codiceInvioDoesNotContain !== null) {
            queryParameters = queryParameters.set('codiceInvio.doesNotContain', codiceInvioDoesNotContain);
        }
        if (codiceInvioEquals !== undefined && codiceInvioEquals !== null) {
            queryParameters = queryParameters.set('codiceInvio.equals', codiceInvioEquals);
        }
        if (codiceInvioIn) {
            codiceInvioIn.forEach(function (element) {
                queryParameters = queryParameters.append('codiceInvio.in', element);
            });
        }
        if (codiceInvioNotEquals !== undefined && codiceInvioNotEquals !== null) {
            queryParameters = queryParameters.set('codiceInvio.notEquals', codiceInvioNotEquals);
        }
        if (codiceInvioSpecified !== undefined && codiceInvioSpecified !== null) {
            queryParameters = queryParameters.set('codiceInvio.specified', codiceInvioSpecified);
        }
        if (contoEquals !== undefined && contoEquals !== null) {
            queryParameters = queryParameters.set('conto.equals', contoEquals);
        }
        if (contoGreaterThan !== undefined && contoGreaterThan !== null) {
            queryParameters = queryParameters.set('conto.greaterThan', contoGreaterThan);
        }
        if (contoGreaterThanOrEqual !== undefined && contoGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('conto.greaterThanOrEqual', contoGreaterThanOrEqual);
        }
        if (contoIn) {
            contoIn.forEach(function (element) {
                queryParameters = queryParameters.append('conto.in', element);
            });
        }
        if (contoLessThan !== undefined && contoLessThan !== null) {
            queryParameters = queryParameters.set('conto.lessThan', contoLessThan);
        }
        if (contoLessThanOrEqual !== undefined && contoLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('conto.lessThanOrEqual', contoLessThanOrEqual);
        }
        if (contoNotEquals !== undefined && contoNotEquals !== null) {
            queryParameters = queryParameters.set('conto.notEquals', contoNotEquals);
        }
        if (contoSpecified !== undefined && contoSpecified !== null) {
            queryParameters = queryParameters.set('conto.specified', contoSpecified);
        }
        if (contrintegpercEquals !== undefined && contrintegpercEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.equals', contrintegpercEquals);
        }
        if (contrintegpercGreaterThan !== undefined && contrintegpercGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThan', contrintegpercGreaterThan);
        }
        if (contrintegpercGreaterThanOrEqual !== undefined && contrintegpercGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThanOrEqual', contrintegpercGreaterThanOrEqual);
        }
        if (contrintegpercIn) {
            contrintegpercIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegperc.in', element);
            });
        }
        if (contrintegpercLessThan !== undefined && contrintegpercLessThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThan', contrintegpercLessThan);
        }
        if (contrintegpercLessThanOrEqual !== undefined && contrintegpercLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThanOrEqual', contrintegpercLessThanOrEqual);
        }
        if (contrintegpercNotEquals !== undefined && contrintegpercNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.notEquals', contrintegpercNotEquals);
        }
        if (contrintegpercSpecified !== undefined && contrintegpercSpecified !== null) {
            queryParameters = queryParameters.set('contrintegperc.specified', contrintegpercSpecified);
        }
        if (contrintegvalEquals !== undefined && contrintegvalEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.equals', contrintegvalEquals);
        }
        if (contrintegvalGreaterThan !== undefined && contrintegvalGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThan', contrintegvalGreaterThan);
        }
        if (contrintegvalGreaterThanOrEqual !== undefined && contrintegvalGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThanOrEqual', contrintegvalGreaterThanOrEqual);
        }
        if (contrintegvalIn) {
            contrintegvalIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegval.in', element);
            });
        }
        if (contrintegvalLessThan !== undefined && contrintegvalLessThan !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThan', contrintegvalLessThan);
        }
        if (contrintegvalLessThanOrEqual !== undefined && contrintegvalLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThanOrEqual', contrintegvalLessThanOrEqual);
        }
        if (contrintegvalNotEquals !== undefined && contrintegvalNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.notEquals', contrintegvalNotEquals);
        }
        if (contrintegvalSpecified !== undefined && contrintegvalSpecified !== null) {
            queryParameters = queryParameters.set('contrintegval.specified', contrintegvalSpecified);
        }
        if (dataEquals !== undefined && dataEquals !== null) {
            queryParameters = queryParameters.set('data.equals', dataEquals);
        }
        if (dataGreaterThan !== undefined && dataGreaterThan !== null) {
            queryParameters = queryParameters.set('data.greaterThan', dataGreaterThan);
        }
        if (dataGreaterThanOrEqual !== undefined && dataGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('data.greaterThanOrEqual', dataGreaterThanOrEqual);
        }
        if (dataIn0ChronologyCalendarType !== undefined && dataIn0ChronologyCalendarType !== null) {
            queryParameters = queryParameters.set('data.in[0].chronology.calendarType', dataIn0ChronologyCalendarType);
        }
        if (dataIn0ChronologyId !== undefined && dataIn0ChronologyId !== null) {
            queryParameters = queryParameters.set('data.in[0].chronology.id', dataIn0ChronologyId);
        }
        if (dataIn0DayOfMonth !== undefined && dataIn0DayOfMonth !== null) {
            queryParameters = queryParameters.set('data.in[0].dayOfMonth', dataIn0DayOfMonth);
        }
        if (dataIn0DayOfWeek !== undefined && dataIn0DayOfWeek !== null) {
            queryParameters = queryParameters.set('data.in[0].dayOfWeek', dataIn0DayOfWeek);
        }
        if (dataIn0DayOfYear !== undefined && dataIn0DayOfYear !== null) {
            queryParameters = queryParameters.set('data.in[0].dayOfYear', dataIn0DayOfYear);
        }
        if (dataIn0EraValue !== undefined && dataIn0EraValue !== null) {
            queryParameters = queryParameters.set('data.in[0].era.value', dataIn0EraValue);
        }
        if (dataIn0LeapYear !== undefined && dataIn0LeapYear !== null) {
            queryParameters = queryParameters.set('data.in[0].leapYear', dataIn0LeapYear);
        }
        if (dataIn0Month !== undefined && dataIn0Month !== null) {
            queryParameters = queryParameters.set('data.in[0].month', dataIn0Month);
        }
        if (dataIn0MonthValue !== undefined && dataIn0MonthValue !== null) {
            queryParameters = queryParameters.set('data.in[0].monthValue', dataIn0MonthValue);
        }
        if (dataIn0Year !== undefined && dataIn0Year !== null) {
            queryParameters = queryParameters.set('data.in[0].year', dataIn0Year);
        }
        if (dataLessThan !== undefined && dataLessThan !== null) {
            queryParameters = queryParameters.set('data.lessThan', dataLessThan);
        }
        if (dataLessThanOrEqual !== undefined && dataLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('data.lessThanOrEqual', dataLessThanOrEqual);
        }
        if (dataNotEquals !== undefined && dataNotEquals !== null) {
            queryParameters = queryParameters.set('data.notEquals', dataNotEquals);
        }
        if (dataSpecified !== undefined && dataSpecified !== null) {
            queryParameters = queryParameters.set('data.specified', dataSpecified);
        }
        if (datainsEquals !== undefined && datainsEquals !== null) {
            queryParameters = queryParameters.set('datains.equals', datainsEquals.toISOString());
        }
        if (datainsGreaterThan !== undefined && datainsGreaterThan !== null) {
            queryParameters = queryParameters.set('datains.greaterThan', datainsGreaterThan.toISOString());
        }
        if (datainsGreaterThanOrEqual !== undefined && datainsGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('datains.greaterThanOrEqual', datainsGreaterThanOrEqual.toISOString());
        }
        if (datainsIn0DayOfMonth !== undefined && datainsIn0DayOfMonth !== null) {
            queryParameters = queryParameters.set('datains.in[0].dayOfMonth', datainsIn0DayOfMonth);
        }
        if (datainsIn0DayOfWeek !== undefined && datainsIn0DayOfWeek !== null) {
            queryParameters = queryParameters.set('datains.in[0].dayOfWeek', datainsIn0DayOfWeek);
        }
        if (datainsIn0DayOfYear !== undefined && datainsIn0DayOfYear !== null) {
            queryParameters = queryParameters.set('datains.in[0].dayOfYear', datainsIn0DayOfYear);
        }
        if (datainsIn0Hour !== undefined && datainsIn0Hour !== null) {
            queryParameters = queryParameters.set('datains.in[0].hour', datainsIn0Hour);
        }
        if (datainsIn0Minute !== undefined && datainsIn0Minute !== null) {
            queryParameters = queryParameters.set('datains.in[0].minute', datainsIn0Minute);
        }
        if (datainsIn0Month !== undefined && datainsIn0Month !== null) {
            queryParameters = queryParameters.set('datains.in[0].month', datainsIn0Month);
        }
        if (datainsIn0MonthValue !== undefined && datainsIn0MonthValue !== null) {
            queryParameters = queryParameters.set('datains.in[0].monthValue', datainsIn0MonthValue);
        }
        if (datainsIn0Nano !== undefined && datainsIn0Nano !== null) {
            queryParameters = queryParameters.set('datains.in[0].nano', datainsIn0Nano);
        }
        if (datainsIn0OffsetId !== undefined && datainsIn0OffsetId !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.id', datainsIn0OffsetId);
        }
        if (datainsIn0OffsetRulesFixedOffset !== undefined && datainsIn0OffsetRulesFixedOffset !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.fixedOffset', datainsIn0OffsetRulesFixedOffset);
        }
        if (datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator !== undefined && datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].dayOfMonthIndicator', datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator);
        }
        if (datainsIn0OffsetRulesTransitionRules0DayOfWeek !== undefined && datainsIn0OffsetRulesTransitionRules0DayOfWeek !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].dayOfWeek', datainsIn0OffsetRulesTransitionRules0DayOfWeek);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeHour !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeHour !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.hour', datainsIn0OffsetRulesTransitionRules0LocalTimeHour);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeMinute !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeMinute !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.minute', datainsIn0OffsetRulesTransitionRules0LocalTimeMinute);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeNano !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.nano', datainsIn0OffsetRulesTransitionRules0LocalTimeNano);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeSecond !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeSecond !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.second', datainsIn0OffsetRulesTransitionRules0LocalTimeSecond);
        }
        if (datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay !== undefined && datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].midnightEndOfDay', datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay);
        }
        if (datainsIn0OffsetRulesTransitionRules0Month !== undefined && datainsIn0OffsetRulesTransitionRules0Month !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].month', datainsIn0OffsetRulesTransitionRules0Month);
        }
        if (datainsIn0OffsetRulesTransitionRules0TimeDefinition !== undefined && datainsIn0OffsetRulesTransitionRules0TimeDefinition !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].timeDefinition', datainsIn0OffsetRulesTransitionRules0TimeDefinition);
        }
        if (datainsIn0OffsetRulesTransitions0DateTimeAfter !== undefined && datainsIn0OffsetRulesTransitions0DateTimeAfter !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].dateTimeAfter', datainsIn0OffsetRulesTransitions0DateTimeAfter.toISOString());
        }
        if (datainsIn0OffsetRulesTransitions0DateTimeBefore !== undefined && datainsIn0OffsetRulesTransitions0DateTimeBefore !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].dateTimeBefore', datainsIn0OffsetRulesTransitions0DateTimeBefore.toISOString());
        }
        if (datainsIn0OffsetRulesTransitions0DurationNano !== undefined && datainsIn0OffsetRulesTransitions0DurationNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.nano', datainsIn0OffsetRulesTransitions0DurationNano);
        }
        if (datainsIn0OffsetRulesTransitions0DurationNegative !== undefined && datainsIn0OffsetRulesTransitions0DurationNegative !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.negative', datainsIn0OffsetRulesTransitions0DurationNegative);
        }
        if (datainsIn0OffsetRulesTransitions0DurationSeconds !== undefined && datainsIn0OffsetRulesTransitions0DurationSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.seconds', datainsIn0OffsetRulesTransitions0DurationSeconds);
        }
        if (datainsIn0OffsetRulesTransitions0DurationUnits0DateBased !== undefined && datainsIn0OffsetRulesTransitions0DurationUnits0DateBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.units[0].dateBased', datainsIn0OffsetRulesTransitions0DurationUnits0DateBased);
        }
        if (datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated !== undefined && datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.units[0].durationEstimated', datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated);
        }
        if (datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased !== undefined && datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.units[0].timeBased', datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased);
        }
        if (datainsIn0OffsetRulesTransitions0DurationZero !== undefined && datainsIn0OffsetRulesTransitions0DurationZero !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.zero', datainsIn0OffsetRulesTransitions0DurationZero);
        }
        if (datainsIn0OffsetRulesTransitions0Gap !== undefined && datainsIn0OffsetRulesTransitions0Gap !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].gap', datainsIn0OffsetRulesTransitions0Gap);
        }
        if (datainsIn0OffsetRulesTransitions0Instant !== undefined && datainsIn0OffsetRulesTransitions0Instant !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].instant', datainsIn0OffsetRulesTransitions0Instant.toISOString());
        }
        if (datainsIn0OffsetRulesTransitions0Overlap !== undefined && datainsIn0OffsetRulesTransitions0Overlap !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].overlap', datainsIn0OffsetRulesTransitions0Overlap);
        }
        if (datainsIn0OffsetTotalSeconds !== undefined && datainsIn0OffsetTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.totalSeconds', datainsIn0OffsetTotalSeconds);
        }
        if (datainsIn0Second !== undefined && datainsIn0Second !== null) {
            queryParameters = queryParameters.set('datains.in[0].second', datainsIn0Second);
        }
        if (datainsIn0Year !== undefined && datainsIn0Year !== null) {
            queryParameters = queryParameters.set('datains.in[0].year', datainsIn0Year);
        }
        if (datainsIn0ZoneId !== undefined && datainsIn0ZoneId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.id', datainsIn0ZoneId);
        }
        if (datainsIn0ZoneRulesFixedOffset !== undefined && datainsIn0ZoneRulesFixedOffset !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.fixedOffset', datainsIn0ZoneRulesFixedOffset);
        }
        if (datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator !== undefined && datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].dayOfMonthIndicator', datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator);
        }
        if (datainsIn0ZoneRulesTransitionRules0DayOfWeek !== undefined && datainsIn0ZoneRulesTransitionRules0DayOfWeek !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].dayOfWeek', datainsIn0ZoneRulesTransitionRules0DayOfWeek);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeHour !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeHour !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.hour', datainsIn0ZoneRulesTransitionRules0LocalTimeHour);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeMinute !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeMinute !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.minute', datainsIn0ZoneRulesTransitionRules0LocalTimeMinute);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeNano !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.nano', datainsIn0ZoneRulesTransitionRules0LocalTimeNano);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeSecond !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeSecond !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.second', datainsIn0ZoneRulesTransitionRules0LocalTimeSecond);
        }
        if (datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay !== undefined && datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].midnightEndOfDay', datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay);
        }
        if (datainsIn0ZoneRulesTransitionRules0Month !== undefined && datainsIn0ZoneRulesTransitionRules0Month !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].month', datainsIn0ZoneRulesTransitionRules0Month);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetAfterId !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetAfterId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetAfter.id', datainsIn0ZoneRulesTransitionRules0OffsetAfterId);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetAfter.totalSeconds', datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetBeforeId !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetBeforeId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetBefore.id', datainsIn0ZoneRulesTransitionRules0OffsetBeforeId);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetBefore.totalSeconds', datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitionRules0StandardOffsetId !== undefined && datainsIn0ZoneRulesTransitionRules0StandardOffsetId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].standardOffset.id', datainsIn0ZoneRulesTransitionRules0StandardOffsetId);
        }
        if (datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds !== undefined && datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].standardOffset.totalSeconds', datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitionRules0TimeDefinition !== undefined && datainsIn0ZoneRulesTransitionRules0TimeDefinition !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].timeDefinition', datainsIn0ZoneRulesTransitionRules0TimeDefinition);
        }
        if (datainsIn0ZoneRulesTransitions0DateTimeAfter !== undefined && datainsIn0ZoneRulesTransitions0DateTimeAfter !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].dateTimeAfter', datainsIn0ZoneRulesTransitions0DateTimeAfter.toISOString());
        }
        if (datainsIn0ZoneRulesTransitions0DateTimeBefore !== undefined && datainsIn0ZoneRulesTransitions0DateTimeBefore !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].dateTimeBefore', datainsIn0ZoneRulesTransitions0DateTimeBefore.toISOString());
        }
        if (datainsIn0ZoneRulesTransitions0DurationNano !== undefined && datainsIn0ZoneRulesTransitions0DurationNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.nano', datainsIn0ZoneRulesTransitions0DurationNano);
        }
        if (datainsIn0ZoneRulesTransitions0DurationNegative !== undefined && datainsIn0ZoneRulesTransitions0DurationNegative !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.negative', datainsIn0ZoneRulesTransitions0DurationNegative);
        }
        if (datainsIn0ZoneRulesTransitions0DurationSeconds !== undefined && datainsIn0ZoneRulesTransitions0DurationSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.seconds', datainsIn0ZoneRulesTransitions0DurationSeconds);
        }
        if (datainsIn0ZoneRulesTransitions0DurationUnits0DateBased !== undefined && datainsIn0ZoneRulesTransitions0DurationUnits0DateBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.units[0].dateBased', datainsIn0ZoneRulesTransitions0DurationUnits0DateBased);
        }
        if (datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated !== undefined && datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.units[0].durationEstimated', datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated);
        }
        if (datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased !== undefined && datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.units[0].timeBased', datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased);
        }
        if (datainsIn0ZoneRulesTransitions0DurationZero !== undefined && datainsIn0ZoneRulesTransitions0DurationZero !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.zero', datainsIn0ZoneRulesTransitions0DurationZero);
        }
        if (datainsIn0ZoneRulesTransitions0Gap !== undefined && datainsIn0ZoneRulesTransitions0Gap !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].gap', datainsIn0ZoneRulesTransitions0Gap);
        }
        if (datainsIn0ZoneRulesTransitions0Instant !== undefined && datainsIn0ZoneRulesTransitions0Instant !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].instant', datainsIn0ZoneRulesTransitions0Instant.toISOString());
        }
        if (datainsIn0ZoneRulesTransitions0OffsetAfterId !== undefined && datainsIn0ZoneRulesTransitions0OffsetAfterId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetAfter.id', datainsIn0ZoneRulesTransitions0OffsetAfterId);
        }
        if (datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds !== undefined && datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetAfter.totalSeconds', datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitions0OffsetBeforeId !== undefined && datainsIn0ZoneRulesTransitions0OffsetBeforeId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetBefore.id', datainsIn0ZoneRulesTransitions0OffsetBeforeId);
        }
        if (datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds !== undefined && datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetBefore.totalSeconds', datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitions0Overlap !== undefined && datainsIn0ZoneRulesTransitions0Overlap !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].overlap', datainsIn0ZoneRulesTransitions0Overlap);
        }
        if (datainsLessThan !== undefined && datainsLessThan !== null) {
            queryParameters = queryParameters.set('datains.lessThan', datainsLessThan.toISOString());
        }
        if (datainsLessThanOrEqual !== undefined && datainsLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('datains.lessThanOrEqual', datainsLessThanOrEqual.toISOString());
        }
        if (datainsNotEquals !== undefined && datainsNotEquals !== null) {
            queryParameters = queryParameters.set('datains.notEquals', datainsNotEquals.toISOString());
        }
        if (datainsSpecified !== undefined && datainsSpecified !== null) {
            queryParameters = queryParameters.set('datains.specified', datainsSpecified);
        }
        if (dataregistrazioneEquals !== undefined && dataregistrazioneEquals !== null) {
            queryParameters = queryParameters.set('dataregistrazione.equals', dataregistrazioneEquals);
        }
        if (dataregistrazioneGreaterThan !== undefined && dataregistrazioneGreaterThan !== null) {
            queryParameters = queryParameters.set('dataregistrazione.greaterThan', dataregistrazioneGreaterThan);
        }
        if (dataregistrazioneGreaterThanOrEqual !== undefined && dataregistrazioneGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('dataregistrazione.greaterThanOrEqual', dataregistrazioneGreaterThanOrEqual);
        }
        if (dataregistrazioneIn0ChronologyCalendarType !== undefined && dataregistrazioneIn0ChronologyCalendarType !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].chronology.calendarType', dataregistrazioneIn0ChronologyCalendarType);
        }
        if (dataregistrazioneIn0ChronologyId !== undefined && dataregistrazioneIn0ChronologyId !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].chronology.id', dataregistrazioneIn0ChronologyId);
        }
        if (dataregistrazioneIn0DayOfMonth !== undefined && dataregistrazioneIn0DayOfMonth !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].dayOfMonth', dataregistrazioneIn0DayOfMonth);
        }
        if (dataregistrazioneIn0DayOfWeek !== undefined && dataregistrazioneIn0DayOfWeek !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].dayOfWeek', dataregistrazioneIn0DayOfWeek);
        }
        if (dataregistrazioneIn0DayOfYear !== undefined && dataregistrazioneIn0DayOfYear !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].dayOfYear', dataregistrazioneIn0DayOfYear);
        }
        if (dataregistrazioneIn0EraValue !== undefined && dataregistrazioneIn0EraValue !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].era.value', dataregistrazioneIn0EraValue);
        }
        if (dataregistrazioneIn0LeapYear !== undefined && dataregistrazioneIn0LeapYear !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].leapYear', dataregistrazioneIn0LeapYear);
        }
        if (dataregistrazioneIn0Month !== undefined && dataregistrazioneIn0Month !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].month', dataregistrazioneIn0Month);
        }
        if (dataregistrazioneIn0MonthValue !== undefined && dataregistrazioneIn0MonthValue !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].monthValue', dataregistrazioneIn0MonthValue);
        }
        if (dataregistrazioneIn0Year !== undefined && dataregistrazioneIn0Year !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].year', dataregistrazioneIn0Year);
        }
        if (dataregistrazioneLessThan !== undefined && dataregistrazioneLessThan !== null) {
            queryParameters = queryParameters.set('dataregistrazione.lessThan', dataregistrazioneLessThan);
        }
        if (dataregistrazioneLessThanOrEqual !== undefined && dataregistrazioneLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('dataregistrazione.lessThanOrEqual', dataregistrazioneLessThanOrEqual);
        }
        if (dataregistrazioneNotEquals !== undefined && dataregistrazioneNotEquals !== null) {
            queryParameters = queryParameters.set('dataregistrazione.notEquals', dataregistrazioneNotEquals);
        }
        if (dataregistrazioneSpecified !== undefined && dataregistrazioneSpecified !== null) {
            queryParameters = queryParameters.set('dataregistrazione.specified', dataregistrazioneSpecified);
        }
        if (fornitoreEquals !== undefined && fornitoreEquals !== null) {
            queryParameters = queryParameters.set('fornitore.equals', fornitoreEquals);
        }
        if (fornitoreIn) {
            fornitoreIn.forEach(function (element) {
                queryParameters = queryParameters.append('fornitore.in', element);
            });
        }
        if (fornitoreNotEquals !== undefined && fornitoreNotEquals !== null) {
            queryParameters = queryParameters.set('fornitore.notEquals', fornitoreNotEquals);
        }
        if (fornitoreSpecified !== undefined && fornitoreSpecified !== null) {
            queryParameters = queryParameters.set('fornitore.specified', fornitoreSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (idanagraficaEquals !== undefined && idanagraficaEquals !== null) {
            queryParameters = queryParameters.set('idanagrafica.equals', idanagraficaEquals);
        }
        if (idanagraficaGreaterThan !== undefined && idanagraficaGreaterThan !== null) {
            queryParameters = queryParameters.set('idanagrafica.greaterThan', idanagraficaGreaterThan);
        }
        if (idanagraficaGreaterThanOrEqual !== undefined && idanagraficaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('idanagrafica.greaterThanOrEqual', idanagraficaGreaterThanOrEqual);
        }
        if (idanagraficaIn) {
            idanagraficaIn.forEach(function (element) {
                queryParameters = queryParameters.append('idanagrafica.in', element);
            });
        }
        if (idanagraficaLessThan !== undefined && idanagraficaLessThan !== null) {
            queryParameters = queryParameters.set('idanagrafica.lessThan', idanagraficaLessThan);
        }
        if (idanagraficaLessThanOrEqual !== undefined && idanagraficaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('idanagrafica.lessThanOrEqual', idanagraficaLessThanOrEqual);
        }
        if (idanagraficaNotEquals !== undefined && idanagraficaNotEquals !== null) {
            queryParameters = queryParameters.set('idanagrafica.notEquals', idanagraficaNotEquals);
        }
        if (idanagraficaSpecified !== undefined && idanagraficaSpecified !== null) {
            queryParameters = queryParameters.set('idanagrafica.specified', idanagraficaSpecified);
        }
        if (idaziendaEquals !== undefined && idaziendaEquals !== null) {
            queryParameters = queryParameters.set('idazienda.equals', idaziendaEquals);
        }
        if (idaziendaGreaterThan !== undefined && idaziendaGreaterThan !== null) {
            queryParameters = queryParameters.set('idazienda.greaterThan', idaziendaGreaterThan);
        }
        if (idaziendaGreaterThanOrEqual !== undefined && idaziendaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('idazienda.greaterThanOrEqual', idaziendaGreaterThanOrEqual);
        }
        if (idaziendaIn) {
            idaziendaIn.forEach(function (element) {
                queryParameters = queryParameters.append('idazienda.in', element);
            });
        }
        if (idaziendaLessThan !== undefined && idaziendaLessThan !== null) {
            queryParameters = queryParameters.set('idazienda.lessThan', idaziendaLessThan);
        }
        if (idaziendaLessThanOrEqual !== undefined && idaziendaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('idazienda.lessThanOrEqual', idaziendaLessThanOrEqual);
        }
        if (idaziendaNotEquals !== undefined && idaziendaNotEquals !== null) {
            queryParameters = queryParameters.set('idazienda.notEquals', idaziendaNotEquals);
        }
        if (idaziendaSpecified !== undefined && idaziendaSpecified !== null) {
            queryParameters = queryParameters.set('idazienda.specified', idaziendaSpecified);
        }
        if (iddocumentoContains !== undefined && iddocumentoContains !== null) {
            queryParameters = queryParameters.set('iddocumento.contains', iddocumentoContains);
        }
        if (iddocumentoDoesNotContain !== undefined && iddocumentoDoesNotContain !== null) {
            queryParameters = queryParameters.set('iddocumento.doesNotContain', iddocumentoDoesNotContain);
        }
        if (iddocumentoEquals !== undefined && iddocumentoEquals !== null) {
            queryParameters = queryParameters.set('iddocumento.equals', iddocumentoEquals);
        }
        if (iddocumentoIn) {
            iddocumentoIn.forEach(function (element) {
                queryParameters = queryParameters.append('iddocumento.in', element);
            });
        }
        if (iddocumentoNotEquals !== undefined && iddocumentoNotEquals !== null) {
            queryParameters = queryParameters.set('iddocumento.notEquals', iddocumentoNotEquals);
        }
        if (iddocumentoSpecified !== undefined && iddocumentoSpecified !== null) {
            queryParameters = queryParameters.set('iddocumento.specified', iddocumentoSpecified);
        }
        if (idsottocontoContains !== undefined && idsottocontoContains !== null) {
            queryParameters = queryParameters.set('idsottoconto.contains', idsottocontoContains);
        }
        if (idsottocontoDoesNotContain !== undefined && idsottocontoDoesNotContain !== null) {
            queryParameters = queryParameters.set('idsottoconto.doesNotContain', idsottocontoDoesNotContain);
        }
        if (idsottocontoEquals !== undefined && idsottocontoEquals !== null) {
            queryParameters = queryParameters.set('idsottoconto.equals', idsottocontoEquals);
        }
        if (idsottocontoIn) {
            idsottocontoIn.forEach(function (element) {
                queryParameters = queryParameters.append('idsottoconto.in', element);
            });
        }
        if (idsottocontoNotEquals !== undefined && idsottocontoNotEquals !== null) {
            queryParameters = queryParameters.set('idsottoconto.notEquals', idsottocontoNotEquals);
        }
        if (idsottocontoSpecified !== undefined && idsottocontoSpecified !== null) {
            queryParameters = queryParameters.set('idsottoconto.specified', idsottocontoSpecified);
        }
        if (indirizzoContains !== undefined && indirizzoContains !== null) {
            queryParameters = queryParameters.set('indirizzo.contains', indirizzoContains);
        }
        if (indirizzoDoesNotContain !== undefined && indirizzoDoesNotContain !== null) {
            queryParameters = queryParameters.set('indirizzo.doesNotContain', indirizzoDoesNotContain);
        }
        if (indirizzoEquals !== undefined && indirizzoEquals !== null) {
            queryParameters = queryParameters.set('indirizzo.equals', indirizzoEquals);
        }
        if (indirizzoIn) {
            indirizzoIn.forEach(function (element) {
                queryParameters = queryParameters.append('indirizzo.in', element);
            });
        }
        if (indirizzoNotEquals !== undefined && indirizzoNotEquals !== null) {
            queryParameters = queryParameters.set('indirizzo.notEquals', indirizzoNotEquals);
        }
        if (indirizzoSpecified !== undefined && indirizzoSpecified !== null) {
            queryParameters = queryParameters.set('indirizzo.specified', indirizzoSpecified);
        }
        if (intestazioneContains !== undefined && intestazioneContains !== null) {
            queryParameters = queryParameters.set('intestazione.contains', intestazioneContains);
        }
        if (intestazioneDoesNotContain !== undefined && intestazioneDoesNotContain !== null) {
            queryParameters = queryParameters.set('intestazione.doesNotContain', intestazioneDoesNotContain);
        }
        if (intestazioneEquals !== undefined && intestazioneEquals !== null) {
            queryParameters = queryParameters.set('intestazione.equals', intestazioneEquals);
        }
        if (intestazioneIn) {
            intestazioneIn.forEach(function (element) {
                queryParameters = queryParameters.append('intestazione.in', element);
            });
        }
        if (intestazioneNotEquals !== undefined && intestazioneNotEquals !== null) {
            queryParameters = queryParameters.set('intestazione.notEquals', intestazioneNotEquals);
        }
        if (intestazioneSpecified !== undefined && intestazioneSpecified !== null) {
            queryParameters = queryParameters.set('intestazione.specified', intestazioneSpecified);
        }
        if (ivaEquals !== undefined && ivaEquals !== null) {
            queryParameters = queryParameters.set('iva.equals', ivaEquals);
        }
        if (ivaGreaterThan !== undefined && ivaGreaterThan !== null) {
            queryParameters = queryParameters.set('iva.greaterThan', ivaGreaterThan);
        }
        if (ivaGreaterThanOrEqual !== undefined && ivaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.greaterThanOrEqual', ivaGreaterThanOrEqual);
        }
        if (ivaIn) {
            ivaIn.forEach(function (element) {
                queryParameters = queryParameters.append('iva.in', element);
            });
        }
        if (ivaLessThan !== undefined && ivaLessThan !== null) {
            queryParameters = queryParameters.set('iva.lessThan', ivaLessThan);
        }
        if (ivaLessThanOrEqual !== undefined && ivaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.lessThanOrEqual', ivaLessThanOrEqual);
        }
        if (ivaNotEquals !== undefined && ivaNotEquals !== null) {
            queryParameters = queryParameters.set('iva.notEquals', ivaNotEquals);
        }
        if (ivaSpecified !== undefined && ivaSpecified !== null) {
            queryParameters = queryParameters.set('iva.specified', ivaSpecified);
        }
        if (ivasinoEquals !== undefined && ivasinoEquals !== null) {
            queryParameters = queryParameters.set('ivasino.equals', ivasinoEquals);
        }
        if (ivasinoIn) {
            ivasinoIn.forEach(function (element) {
                queryParameters = queryParameters.append('ivasino.in', element);
            });
        }
        if (ivasinoNotEquals !== undefined && ivasinoNotEquals !== null) {
            queryParameters = queryParameters.set('ivasino.notEquals', ivasinoNotEquals);
        }
        if (ivasinoSpecified !== undefined && ivasinoSpecified !== null) {
            queryParameters = queryParameters.set('ivasino.specified', ivasinoSpecified);
        }
        if (mdopagEquals !== undefined && mdopagEquals !== null) {
            queryParameters = queryParameters.set('mdopag.equals', mdopagEquals);
        }
        if (mdopagGreaterThan !== undefined && mdopagGreaterThan !== null) {
            queryParameters = queryParameters.set('mdopag.greaterThan', mdopagGreaterThan);
        }
        if (mdopagGreaterThanOrEqual !== undefined && mdopagGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('mdopag.greaterThanOrEqual', mdopagGreaterThanOrEqual);
        }
        if (mdopagIn) {
            mdopagIn.forEach(function (element) {
                queryParameters = queryParameters.append('mdopag.in', element);
            });
        }
        if (mdopagLessThan !== undefined && mdopagLessThan !== null) {
            queryParameters = queryParameters.set('mdopag.lessThan', mdopagLessThan);
        }
        if (mdopagLessThanOrEqual !== undefined && mdopagLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('mdopag.lessThanOrEqual', mdopagLessThanOrEqual);
        }
        if (mdopagNotEquals !== undefined && mdopagNotEquals !== null) {
            queryParameters = queryParameters.set('mdopag.notEquals', mdopagNotEquals);
        }
        if (mdopagSpecified !== undefined && mdopagSpecified !== null) {
            queryParameters = queryParameters.set('mdopag.specified', mdopagSpecified);
        }
        if (ndocContains !== undefined && ndocContains !== null) {
            queryParameters = queryParameters.set('ndoc.contains', ndocContains);
        }
        if (ndocDoesNotContain !== undefined && ndocDoesNotContain !== null) {
            queryParameters = queryParameters.set('ndoc.doesNotContain', ndocDoesNotContain);
        }
        if (ndocEquals !== undefined && ndocEquals !== null) {
            queryParameters = queryParameters.set('ndoc.equals', ndocEquals);
        }
        if (ndocIn) {
            ndocIn.forEach(function (element) {
                queryParameters = queryParameters.append('ndoc.in', element);
            });
        }
        if (ndocNotEquals !== undefined && ndocNotEquals !== null) {
            queryParameters = queryParameters.set('ndoc.notEquals', ndocNotEquals);
        }
        if (ndocSpecified !== undefined && ndocSpecified !== null) {
            queryParameters = queryParameters.set('ndoc.specified', ndocSpecified);
        }
        if (ndocSuffEquals !== undefined && ndocSuffEquals !== null) {
            queryParameters = queryParameters.set('ndocSuff.equals', ndocSuffEquals);
        }
        if (ndocSuffGreaterThan !== undefined && ndocSuffGreaterThan !== null) {
            queryParameters = queryParameters.set('ndocSuff.greaterThan', ndocSuffGreaterThan);
        }
        if (ndocSuffGreaterThanOrEqual !== undefined && ndocSuffGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('ndocSuff.greaterThanOrEqual', ndocSuffGreaterThanOrEqual);
        }
        if (ndocSuffIn) {
            ndocSuffIn.forEach(function (element) {
                queryParameters = queryParameters.append('ndocSuff.in', element);
            });
        }
        if (ndocSuffLessThan !== undefined && ndocSuffLessThan !== null) {
            queryParameters = queryParameters.set('ndocSuff.lessThan', ndocSuffLessThan);
        }
        if (ndocSuffLessThanOrEqual !== undefined && ndocSuffLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('ndocSuff.lessThanOrEqual', ndocSuffLessThanOrEqual);
        }
        if (ndocSuffNotEquals !== undefined && ndocSuffNotEquals !== null) {
            queryParameters = queryParameters.set('ndocSuff.notEquals', ndocSuffNotEquals);
        }
        if (ndocSuffSpecified !== undefined && ndocSuffSpecified !== null) {
            queryParameters = queryParameters.set('ndocSuff.specified', ndocSuffSpecified);
        }
        if (noteContains !== undefined && noteContains !== null) {
            queryParameters = queryParameters.set('note.contains', noteContains);
        }
        if (noteDoesNotContain !== undefined && noteDoesNotContain !== null) {
            queryParameters = queryParameters.set('note.doesNotContain', noteDoesNotContain);
        }
        if (noteEquals !== undefined && noteEquals !== null) {
            queryParameters = queryParameters.set('note.equals', noteEquals);
        }
        if (noteIn) {
            noteIn.forEach(function (element) {
                queryParameters = queryParameters.append('note.in', element);
            });
        }
        if (noteNotEquals !== undefined && noteNotEquals !== null) {
            queryParameters = queryParameters.set('note.notEquals', noteNotEquals);
        }
        if (noteSpecified !== undefined && noteSpecified !== null) {
            queryParameters = queryParameters.set('note.specified', noteSpecified);
        }
        if (opeinsContains !== undefined && opeinsContains !== null) {
            queryParameters = queryParameters.set('opeins.contains', opeinsContains);
        }
        if (opeinsDoesNotContain !== undefined && opeinsDoesNotContain !== null) {
            queryParameters = queryParameters.set('opeins.doesNotContain', opeinsDoesNotContain);
        }
        if (opeinsEquals !== undefined && opeinsEquals !== null) {
            queryParameters = queryParameters.set('opeins.equals', opeinsEquals);
        }
        if (opeinsIn) {
            opeinsIn.forEach(function (element) {
                queryParameters = queryParameters.append('opeins.in', element);
            });
        }
        if (opeinsNotEquals !== undefined && opeinsNotEquals !== null) {
            queryParameters = queryParameters.set('opeins.notEquals', opeinsNotEquals);
        }
        if (opeinsSpecified !== undefined && opeinsSpecified !== null) {
            queryParameters = queryParameters.set('opeins.specified', opeinsSpecified);
        }
        if (pecContains !== undefined && pecContains !== null) {
            queryParameters = queryParameters.set('pec.contains', pecContains);
        }
        if (pecDoesNotContain !== undefined && pecDoesNotContain !== null) {
            queryParameters = queryParameters.set('pec.doesNotContain', pecDoesNotContain);
        }
        if (pecEquals !== undefined && pecEquals !== null) {
            queryParameters = queryParameters.set('pec.equals', pecEquals);
        }
        if (pecIn) {
            pecIn.forEach(function (element) {
                queryParameters = queryParameters.append('pec.in', element);
            });
        }
        if (pecNotEquals !== undefined && pecNotEquals !== null) {
            queryParameters = queryParameters.set('pec.notEquals', pecNotEquals);
        }
        if (pecSpecified !== undefined && pecSpecified !== null) {
            queryParameters = queryParameters.set('pec.specified', pecSpecified);
        }
        if (percentIvaEquals !== undefined && percentIvaEquals !== null) {
            queryParameters = queryParameters.set('percentIva.equals', percentIvaEquals);
        }
        if (percentIvaGreaterThan !== undefined && percentIvaGreaterThan !== null) {
            queryParameters = queryParameters.set('percentIva.greaterThan', percentIvaGreaterThan);
        }
        if (percentIvaGreaterThanOrEqual !== undefined && percentIvaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('percentIva.greaterThanOrEqual', percentIvaGreaterThanOrEqual);
        }
        if (percentIvaIn) {
            percentIvaIn.forEach(function (element) {
                queryParameters = queryParameters.append('percentIva.in', element);
            });
        }
        if (percentIvaLessThan !== undefined && percentIvaLessThan !== null) {
            queryParameters = queryParameters.set('percentIva.lessThan', percentIvaLessThan);
        }
        if (percentIvaLessThanOrEqual !== undefined && percentIvaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('percentIva.lessThanOrEqual', percentIvaLessThanOrEqual);
        }
        if (percentIvaNotEquals !== undefined && percentIvaNotEquals !== null) {
            queryParameters = queryParameters.set('percentIva.notEquals', percentIvaNotEquals);
        }
        if (percentIvaSpecified !== undefined && percentIvaSpecified !== null) {
            queryParameters = queryParameters.set('percentIva.specified', percentIvaSpecified);
        }
        if (percritenutaEquals !== undefined && percritenutaEquals !== null) {
            queryParameters = queryParameters.set('percritenuta.equals', percritenutaEquals);
        }
        if (percritenutaGreaterThan !== undefined && percritenutaGreaterThan !== null) {
            queryParameters = queryParameters.set('percritenuta.greaterThan', percritenutaGreaterThan);
        }
        if (percritenutaGreaterThanOrEqual !== undefined && percritenutaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('percritenuta.greaterThanOrEqual', percritenutaGreaterThanOrEqual);
        }
        if (percritenutaIn) {
            percritenutaIn.forEach(function (element) {
                queryParameters = queryParameters.append('percritenuta.in', element);
            });
        }
        if (percritenutaLessThan !== undefined && percritenutaLessThan !== null) {
            queryParameters = queryParameters.set('percritenuta.lessThan', percritenutaLessThan);
        }
        if (percritenutaLessThanOrEqual !== undefined && percritenutaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('percritenuta.lessThanOrEqual', percritenutaLessThanOrEqual);
        }
        if (percritenutaNotEquals !== undefined && percritenutaNotEquals !== null) {
            queryParameters = queryParameters.set('percritenuta.notEquals', percritenutaNotEquals);
        }
        if (percritenutaSpecified !== undefined && percritenutaSpecified !== null) {
            queryParameters = queryParameters.set('percritenuta.specified', percritenutaSpecified);
        }
        if (pivaContains !== undefined && pivaContains !== null) {
            queryParameters = queryParameters.set('piva.contains', pivaContains);
        }
        if (pivaDoesNotContain !== undefined && pivaDoesNotContain !== null) {
            queryParameters = queryParameters.set('piva.doesNotContain', pivaDoesNotContain);
        }
        if (pivaEquals !== undefined && pivaEquals !== null) {
            queryParameters = queryParameters.set('piva.equals', pivaEquals);
        }
        if (pivaIn) {
            pivaIn.forEach(function (element) {
                queryParameters = queryParameters.append('piva.in', element);
            });
        }
        if (pivaNotEquals !== undefined && pivaNotEquals !== null) {
            queryParameters = queryParameters.set('piva.notEquals', pivaNotEquals);
        }
        if (pivaSpecified !== undefined && pivaSpecified !== null) {
            queryParameters = queryParameters.set('piva.specified', pivaSpecified);
        }
        if (protSuffEquals !== undefined && protSuffEquals !== null) {
            queryParameters = queryParameters.set('protSuff.equals', protSuffEquals);
        }
        if (protSuffGreaterThan !== undefined && protSuffGreaterThan !== null) {
            queryParameters = queryParameters.set('protSuff.greaterThan', protSuffGreaterThan);
        }
        if (protSuffGreaterThanOrEqual !== undefined && protSuffGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('protSuff.greaterThanOrEqual', protSuffGreaterThanOrEqual);
        }
        if (protSuffIn) {
            protSuffIn.forEach(function (element) {
                queryParameters = queryParameters.append('protSuff.in', element);
            });
        }
        if (protSuffLessThan !== undefined && protSuffLessThan !== null) {
            queryParameters = queryParameters.set('protSuff.lessThan', protSuffLessThan);
        }
        if (protSuffLessThanOrEqual !== undefined && protSuffLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('protSuff.lessThanOrEqual', protSuffLessThanOrEqual);
        }
        if (protSuffNotEquals !== undefined && protSuffNotEquals !== null) {
            queryParameters = queryParameters.set('protSuff.notEquals', protSuffNotEquals);
        }
        if (protSuffSpecified !== undefined && protSuffSpecified !== null) {
            queryParameters = queryParameters.set('protSuff.specified', protSuffSpecified);
        }
        if (protocolloEquals !== undefined && protocolloEquals !== null) {
            queryParameters = queryParameters.set('protocollo.equals', protocolloEquals);
        }
        if (protocolloGreaterThan !== undefined && protocolloGreaterThan !== null) {
            queryParameters = queryParameters.set('protocollo.greaterThan', protocolloGreaterThan);
        }
        if (protocolloGreaterThanOrEqual !== undefined && protocolloGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('protocollo.greaterThanOrEqual', protocolloGreaterThanOrEqual);
        }
        if (protocolloIn) {
            protocolloIn.forEach(function (element) {
                queryParameters = queryParameters.append('protocollo.in', element);
            });
        }
        if (protocolloLessThan !== undefined && protocolloLessThan !== null) {
            queryParameters = queryParameters.set('protocollo.lessThan', protocolloLessThan);
        }
        if (protocolloLessThanOrEqual !== undefined && protocolloLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('protocollo.lessThanOrEqual', protocolloLessThanOrEqual);
        }
        if (protocolloNotEquals !== undefined && protocolloNotEquals !== null) {
            queryParameters = queryParameters.set('protocollo.notEquals', protocolloNotEquals);
        }
        if (protocolloSpecified !== undefined && protocolloSpecified !== null) {
            queryParameters = queryParameters.set('protocollo.specified', protocolloSpecified);
        }
        if (provContains !== undefined && provContains !== null) {
            queryParameters = queryParameters.set('prov.contains', provContains);
        }
        if (provDoesNotContain !== undefined && provDoesNotContain !== null) {
            queryParameters = queryParameters.set('prov.doesNotContain', provDoesNotContain);
        }
        if (provEquals !== undefined && provEquals !== null) {
            queryParameters = queryParameters.set('prov.equals', provEquals);
        }
        if (provIn) {
            provIn.forEach(function (element) {
                queryParameters = queryParameters.append('prov.in', element);
            });
        }
        if (provNotEquals !== undefined && provNotEquals !== null) {
            queryParameters = queryParameters.set('prov.notEquals', provNotEquals);
        }
        if (provSpecified !== undefined && provSpecified !== null) {
            queryParameters = queryParameters.set('prov.specified', provSpecified);
        }
        if (ritenutaEquals !== undefined && ritenutaEquals !== null) {
            queryParameters = queryParameters.set('ritenuta.equals', ritenutaEquals);
        }
        if (ritenutaGreaterThan !== undefined && ritenutaGreaterThan !== null) {
            queryParameters = queryParameters.set('ritenuta.greaterThan', ritenutaGreaterThan);
        }
        if (ritenutaGreaterThanOrEqual !== undefined && ritenutaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('ritenuta.greaterThanOrEqual', ritenutaGreaterThanOrEqual);
        }
        if (ritenutaIn) {
            ritenutaIn.forEach(function (element) {
                queryParameters = queryParameters.append('ritenuta.in', element);
            });
        }
        if (ritenutaLessThan !== undefined && ritenutaLessThan !== null) {
            queryParameters = queryParameters.set('ritenuta.lessThan', ritenutaLessThan);
        }
        if (ritenutaLessThanOrEqual !== undefined && ritenutaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('ritenuta.lessThanOrEqual', ritenutaLessThanOrEqual);
        }
        if (ritenutaNotEquals !== undefined && ritenutaNotEquals !== null) {
            queryParameters = queryParameters.set('ritenuta.notEquals', ritenutaNotEquals);
        }
        if (ritenutaSpecified !== undefined && ritenutaSpecified !== null) {
            queryParameters = queryParameters.set('ritenuta.specified', ritenutaSpecified);
        }
        if (tipoContains !== undefined && tipoContains !== null) {
            queryParameters = queryParameters.set('tipo.contains', tipoContains);
        }
        if (tipoDoesNotContain !== undefined && tipoDoesNotContain !== null) {
            queryParameters = queryParameters.set('tipo.doesNotContain', tipoDoesNotContain);
        }
        if (tipoEquals !== undefined && tipoEquals !== null) {
            queryParameters = queryParameters.set('tipo.equals', tipoEquals);
        }
        if (tipoIn) {
            tipoIn.forEach(function (element) {
                queryParameters = queryParameters.append('tipo.in', element);
            });
        }
        if (tipoNotEquals !== undefined && tipoNotEquals !== null) {
            queryParameters = queryParameters.set('tipo.notEquals', tipoNotEquals);
        }
        if (tipoSpecified !== undefined && tipoSpecified !== null) {
            queryParameters = queryParameters.set('tipo.specified', tipoSpecified);
        }
        if (totaleEquals !== undefined && totaleEquals !== null) {
            queryParameters = queryParameters.set('totale.equals', totaleEquals);
        }
        if (totaleGreaterThan !== undefined && totaleGreaterThan !== null) {
            queryParameters = queryParameters.set('totale.greaterThan', totaleGreaterThan);
        }
        if (totaleGreaterThanOrEqual !== undefined && totaleGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('totale.greaterThanOrEqual', totaleGreaterThanOrEqual);
        }
        if (totaleIn) {
            totaleIn.forEach(function (element) {
                queryParameters = queryParameters.append('totale.in', element);
            });
        }
        if (totaleLessThan !== undefined && totaleLessThan !== null) {
            queryParameters = queryParameters.set('totale.lessThan', totaleLessThan);
        }
        if (totaleLessThanOrEqual !== undefined && totaleLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('totale.lessThanOrEqual', totaleLessThanOrEqual);
        }
        if (totaleNotEquals !== undefined && totaleNotEquals !== null) {
            queryParameters = queryParameters.set('totale.notEquals', totaleNotEquals);
        }
        if (totaleSpecified !== undefined && totaleSpecified !== null) {
            queryParameters = queryParameters.set('totale.specified', totaleSpecified);
        }
        if (totimponibileEquals !== undefined && totimponibileEquals !== null) {
            queryParameters = queryParameters.set('totimponibile.equals', totimponibileEquals);
        }
        if (totimponibileGreaterThan !== undefined && totimponibileGreaterThan !== null) {
            queryParameters = queryParameters.set('totimponibile.greaterThan', totimponibileGreaterThan);
        }
        if (totimponibileGreaterThanOrEqual !== undefined && totimponibileGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('totimponibile.greaterThanOrEqual', totimponibileGreaterThanOrEqual);
        }
        if (totimponibileIn) {
            totimponibileIn.forEach(function (element) {
                queryParameters = queryParameters.append('totimponibile.in', element);
            });
        }
        if (totimponibileLessThan !== undefined && totimponibileLessThan !== null) {
            queryParameters = queryParameters.set('totimponibile.lessThan', totimponibileLessThan);
        }
        if (totimponibileLessThanOrEqual !== undefined && totimponibileLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('totimponibile.lessThanOrEqual', totimponibileLessThanOrEqual);
        }
        if (totimponibileNotEquals !== undefined && totimponibileNotEquals !== null) {
            queryParameters = queryParameters.set('totimponibile.notEquals', totimponibileNotEquals);
        }
        if (totimponibileSpecified !== undefined && totimponibileSpecified !== null) {
            queryParameters = queryParameters.set('totimponibile.specified', totimponibileSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/apollo-documents/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentResourceService.prototype.createApolloDocumentUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createApolloDocumentUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/apollo-documents", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentResourceService.prototype.deleteApolloDocumentUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteApolloDocumentUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/apollo-documents/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentResourceService.prototype.getAllApolloDocumentsUsingGET = function (capContains, capDoesNotContain, capEquals, capIn, capNotEquals, capSpecified, cittContains, cittDoesNotContain, cittEquals, cittIn, cittNotEquals, cittSpecified, clienteEquals, clienteIn, clienteNotEquals, clienteSpecified, codfiscContains, codfiscDoesNotContain, codfiscEquals, codfiscIn, codfiscNotEquals, codfiscSpecified, codiceInvioContains, codiceInvioDoesNotContain, codiceInvioEquals, codiceInvioIn, codiceInvioNotEquals, codiceInvioSpecified, contoEquals, contoGreaterThan, contoGreaterThanOrEqual, contoIn, contoLessThan, contoLessThanOrEqual, contoNotEquals, contoSpecified, contrintegpercEquals, contrintegpercGreaterThan, contrintegpercGreaterThanOrEqual, contrintegpercIn, contrintegpercLessThan, contrintegpercLessThanOrEqual, contrintegpercNotEquals, contrintegpercSpecified, contrintegvalEquals, contrintegvalGreaterThan, contrintegvalGreaterThanOrEqual, contrintegvalIn, contrintegvalLessThan, contrintegvalLessThanOrEqual, contrintegvalNotEquals, contrintegvalSpecified, dataEquals, dataGreaterThan, dataGreaterThanOrEqual, dataIn0ChronologyCalendarType, dataIn0ChronologyId, dataIn0DayOfMonth, dataIn0DayOfWeek, dataIn0DayOfYear, dataIn0EraValue, dataIn0LeapYear, dataIn0Month, dataIn0MonthValue, dataIn0Year, dataLessThan, dataLessThanOrEqual, dataNotEquals, dataSpecified, datainsEquals, datainsGreaterThan, datainsGreaterThanOrEqual, datainsIn0DayOfMonth, datainsIn0DayOfWeek, datainsIn0DayOfYear, datainsIn0Hour, datainsIn0Minute, datainsIn0Month, datainsIn0MonthValue, datainsIn0Nano, datainsIn0OffsetId, datainsIn0OffsetRulesFixedOffset, datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator, datainsIn0OffsetRulesTransitionRules0DayOfWeek, datainsIn0OffsetRulesTransitionRules0LocalTimeHour, datainsIn0OffsetRulesTransitionRules0LocalTimeMinute, datainsIn0OffsetRulesTransitionRules0LocalTimeNano, datainsIn0OffsetRulesTransitionRules0LocalTimeSecond, datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay, datainsIn0OffsetRulesTransitionRules0Month, datainsIn0OffsetRulesTransitionRules0TimeDefinition, datainsIn0OffsetRulesTransitions0DateTimeAfter, datainsIn0OffsetRulesTransitions0DateTimeBefore, datainsIn0OffsetRulesTransitions0DurationNano, datainsIn0OffsetRulesTransitions0DurationNegative, datainsIn0OffsetRulesTransitions0DurationSeconds, datainsIn0OffsetRulesTransitions0DurationUnits0DateBased, datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated, datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased, datainsIn0OffsetRulesTransitions0DurationZero, datainsIn0OffsetRulesTransitions0Gap, datainsIn0OffsetRulesTransitions0Instant, datainsIn0OffsetRulesTransitions0Overlap, datainsIn0OffsetTotalSeconds, datainsIn0Second, datainsIn0Year, datainsIn0ZoneId, datainsIn0ZoneRulesFixedOffset, datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator, datainsIn0ZoneRulesTransitionRules0DayOfWeek, datainsIn0ZoneRulesTransitionRules0LocalTimeHour, datainsIn0ZoneRulesTransitionRules0LocalTimeMinute, datainsIn0ZoneRulesTransitionRules0LocalTimeNano, datainsIn0ZoneRulesTransitionRules0LocalTimeSecond, datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay, datainsIn0ZoneRulesTransitionRules0Month, datainsIn0ZoneRulesTransitionRules0OffsetAfterId, datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds, datainsIn0ZoneRulesTransitionRules0OffsetBeforeId, datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds, datainsIn0ZoneRulesTransitionRules0StandardOffsetId, datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds, datainsIn0ZoneRulesTransitionRules0TimeDefinition, datainsIn0ZoneRulesTransitions0DateTimeAfter, datainsIn0ZoneRulesTransitions0DateTimeBefore, datainsIn0ZoneRulesTransitions0DurationNano, datainsIn0ZoneRulesTransitions0DurationNegative, datainsIn0ZoneRulesTransitions0DurationSeconds, datainsIn0ZoneRulesTransitions0DurationUnits0DateBased, datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated, datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased, datainsIn0ZoneRulesTransitions0DurationZero, datainsIn0ZoneRulesTransitions0Gap, datainsIn0ZoneRulesTransitions0Instant, datainsIn0ZoneRulesTransitions0OffsetAfterId, datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds, datainsIn0ZoneRulesTransitions0OffsetBeforeId, datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds, datainsIn0ZoneRulesTransitions0Overlap, datainsLessThan, datainsLessThanOrEqual, datainsNotEquals, datainsSpecified, dataregistrazioneEquals, dataregistrazioneGreaterThan, dataregistrazioneGreaterThanOrEqual, dataregistrazioneIn0ChronologyCalendarType, dataregistrazioneIn0ChronologyId, dataregistrazioneIn0DayOfMonth, dataregistrazioneIn0DayOfWeek, dataregistrazioneIn0DayOfYear, dataregistrazioneIn0EraValue, dataregistrazioneIn0LeapYear, dataregistrazioneIn0Month, dataregistrazioneIn0MonthValue, dataregistrazioneIn0Year, dataregistrazioneLessThan, dataregistrazioneLessThanOrEqual, dataregistrazioneNotEquals, dataregistrazioneSpecified, fornitoreEquals, fornitoreIn, fornitoreNotEquals, fornitoreSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, idanagraficaEquals, idanagraficaGreaterThan, idanagraficaGreaterThanOrEqual, idanagraficaIn, idanagraficaLessThan, idanagraficaLessThanOrEqual, idanagraficaNotEquals, idanagraficaSpecified, idaziendaEquals, idaziendaGreaterThan, idaziendaGreaterThanOrEqual, idaziendaIn, idaziendaLessThan, idaziendaLessThanOrEqual, idaziendaNotEquals, idaziendaSpecified, iddocumentoContains, iddocumentoDoesNotContain, iddocumentoEquals, iddocumentoIn, iddocumentoNotEquals, iddocumentoSpecified, idsottocontoContains, idsottocontoDoesNotContain, idsottocontoEquals, idsottocontoIn, idsottocontoNotEquals, idsottocontoSpecified, indirizzoContains, indirizzoDoesNotContain, indirizzoEquals, indirizzoIn, indirizzoNotEquals, indirizzoSpecified, intestazioneContains, intestazioneDoesNotContain, intestazioneEquals, intestazioneIn, intestazioneNotEquals, intestazioneSpecified, ivaEquals, ivaGreaterThan, ivaGreaterThanOrEqual, ivaIn, ivaLessThan, ivaLessThanOrEqual, ivaNotEquals, ivaSpecified, ivasinoEquals, ivasinoIn, ivasinoNotEquals, ivasinoSpecified, mdopagEquals, mdopagGreaterThan, mdopagGreaterThanOrEqual, mdopagIn, mdopagLessThan, mdopagLessThanOrEqual, mdopagNotEquals, mdopagSpecified, ndocContains, ndocDoesNotContain, ndocEquals, ndocIn, ndocNotEquals, ndocSpecified, ndocSuffEquals, ndocSuffGreaterThan, ndocSuffGreaterThanOrEqual, ndocSuffIn, ndocSuffLessThan, ndocSuffLessThanOrEqual, ndocSuffNotEquals, ndocSuffSpecified, noteContains, noteDoesNotContain, noteEquals, noteIn, noteNotEquals, noteSpecified, opeinsContains, opeinsDoesNotContain, opeinsEquals, opeinsIn, opeinsNotEquals, opeinsSpecified, page, pecContains, pecDoesNotContain, pecEquals, pecIn, pecNotEquals, pecSpecified, percentIvaEquals, percentIvaGreaterThan, percentIvaGreaterThanOrEqual, percentIvaIn, percentIvaLessThan, percentIvaLessThanOrEqual, percentIvaNotEquals, percentIvaSpecified, percritenutaEquals, percritenutaGreaterThan, percritenutaGreaterThanOrEqual, percritenutaIn, percritenutaLessThan, percritenutaLessThanOrEqual, percritenutaNotEquals, percritenutaSpecified, pivaContains, pivaDoesNotContain, pivaEquals, pivaIn, pivaNotEquals, pivaSpecified, protSuffEquals, protSuffGreaterThan, protSuffGreaterThanOrEqual, protSuffIn, protSuffLessThan, protSuffLessThanOrEqual, protSuffNotEquals, protSuffSpecified, protocolloEquals, protocolloGreaterThan, protocolloGreaterThanOrEqual, protocolloIn, protocolloLessThan, protocolloLessThanOrEqual, protocolloNotEquals, protocolloSpecified, provContains, provDoesNotContain, provEquals, provIn, provNotEquals, provSpecified, ritenutaEquals, ritenutaGreaterThan, ritenutaGreaterThanOrEqual, ritenutaIn, ritenutaLessThan, ritenutaLessThanOrEqual, ritenutaNotEquals, ritenutaSpecified, size, sort, tipoContains, tipoDoesNotContain, tipoEquals, tipoIn, tipoNotEquals, tipoSpecified, totaleEquals, totaleGreaterThan, totaleGreaterThanOrEqual, totaleIn, totaleLessThan, totaleLessThanOrEqual, totaleNotEquals, totaleSpecified, totimponibileEquals, totimponibileGreaterThan, totimponibileGreaterThanOrEqual, totimponibileIn, totimponibileLessThan, totimponibileLessThanOrEqual, totimponibileNotEquals, totimponibileSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (capContains !== undefined && capContains !== null) {
            queryParameters = queryParameters.set('cap.contains', capContains);
        }
        if (capDoesNotContain !== undefined && capDoesNotContain !== null) {
            queryParameters = queryParameters.set('cap.doesNotContain', capDoesNotContain);
        }
        if (capEquals !== undefined && capEquals !== null) {
            queryParameters = queryParameters.set('cap.equals', capEquals);
        }
        if (capIn) {
            capIn.forEach(function (element) {
                queryParameters = queryParameters.append('cap.in', element);
            });
        }
        if (capNotEquals !== undefined && capNotEquals !== null) {
            queryParameters = queryParameters.set('cap.notEquals', capNotEquals);
        }
        if (capSpecified !== undefined && capSpecified !== null) {
            queryParameters = queryParameters.set('cap.specified', capSpecified);
        }
        if (cittContains !== undefined && cittContains !== null) {
            queryParameters = queryParameters.set('citt.contains', cittContains);
        }
        if (cittDoesNotContain !== undefined && cittDoesNotContain !== null) {
            queryParameters = queryParameters.set('citt.doesNotContain', cittDoesNotContain);
        }
        if (cittEquals !== undefined && cittEquals !== null) {
            queryParameters = queryParameters.set('citt.equals', cittEquals);
        }
        if (cittIn) {
            cittIn.forEach(function (element) {
                queryParameters = queryParameters.append('citt.in', element);
            });
        }
        if (cittNotEquals !== undefined && cittNotEquals !== null) {
            queryParameters = queryParameters.set('citt.notEquals', cittNotEquals);
        }
        if (cittSpecified !== undefined && cittSpecified !== null) {
            queryParameters = queryParameters.set('citt.specified', cittSpecified);
        }
        if (clienteEquals !== undefined && clienteEquals !== null) {
            queryParameters = queryParameters.set('cliente.equals', clienteEquals);
        }
        if (clienteIn) {
            clienteIn.forEach(function (element) {
                queryParameters = queryParameters.append('cliente.in', element);
            });
        }
        if (clienteNotEquals !== undefined && clienteNotEquals !== null) {
            queryParameters = queryParameters.set('cliente.notEquals', clienteNotEquals);
        }
        if (clienteSpecified !== undefined && clienteSpecified !== null) {
            queryParameters = queryParameters.set('cliente.specified', clienteSpecified);
        }
        if (codfiscContains !== undefined && codfiscContains !== null) {
            queryParameters = queryParameters.set('codfisc.contains', codfiscContains);
        }
        if (codfiscDoesNotContain !== undefined && codfiscDoesNotContain !== null) {
            queryParameters = queryParameters.set('codfisc.doesNotContain', codfiscDoesNotContain);
        }
        if (codfiscEquals !== undefined && codfiscEquals !== null) {
            queryParameters = queryParameters.set('codfisc.equals', codfiscEquals);
        }
        if (codfiscIn) {
            codfiscIn.forEach(function (element) {
                queryParameters = queryParameters.append('codfisc.in', element);
            });
        }
        if (codfiscNotEquals !== undefined && codfiscNotEquals !== null) {
            queryParameters = queryParameters.set('codfisc.notEquals', codfiscNotEquals);
        }
        if (codfiscSpecified !== undefined && codfiscSpecified !== null) {
            queryParameters = queryParameters.set('codfisc.specified', codfiscSpecified);
        }
        if (codiceInvioContains !== undefined && codiceInvioContains !== null) {
            queryParameters = queryParameters.set('codiceInvio.contains', codiceInvioContains);
        }
        if (codiceInvioDoesNotContain !== undefined && codiceInvioDoesNotContain !== null) {
            queryParameters = queryParameters.set('codiceInvio.doesNotContain', codiceInvioDoesNotContain);
        }
        if (codiceInvioEquals !== undefined && codiceInvioEquals !== null) {
            queryParameters = queryParameters.set('codiceInvio.equals', codiceInvioEquals);
        }
        if (codiceInvioIn) {
            codiceInvioIn.forEach(function (element) {
                queryParameters = queryParameters.append('codiceInvio.in', element);
            });
        }
        if (codiceInvioNotEquals !== undefined && codiceInvioNotEquals !== null) {
            queryParameters = queryParameters.set('codiceInvio.notEquals', codiceInvioNotEquals);
        }
        if (codiceInvioSpecified !== undefined && codiceInvioSpecified !== null) {
            queryParameters = queryParameters.set('codiceInvio.specified', codiceInvioSpecified);
        }
        if (contoEquals !== undefined && contoEquals !== null) {
            queryParameters = queryParameters.set('conto.equals', contoEquals);
        }
        if (contoGreaterThan !== undefined && contoGreaterThan !== null) {
            queryParameters = queryParameters.set('conto.greaterThan', contoGreaterThan);
        }
        if (contoGreaterThanOrEqual !== undefined && contoGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('conto.greaterThanOrEqual', contoGreaterThanOrEqual);
        }
        if (contoIn) {
            contoIn.forEach(function (element) {
                queryParameters = queryParameters.append('conto.in', element);
            });
        }
        if (contoLessThan !== undefined && contoLessThan !== null) {
            queryParameters = queryParameters.set('conto.lessThan', contoLessThan);
        }
        if (contoLessThanOrEqual !== undefined && contoLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('conto.lessThanOrEqual', contoLessThanOrEqual);
        }
        if (contoNotEquals !== undefined && contoNotEquals !== null) {
            queryParameters = queryParameters.set('conto.notEquals', contoNotEquals);
        }
        if (contoSpecified !== undefined && contoSpecified !== null) {
            queryParameters = queryParameters.set('conto.specified', contoSpecified);
        }
        if (contrintegpercEquals !== undefined && contrintegpercEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.equals', contrintegpercEquals);
        }
        if (contrintegpercGreaterThan !== undefined && contrintegpercGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThan', contrintegpercGreaterThan);
        }
        if (contrintegpercGreaterThanOrEqual !== undefined && contrintegpercGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.greaterThanOrEqual', contrintegpercGreaterThanOrEqual);
        }
        if (contrintegpercIn) {
            contrintegpercIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegperc.in', element);
            });
        }
        if (contrintegpercLessThan !== undefined && contrintegpercLessThan !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThan', contrintegpercLessThan);
        }
        if (contrintegpercLessThanOrEqual !== undefined && contrintegpercLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegperc.lessThanOrEqual', contrintegpercLessThanOrEqual);
        }
        if (contrintegpercNotEquals !== undefined && contrintegpercNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegperc.notEquals', contrintegpercNotEquals);
        }
        if (contrintegpercSpecified !== undefined && contrintegpercSpecified !== null) {
            queryParameters = queryParameters.set('contrintegperc.specified', contrintegpercSpecified);
        }
        if (contrintegvalEquals !== undefined && contrintegvalEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.equals', contrintegvalEquals);
        }
        if (contrintegvalGreaterThan !== undefined && contrintegvalGreaterThan !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThan', contrintegvalGreaterThan);
        }
        if (contrintegvalGreaterThanOrEqual !== undefined && contrintegvalGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.greaterThanOrEqual', contrintegvalGreaterThanOrEqual);
        }
        if (contrintegvalIn) {
            contrintegvalIn.forEach(function (element) {
                queryParameters = queryParameters.append('contrintegval.in', element);
            });
        }
        if (contrintegvalLessThan !== undefined && contrintegvalLessThan !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThan', contrintegvalLessThan);
        }
        if (contrintegvalLessThanOrEqual !== undefined && contrintegvalLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contrintegval.lessThanOrEqual', contrintegvalLessThanOrEqual);
        }
        if (contrintegvalNotEquals !== undefined && contrintegvalNotEquals !== null) {
            queryParameters = queryParameters.set('contrintegval.notEquals', contrintegvalNotEquals);
        }
        if (contrintegvalSpecified !== undefined && contrintegvalSpecified !== null) {
            queryParameters = queryParameters.set('contrintegval.specified', contrintegvalSpecified);
        }
        if (dataEquals !== undefined && dataEquals !== null) {
            queryParameters = queryParameters.set('data.equals', dataEquals);
        }
        if (dataGreaterThan !== undefined && dataGreaterThan !== null) {
            queryParameters = queryParameters.set('data.greaterThan', dataGreaterThan);
        }
        if (dataGreaterThanOrEqual !== undefined && dataGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('data.greaterThanOrEqual', dataGreaterThanOrEqual);
        }
        if (dataIn0ChronologyCalendarType !== undefined && dataIn0ChronologyCalendarType !== null) {
            queryParameters = queryParameters.set('data.in[0].chronology.calendarType', dataIn0ChronologyCalendarType);
        }
        if (dataIn0ChronologyId !== undefined && dataIn0ChronologyId !== null) {
            queryParameters = queryParameters.set('data.in[0].chronology.id', dataIn0ChronologyId);
        }
        if (dataIn0DayOfMonth !== undefined && dataIn0DayOfMonth !== null) {
            queryParameters = queryParameters.set('data.in[0].dayOfMonth', dataIn0DayOfMonth);
        }
        if (dataIn0DayOfWeek !== undefined && dataIn0DayOfWeek !== null) {
            queryParameters = queryParameters.set('data.in[0].dayOfWeek', dataIn0DayOfWeek);
        }
        if (dataIn0DayOfYear !== undefined && dataIn0DayOfYear !== null) {
            queryParameters = queryParameters.set('data.in[0].dayOfYear', dataIn0DayOfYear);
        }
        if (dataIn0EraValue !== undefined && dataIn0EraValue !== null) {
            queryParameters = queryParameters.set('data.in[0].era.value', dataIn0EraValue);
        }
        if (dataIn0LeapYear !== undefined && dataIn0LeapYear !== null) {
            queryParameters = queryParameters.set('data.in[0].leapYear', dataIn0LeapYear);
        }
        if (dataIn0Month !== undefined && dataIn0Month !== null) {
            queryParameters = queryParameters.set('data.in[0].month', dataIn0Month);
        }
        if (dataIn0MonthValue !== undefined && dataIn0MonthValue !== null) {
            queryParameters = queryParameters.set('data.in[0].monthValue', dataIn0MonthValue);
        }
        if (dataIn0Year !== undefined && dataIn0Year !== null) {
            queryParameters = queryParameters.set('data.in[0].year', dataIn0Year);
        }
        if (dataLessThan !== undefined && dataLessThan !== null) {
            queryParameters = queryParameters.set('data.lessThan', dataLessThan);
        }
        if (dataLessThanOrEqual !== undefined && dataLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('data.lessThanOrEqual', dataLessThanOrEqual);
        }
        if (dataNotEquals !== undefined && dataNotEquals !== null) {
            queryParameters = queryParameters.set('data.notEquals', dataNotEquals);
        }
        if (dataSpecified !== undefined && dataSpecified !== null) {
            queryParameters = queryParameters.set('data.specified', dataSpecified);
        }
        if (datainsEquals !== undefined && datainsEquals !== null) {
            queryParameters = queryParameters.set('datains.equals', datainsEquals.toISOString());
        }
        if (datainsGreaterThan !== undefined && datainsGreaterThan !== null) {
            queryParameters = queryParameters.set('datains.greaterThan', datainsGreaterThan.toISOString());
        }
        if (datainsGreaterThanOrEqual !== undefined && datainsGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('datains.greaterThanOrEqual', datainsGreaterThanOrEqual.toISOString());
        }
        if (datainsIn0DayOfMonth !== undefined && datainsIn0DayOfMonth !== null) {
            queryParameters = queryParameters.set('datains.in[0].dayOfMonth', datainsIn0DayOfMonth);
        }
        if (datainsIn0DayOfWeek !== undefined && datainsIn0DayOfWeek !== null) {
            queryParameters = queryParameters.set('datains.in[0].dayOfWeek', datainsIn0DayOfWeek);
        }
        if (datainsIn0DayOfYear !== undefined && datainsIn0DayOfYear !== null) {
            queryParameters = queryParameters.set('datains.in[0].dayOfYear', datainsIn0DayOfYear);
        }
        if (datainsIn0Hour !== undefined && datainsIn0Hour !== null) {
            queryParameters = queryParameters.set('datains.in[0].hour', datainsIn0Hour);
        }
        if (datainsIn0Minute !== undefined && datainsIn0Minute !== null) {
            queryParameters = queryParameters.set('datains.in[0].minute', datainsIn0Minute);
        }
        if (datainsIn0Month !== undefined && datainsIn0Month !== null) {
            queryParameters = queryParameters.set('datains.in[0].month', datainsIn0Month);
        }
        if (datainsIn0MonthValue !== undefined && datainsIn0MonthValue !== null) {
            queryParameters = queryParameters.set('datains.in[0].monthValue', datainsIn0MonthValue);
        }
        if (datainsIn0Nano !== undefined && datainsIn0Nano !== null) {
            queryParameters = queryParameters.set('datains.in[0].nano', datainsIn0Nano);
        }
        if (datainsIn0OffsetId !== undefined && datainsIn0OffsetId !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.id', datainsIn0OffsetId);
        }
        if (datainsIn0OffsetRulesFixedOffset !== undefined && datainsIn0OffsetRulesFixedOffset !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.fixedOffset', datainsIn0OffsetRulesFixedOffset);
        }
        if (datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator !== undefined && datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].dayOfMonthIndicator', datainsIn0OffsetRulesTransitionRules0DayOfMonthIndicator);
        }
        if (datainsIn0OffsetRulesTransitionRules0DayOfWeek !== undefined && datainsIn0OffsetRulesTransitionRules0DayOfWeek !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].dayOfWeek', datainsIn0OffsetRulesTransitionRules0DayOfWeek);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeHour !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeHour !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.hour', datainsIn0OffsetRulesTransitionRules0LocalTimeHour);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeMinute !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeMinute !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.minute', datainsIn0OffsetRulesTransitionRules0LocalTimeMinute);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeNano !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.nano', datainsIn0OffsetRulesTransitionRules0LocalTimeNano);
        }
        if (datainsIn0OffsetRulesTransitionRules0LocalTimeSecond !== undefined && datainsIn0OffsetRulesTransitionRules0LocalTimeSecond !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].localTime.second', datainsIn0OffsetRulesTransitionRules0LocalTimeSecond);
        }
        if (datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay !== undefined && datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].midnightEndOfDay', datainsIn0OffsetRulesTransitionRules0MidnightEndOfDay);
        }
        if (datainsIn0OffsetRulesTransitionRules0Month !== undefined && datainsIn0OffsetRulesTransitionRules0Month !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].month', datainsIn0OffsetRulesTransitionRules0Month);
        }
        if (datainsIn0OffsetRulesTransitionRules0TimeDefinition !== undefined && datainsIn0OffsetRulesTransitionRules0TimeDefinition !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitionRules[0].timeDefinition', datainsIn0OffsetRulesTransitionRules0TimeDefinition);
        }
        if (datainsIn0OffsetRulesTransitions0DateTimeAfter !== undefined && datainsIn0OffsetRulesTransitions0DateTimeAfter !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].dateTimeAfter', datainsIn0OffsetRulesTransitions0DateTimeAfter.toISOString());
        }
        if (datainsIn0OffsetRulesTransitions0DateTimeBefore !== undefined && datainsIn0OffsetRulesTransitions0DateTimeBefore !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].dateTimeBefore', datainsIn0OffsetRulesTransitions0DateTimeBefore.toISOString());
        }
        if (datainsIn0OffsetRulesTransitions0DurationNano !== undefined && datainsIn0OffsetRulesTransitions0DurationNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.nano', datainsIn0OffsetRulesTransitions0DurationNano);
        }
        if (datainsIn0OffsetRulesTransitions0DurationNegative !== undefined && datainsIn0OffsetRulesTransitions0DurationNegative !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.negative', datainsIn0OffsetRulesTransitions0DurationNegative);
        }
        if (datainsIn0OffsetRulesTransitions0DurationSeconds !== undefined && datainsIn0OffsetRulesTransitions0DurationSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.seconds', datainsIn0OffsetRulesTransitions0DurationSeconds);
        }
        if (datainsIn0OffsetRulesTransitions0DurationUnits0DateBased !== undefined && datainsIn0OffsetRulesTransitions0DurationUnits0DateBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.units[0].dateBased', datainsIn0OffsetRulesTransitions0DurationUnits0DateBased);
        }
        if (datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated !== undefined && datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.units[0].durationEstimated', datainsIn0OffsetRulesTransitions0DurationUnits0DurationEstimated);
        }
        if (datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased !== undefined && datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.units[0].timeBased', datainsIn0OffsetRulesTransitions0DurationUnits0TimeBased);
        }
        if (datainsIn0OffsetRulesTransitions0DurationZero !== undefined && datainsIn0OffsetRulesTransitions0DurationZero !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].duration.zero', datainsIn0OffsetRulesTransitions0DurationZero);
        }
        if (datainsIn0OffsetRulesTransitions0Gap !== undefined && datainsIn0OffsetRulesTransitions0Gap !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].gap', datainsIn0OffsetRulesTransitions0Gap);
        }
        if (datainsIn0OffsetRulesTransitions0Instant !== undefined && datainsIn0OffsetRulesTransitions0Instant !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].instant', datainsIn0OffsetRulesTransitions0Instant.toISOString());
        }
        if (datainsIn0OffsetRulesTransitions0Overlap !== undefined && datainsIn0OffsetRulesTransitions0Overlap !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.rules.transitions[0].overlap', datainsIn0OffsetRulesTransitions0Overlap);
        }
        if (datainsIn0OffsetTotalSeconds !== undefined && datainsIn0OffsetTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].offset.totalSeconds', datainsIn0OffsetTotalSeconds);
        }
        if (datainsIn0Second !== undefined && datainsIn0Second !== null) {
            queryParameters = queryParameters.set('datains.in[0].second', datainsIn0Second);
        }
        if (datainsIn0Year !== undefined && datainsIn0Year !== null) {
            queryParameters = queryParameters.set('datains.in[0].year', datainsIn0Year);
        }
        if (datainsIn0ZoneId !== undefined && datainsIn0ZoneId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.id', datainsIn0ZoneId);
        }
        if (datainsIn0ZoneRulesFixedOffset !== undefined && datainsIn0ZoneRulesFixedOffset !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.fixedOffset', datainsIn0ZoneRulesFixedOffset);
        }
        if (datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator !== undefined && datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].dayOfMonthIndicator', datainsIn0ZoneRulesTransitionRules0DayOfMonthIndicator);
        }
        if (datainsIn0ZoneRulesTransitionRules0DayOfWeek !== undefined && datainsIn0ZoneRulesTransitionRules0DayOfWeek !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].dayOfWeek', datainsIn0ZoneRulesTransitionRules0DayOfWeek);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeHour !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeHour !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.hour', datainsIn0ZoneRulesTransitionRules0LocalTimeHour);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeMinute !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeMinute !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.minute', datainsIn0ZoneRulesTransitionRules0LocalTimeMinute);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeNano !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.nano', datainsIn0ZoneRulesTransitionRules0LocalTimeNano);
        }
        if (datainsIn0ZoneRulesTransitionRules0LocalTimeSecond !== undefined && datainsIn0ZoneRulesTransitionRules0LocalTimeSecond !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].localTime.second', datainsIn0ZoneRulesTransitionRules0LocalTimeSecond);
        }
        if (datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay !== undefined && datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].midnightEndOfDay', datainsIn0ZoneRulesTransitionRules0MidnightEndOfDay);
        }
        if (datainsIn0ZoneRulesTransitionRules0Month !== undefined && datainsIn0ZoneRulesTransitionRules0Month !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].month', datainsIn0ZoneRulesTransitionRules0Month);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetAfterId !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetAfterId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetAfter.id', datainsIn0ZoneRulesTransitionRules0OffsetAfterId);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetAfter.totalSeconds', datainsIn0ZoneRulesTransitionRules0OffsetAfterTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetBeforeId !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetBeforeId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetBefore.id', datainsIn0ZoneRulesTransitionRules0OffsetBeforeId);
        }
        if (datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds !== undefined && datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].offsetBefore.totalSeconds', datainsIn0ZoneRulesTransitionRules0OffsetBeforeTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitionRules0StandardOffsetId !== undefined && datainsIn0ZoneRulesTransitionRules0StandardOffsetId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].standardOffset.id', datainsIn0ZoneRulesTransitionRules0StandardOffsetId);
        }
        if (datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds !== undefined && datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].standardOffset.totalSeconds', datainsIn0ZoneRulesTransitionRules0StandardOffsetTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitionRules0TimeDefinition !== undefined && datainsIn0ZoneRulesTransitionRules0TimeDefinition !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitionRules[0].timeDefinition', datainsIn0ZoneRulesTransitionRules0TimeDefinition);
        }
        if (datainsIn0ZoneRulesTransitions0DateTimeAfter !== undefined && datainsIn0ZoneRulesTransitions0DateTimeAfter !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].dateTimeAfter', datainsIn0ZoneRulesTransitions0DateTimeAfter.toISOString());
        }
        if (datainsIn0ZoneRulesTransitions0DateTimeBefore !== undefined && datainsIn0ZoneRulesTransitions0DateTimeBefore !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].dateTimeBefore', datainsIn0ZoneRulesTransitions0DateTimeBefore.toISOString());
        }
        if (datainsIn0ZoneRulesTransitions0DurationNano !== undefined && datainsIn0ZoneRulesTransitions0DurationNano !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.nano', datainsIn0ZoneRulesTransitions0DurationNano);
        }
        if (datainsIn0ZoneRulesTransitions0DurationNegative !== undefined && datainsIn0ZoneRulesTransitions0DurationNegative !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.negative', datainsIn0ZoneRulesTransitions0DurationNegative);
        }
        if (datainsIn0ZoneRulesTransitions0DurationSeconds !== undefined && datainsIn0ZoneRulesTransitions0DurationSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.seconds', datainsIn0ZoneRulesTransitions0DurationSeconds);
        }
        if (datainsIn0ZoneRulesTransitions0DurationUnits0DateBased !== undefined && datainsIn0ZoneRulesTransitions0DurationUnits0DateBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.units[0].dateBased', datainsIn0ZoneRulesTransitions0DurationUnits0DateBased);
        }
        if (datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated !== undefined && datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.units[0].durationEstimated', datainsIn0ZoneRulesTransitions0DurationUnits0DurationEstimated);
        }
        if (datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased !== undefined && datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.units[0].timeBased', datainsIn0ZoneRulesTransitions0DurationUnits0TimeBased);
        }
        if (datainsIn0ZoneRulesTransitions0DurationZero !== undefined && datainsIn0ZoneRulesTransitions0DurationZero !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].duration.zero', datainsIn0ZoneRulesTransitions0DurationZero);
        }
        if (datainsIn0ZoneRulesTransitions0Gap !== undefined && datainsIn0ZoneRulesTransitions0Gap !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].gap', datainsIn0ZoneRulesTransitions0Gap);
        }
        if (datainsIn0ZoneRulesTransitions0Instant !== undefined && datainsIn0ZoneRulesTransitions0Instant !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].instant', datainsIn0ZoneRulesTransitions0Instant.toISOString());
        }
        if (datainsIn0ZoneRulesTransitions0OffsetAfterId !== undefined && datainsIn0ZoneRulesTransitions0OffsetAfterId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetAfter.id', datainsIn0ZoneRulesTransitions0OffsetAfterId);
        }
        if (datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds !== undefined && datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetAfter.totalSeconds', datainsIn0ZoneRulesTransitions0OffsetAfterTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitions0OffsetBeforeId !== undefined && datainsIn0ZoneRulesTransitions0OffsetBeforeId !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetBefore.id', datainsIn0ZoneRulesTransitions0OffsetBeforeId);
        }
        if (datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds !== undefined && datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].offsetBefore.totalSeconds', datainsIn0ZoneRulesTransitions0OffsetBeforeTotalSeconds);
        }
        if (datainsIn0ZoneRulesTransitions0Overlap !== undefined && datainsIn0ZoneRulesTransitions0Overlap !== null) {
            queryParameters = queryParameters.set('datains.in[0].zone.rules.transitions[0].overlap', datainsIn0ZoneRulesTransitions0Overlap);
        }
        if (datainsLessThan !== undefined && datainsLessThan !== null) {
            queryParameters = queryParameters.set('datains.lessThan', datainsLessThan.toISOString());
        }
        if (datainsLessThanOrEqual !== undefined && datainsLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('datains.lessThanOrEqual', datainsLessThanOrEqual.toISOString());
        }
        if (datainsNotEquals !== undefined && datainsNotEquals !== null) {
            queryParameters = queryParameters.set('datains.notEquals', datainsNotEquals.toISOString());
        }
        if (datainsSpecified !== undefined && datainsSpecified !== null) {
            queryParameters = queryParameters.set('datains.specified', datainsSpecified);
        }
        if (dataregistrazioneEquals !== undefined && dataregistrazioneEquals !== null) {
            queryParameters = queryParameters.set('dataregistrazione.equals', dataregistrazioneEquals);
        }
        if (dataregistrazioneGreaterThan !== undefined && dataregistrazioneGreaterThan !== null) {
            queryParameters = queryParameters.set('dataregistrazione.greaterThan', dataregistrazioneGreaterThan);
        }
        if (dataregistrazioneGreaterThanOrEqual !== undefined && dataregistrazioneGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('dataregistrazione.greaterThanOrEqual', dataregistrazioneGreaterThanOrEqual);
        }
        if (dataregistrazioneIn0ChronologyCalendarType !== undefined && dataregistrazioneIn0ChronologyCalendarType !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].chronology.calendarType', dataregistrazioneIn0ChronologyCalendarType);
        }
        if (dataregistrazioneIn0ChronologyId !== undefined && dataregistrazioneIn0ChronologyId !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].chronology.id', dataregistrazioneIn0ChronologyId);
        }
        if (dataregistrazioneIn0DayOfMonth !== undefined && dataregistrazioneIn0DayOfMonth !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].dayOfMonth', dataregistrazioneIn0DayOfMonth);
        }
        if (dataregistrazioneIn0DayOfWeek !== undefined && dataregistrazioneIn0DayOfWeek !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].dayOfWeek', dataregistrazioneIn0DayOfWeek);
        }
        if (dataregistrazioneIn0DayOfYear !== undefined && dataregistrazioneIn0DayOfYear !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].dayOfYear', dataregistrazioneIn0DayOfYear);
        }
        if (dataregistrazioneIn0EraValue !== undefined && dataregistrazioneIn0EraValue !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].era.value', dataregistrazioneIn0EraValue);
        }
        if (dataregistrazioneIn0LeapYear !== undefined && dataregistrazioneIn0LeapYear !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].leapYear', dataregistrazioneIn0LeapYear);
        }
        if (dataregistrazioneIn0Month !== undefined && dataregistrazioneIn0Month !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].month', dataregistrazioneIn0Month);
        }
        if (dataregistrazioneIn0MonthValue !== undefined && dataregistrazioneIn0MonthValue !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].monthValue', dataregistrazioneIn0MonthValue);
        }
        if (dataregistrazioneIn0Year !== undefined && dataregistrazioneIn0Year !== null) {
            queryParameters = queryParameters.set('dataregistrazione.in[0].year', dataregistrazioneIn0Year);
        }
        if (dataregistrazioneLessThan !== undefined && dataregistrazioneLessThan !== null) {
            queryParameters = queryParameters.set('dataregistrazione.lessThan', dataregistrazioneLessThan);
        }
        if (dataregistrazioneLessThanOrEqual !== undefined && dataregistrazioneLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('dataregistrazione.lessThanOrEqual', dataregistrazioneLessThanOrEqual);
        }
        if (dataregistrazioneNotEquals !== undefined && dataregistrazioneNotEquals !== null) {
            queryParameters = queryParameters.set('dataregistrazione.notEquals', dataregistrazioneNotEquals);
        }
        if (dataregistrazioneSpecified !== undefined && dataregistrazioneSpecified !== null) {
            queryParameters = queryParameters.set('dataregistrazione.specified', dataregistrazioneSpecified);
        }
        if (fornitoreEquals !== undefined && fornitoreEquals !== null) {
            queryParameters = queryParameters.set('fornitore.equals', fornitoreEquals);
        }
        if (fornitoreIn) {
            fornitoreIn.forEach(function (element) {
                queryParameters = queryParameters.append('fornitore.in', element);
            });
        }
        if (fornitoreNotEquals !== undefined && fornitoreNotEquals !== null) {
            queryParameters = queryParameters.set('fornitore.notEquals', fornitoreNotEquals);
        }
        if (fornitoreSpecified !== undefined && fornitoreSpecified !== null) {
            queryParameters = queryParameters.set('fornitore.specified', fornitoreSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (idanagraficaEquals !== undefined && idanagraficaEquals !== null) {
            queryParameters = queryParameters.set('idanagrafica.equals', idanagraficaEquals);
        }
        if (idanagraficaGreaterThan !== undefined && idanagraficaGreaterThan !== null) {
            queryParameters = queryParameters.set('idanagrafica.greaterThan', idanagraficaGreaterThan);
        }
        if (idanagraficaGreaterThanOrEqual !== undefined && idanagraficaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('idanagrafica.greaterThanOrEqual', idanagraficaGreaterThanOrEqual);
        }
        if (idanagraficaIn) {
            idanagraficaIn.forEach(function (element) {
                queryParameters = queryParameters.append('idanagrafica.in', element);
            });
        }
        if (idanagraficaLessThan !== undefined && idanagraficaLessThan !== null) {
            queryParameters = queryParameters.set('idanagrafica.lessThan', idanagraficaLessThan);
        }
        if (idanagraficaLessThanOrEqual !== undefined && idanagraficaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('idanagrafica.lessThanOrEqual', idanagraficaLessThanOrEqual);
        }
        if (idanagraficaNotEquals !== undefined && idanagraficaNotEquals !== null) {
            queryParameters = queryParameters.set('idanagrafica.notEquals', idanagraficaNotEquals);
        }
        if (idanagraficaSpecified !== undefined && idanagraficaSpecified !== null) {
            queryParameters = queryParameters.set('idanagrafica.specified', idanagraficaSpecified);
        }
        if (idaziendaEquals !== undefined && idaziendaEquals !== null) {
            queryParameters = queryParameters.set('idazienda.equals', idaziendaEquals);
        }
        if (idaziendaGreaterThan !== undefined && idaziendaGreaterThan !== null) {
            queryParameters = queryParameters.set('idazienda.greaterThan', idaziendaGreaterThan);
        }
        if (idaziendaGreaterThanOrEqual !== undefined && idaziendaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('idazienda.greaterThanOrEqual', idaziendaGreaterThanOrEqual);
        }
        if (idaziendaIn) {
            idaziendaIn.forEach(function (element) {
                queryParameters = queryParameters.append('idazienda.in', element);
            });
        }
        if (idaziendaLessThan !== undefined && idaziendaLessThan !== null) {
            queryParameters = queryParameters.set('idazienda.lessThan', idaziendaLessThan);
        }
        if (idaziendaLessThanOrEqual !== undefined && idaziendaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('idazienda.lessThanOrEqual', idaziendaLessThanOrEqual);
        }
        if (idaziendaNotEquals !== undefined && idaziendaNotEquals !== null) {
            queryParameters = queryParameters.set('idazienda.notEquals', idaziendaNotEquals);
        }
        if (idaziendaSpecified !== undefined && idaziendaSpecified !== null) {
            queryParameters = queryParameters.set('idazienda.specified', idaziendaSpecified);
        }
        if (iddocumentoContains !== undefined && iddocumentoContains !== null) {
            queryParameters = queryParameters.set('iddocumento.contains', iddocumentoContains);
        }
        if (iddocumentoDoesNotContain !== undefined && iddocumentoDoesNotContain !== null) {
            queryParameters = queryParameters.set('iddocumento.doesNotContain', iddocumentoDoesNotContain);
        }
        if (iddocumentoEquals !== undefined && iddocumentoEquals !== null) {
            queryParameters = queryParameters.set('iddocumento.equals', iddocumentoEquals);
        }
        if (iddocumentoIn) {
            iddocumentoIn.forEach(function (element) {
                queryParameters = queryParameters.append('iddocumento.in', element);
            });
        }
        if (iddocumentoNotEquals !== undefined && iddocumentoNotEquals !== null) {
            queryParameters = queryParameters.set('iddocumento.notEquals', iddocumentoNotEquals);
        }
        if (iddocumentoSpecified !== undefined && iddocumentoSpecified !== null) {
            queryParameters = queryParameters.set('iddocumento.specified', iddocumentoSpecified);
        }
        if (idsottocontoContains !== undefined && idsottocontoContains !== null) {
            queryParameters = queryParameters.set('idsottoconto.contains', idsottocontoContains);
        }
        if (idsottocontoDoesNotContain !== undefined && idsottocontoDoesNotContain !== null) {
            queryParameters = queryParameters.set('idsottoconto.doesNotContain', idsottocontoDoesNotContain);
        }
        if (idsottocontoEquals !== undefined && idsottocontoEquals !== null) {
            queryParameters = queryParameters.set('idsottoconto.equals', idsottocontoEquals);
        }
        if (idsottocontoIn) {
            idsottocontoIn.forEach(function (element) {
                queryParameters = queryParameters.append('idsottoconto.in', element);
            });
        }
        if (idsottocontoNotEquals !== undefined && idsottocontoNotEquals !== null) {
            queryParameters = queryParameters.set('idsottoconto.notEquals', idsottocontoNotEquals);
        }
        if (idsottocontoSpecified !== undefined && idsottocontoSpecified !== null) {
            queryParameters = queryParameters.set('idsottoconto.specified', idsottocontoSpecified);
        }
        if (indirizzoContains !== undefined && indirizzoContains !== null) {
            queryParameters = queryParameters.set('indirizzo.contains', indirizzoContains);
        }
        if (indirizzoDoesNotContain !== undefined && indirizzoDoesNotContain !== null) {
            queryParameters = queryParameters.set('indirizzo.doesNotContain', indirizzoDoesNotContain);
        }
        if (indirizzoEquals !== undefined && indirizzoEquals !== null) {
            queryParameters = queryParameters.set('indirizzo.equals', indirizzoEquals);
        }
        if (indirizzoIn) {
            indirizzoIn.forEach(function (element) {
                queryParameters = queryParameters.append('indirizzo.in', element);
            });
        }
        if (indirizzoNotEquals !== undefined && indirizzoNotEquals !== null) {
            queryParameters = queryParameters.set('indirizzo.notEquals', indirizzoNotEquals);
        }
        if (indirizzoSpecified !== undefined && indirizzoSpecified !== null) {
            queryParameters = queryParameters.set('indirizzo.specified', indirizzoSpecified);
        }
        if (intestazioneContains !== undefined && intestazioneContains !== null) {
            queryParameters = queryParameters.set('intestazione.contains', intestazioneContains);
        }
        if (intestazioneDoesNotContain !== undefined && intestazioneDoesNotContain !== null) {
            queryParameters = queryParameters.set('intestazione.doesNotContain', intestazioneDoesNotContain);
        }
        if (intestazioneEquals !== undefined && intestazioneEquals !== null) {
            queryParameters = queryParameters.set('intestazione.equals', intestazioneEquals);
        }
        if (intestazioneIn) {
            intestazioneIn.forEach(function (element) {
                queryParameters = queryParameters.append('intestazione.in', element);
            });
        }
        if (intestazioneNotEquals !== undefined && intestazioneNotEquals !== null) {
            queryParameters = queryParameters.set('intestazione.notEquals', intestazioneNotEquals);
        }
        if (intestazioneSpecified !== undefined && intestazioneSpecified !== null) {
            queryParameters = queryParameters.set('intestazione.specified', intestazioneSpecified);
        }
        if (ivaEquals !== undefined && ivaEquals !== null) {
            queryParameters = queryParameters.set('iva.equals', ivaEquals);
        }
        if (ivaGreaterThan !== undefined && ivaGreaterThan !== null) {
            queryParameters = queryParameters.set('iva.greaterThan', ivaGreaterThan);
        }
        if (ivaGreaterThanOrEqual !== undefined && ivaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.greaterThanOrEqual', ivaGreaterThanOrEqual);
        }
        if (ivaIn) {
            ivaIn.forEach(function (element) {
                queryParameters = queryParameters.append('iva.in', element);
            });
        }
        if (ivaLessThan !== undefined && ivaLessThan !== null) {
            queryParameters = queryParameters.set('iva.lessThan', ivaLessThan);
        }
        if (ivaLessThanOrEqual !== undefined && ivaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('iva.lessThanOrEqual', ivaLessThanOrEqual);
        }
        if (ivaNotEquals !== undefined && ivaNotEquals !== null) {
            queryParameters = queryParameters.set('iva.notEquals', ivaNotEquals);
        }
        if (ivaSpecified !== undefined && ivaSpecified !== null) {
            queryParameters = queryParameters.set('iva.specified', ivaSpecified);
        }
        if (ivasinoEquals !== undefined && ivasinoEquals !== null) {
            queryParameters = queryParameters.set('ivasino.equals', ivasinoEquals);
        }
        if (ivasinoIn) {
            ivasinoIn.forEach(function (element) {
                queryParameters = queryParameters.append('ivasino.in', element);
            });
        }
        if (ivasinoNotEquals !== undefined && ivasinoNotEquals !== null) {
            queryParameters = queryParameters.set('ivasino.notEquals', ivasinoNotEquals);
        }
        if (ivasinoSpecified !== undefined && ivasinoSpecified !== null) {
            queryParameters = queryParameters.set('ivasino.specified', ivasinoSpecified);
        }
        if (mdopagEquals !== undefined && mdopagEquals !== null) {
            queryParameters = queryParameters.set('mdopag.equals', mdopagEquals);
        }
        if (mdopagGreaterThan !== undefined && mdopagGreaterThan !== null) {
            queryParameters = queryParameters.set('mdopag.greaterThan', mdopagGreaterThan);
        }
        if (mdopagGreaterThanOrEqual !== undefined && mdopagGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('mdopag.greaterThanOrEqual', mdopagGreaterThanOrEqual);
        }
        if (mdopagIn) {
            mdopagIn.forEach(function (element) {
                queryParameters = queryParameters.append('mdopag.in', element);
            });
        }
        if (mdopagLessThan !== undefined && mdopagLessThan !== null) {
            queryParameters = queryParameters.set('mdopag.lessThan', mdopagLessThan);
        }
        if (mdopagLessThanOrEqual !== undefined && mdopagLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('mdopag.lessThanOrEqual', mdopagLessThanOrEqual);
        }
        if (mdopagNotEquals !== undefined && mdopagNotEquals !== null) {
            queryParameters = queryParameters.set('mdopag.notEquals', mdopagNotEquals);
        }
        if (mdopagSpecified !== undefined && mdopagSpecified !== null) {
            queryParameters = queryParameters.set('mdopag.specified', mdopagSpecified);
        }
        if (ndocContains !== undefined && ndocContains !== null) {
            queryParameters = queryParameters.set('ndoc.contains', ndocContains);
        }
        if (ndocDoesNotContain !== undefined && ndocDoesNotContain !== null) {
            queryParameters = queryParameters.set('ndoc.doesNotContain', ndocDoesNotContain);
        }
        if (ndocEquals !== undefined && ndocEquals !== null) {
            queryParameters = queryParameters.set('ndoc.equals', ndocEquals);
        }
        if (ndocIn) {
            ndocIn.forEach(function (element) {
                queryParameters = queryParameters.append('ndoc.in', element);
            });
        }
        if (ndocNotEquals !== undefined && ndocNotEquals !== null) {
            queryParameters = queryParameters.set('ndoc.notEquals', ndocNotEquals);
        }
        if (ndocSpecified !== undefined && ndocSpecified !== null) {
            queryParameters = queryParameters.set('ndoc.specified', ndocSpecified);
        }
        if (ndocSuffEquals !== undefined && ndocSuffEquals !== null) {
            queryParameters = queryParameters.set('ndocSuff.equals', ndocSuffEquals);
        }
        if (ndocSuffGreaterThan !== undefined && ndocSuffGreaterThan !== null) {
            queryParameters = queryParameters.set('ndocSuff.greaterThan', ndocSuffGreaterThan);
        }
        if (ndocSuffGreaterThanOrEqual !== undefined && ndocSuffGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('ndocSuff.greaterThanOrEqual', ndocSuffGreaterThanOrEqual);
        }
        if (ndocSuffIn) {
            ndocSuffIn.forEach(function (element) {
                queryParameters = queryParameters.append('ndocSuff.in', element);
            });
        }
        if (ndocSuffLessThan !== undefined && ndocSuffLessThan !== null) {
            queryParameters = queryParameters.set('ndocSuff.lessThan', ndocSuffLessThan);
        }
        if (ndocSuffLessThanOrEqual !== undefined && ndocSuffLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('ndocSuff.lessThanOrEqual', ndocSuffLessThanOrEqual);
        }
        if (ndocSuffNotEquals !== undefined && ndocSuffNotEquals !== null) {
            queryParameters = queryParameters.set('ndocSuff.notEquals', ndocSuffNotEquals);
        }
        if (ndocSuffSpecified !== undefined && ndocSuffSpecified !== null) {
            queryParameters = queryParameters.set('ndocSuff.specified', ndocSuffSpecified);
        }
        if (noteContains !== undefined && noteContains !== null) {
            queryParameters = queryParameters.set('note.contains', noteContains);
        }
        if (noteDoesNotContain !== undefined && noteDoesNotContain !== null) {
            queryParameters = queryParameters.set('note.doesNotContain', noteDoesNotContain);
        }
        if (noteEquals !== undefined && noteEquals !== null) {
            queryParameters = queryParameters.set('note.equals', noteEquals);
        }
        if (noteIn) {
            noteIn.forEach(function (element) {
                queryParameters = queryParameters.append('note.in', element);
            });
        }
        if (noteNotEquals !== undefined && noteNotEquals !== null) {
            queryParameters = queryParameters.set('note.notEquals', noteNotEquals);
        }
        if (noteSpecified !== undefined && noteSpecified !== null) {
            queryParameters = queryParameters.set('note.specified', noteSpecified);
        }
        if (opeinsContains !== undefined && opeinsContains !== null) {
            queryParameters = queryParameters.set('opeins.contains', opeinsContains);
        }
        if (opeinsDoesNotContain !== undefined && opeinsDoesNotContain !== null) {
            queryParameters = queryParameters.set('opeins.doesNotContain', opeinsDoesNotContain);
        }
        if (opeinsEquals !== undefined && opeinsEquals !== null) {
            queryParameters = queryParameters.set('opeins.equals', opeinsEquals);
        }
        if (opeinsIn) {
            opeinsIn.forEach(function (element) {
                queryParameters = queryParameters.append('opeins.in', element);
            });
        }
        if (opeinsNotEquals !== undefined && opeinsNotEquals !== null) {
            queryParameters = queryParameters.set('opeins.notEquals', opeinsNotEquals);
        }
        if (opeinsSpecified !== undefined && opeinsSpecified !== null) {
            queryParameters = queryParameters.set('opeins.specified', opeinsSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (pecContains !== undefined && pecContains !== null) {
            queryParameters = queryParameters.set('pec.contains', pecContains);
        }
        if (pecDoesNotContain !== undefined && pecDoesNotContain !== null) {
            queryParameters = queryParameters.set('pec.doesNotContain', pecDoesNotContain);
        }
        if (pecEquals !== undefined && pecEquals !== null) {
            queryParameters = queryParameters.set('pec.equals', pecEquals);
        }
        if (pecIn) {
            pecIn.forEach(function (element) {
                queryParameters = queryParameters.append('pec.in', element);
            });
        }
        if (pecNotEquals !== undefined && pecNotEquals !== null) {
            queryParameters = queryParameters.set('pec.notEquals', pecNotEquals);
        }
        if (pecSpecified !== undefined && pecSpecified !== null) {
            queryParameters = queryParameters.set('pec.specified', pecSpecified);
        }
        if (percentIvaEquals !== undefined && percentIvaEquals !== null) {
            queryParameters = queryParameters.set('percentIva.equals', percentIvaEquals);
        }
        if (percentIvaGreaterThan !== undefined && percentIvaGreaterThan !== null) {
            queryParameters = queryParameters.set('percentIva.greaterThan', percentIvaGreaterThan);
        }
        if (percentIvaGreaterThanOrEqual !== undefined && percentIvaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('percentIva.greaterThanOrEqual', percentIvaGreaterThanOrEqual);
        }
        if (percentIvaIn) {
            percentIvaIn.forEach(function (element) {
                queryParameters = queryParameters.append('percentIva.in', element);
            });
        }
        if (percentIvaLessThan !== undefined && percentIvaLessThan !== null) {
            queryParameters = queryParameters.set('percentIva.lessThan', percentIvaLessThan);
        }
        if (percentIvaLessThanOrEqual !== undefined && percentIvaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('percentIva.lessThanOrEqual', percentIvaLessThanOrEqual);
        }
        if (percentIvaNotEquals !== undefined && percentIvaNotEquals !== null) {
            queryParameters = queryParameters.set('percentIva.notEquals', percentIvaNotEquals);
        }
        if (percentIvaSpecified !== undefined && percentIvaSpecified !== null) {
            queryParameters = queryParameters.set('percentIva.specified', percentIvaSpecified);
        }
        if (percritenutaEquals !== undefined && percritenutaEquals !== null) {
            queryParameters = queryParameters.set('percritenuta.equals', percritenutaEquals);
        }
        if (percritenutaGreaterThan !== undefined && percritenutaGreaterThan !== null) {
            queryParameters = queryParameters.set('percritenuta.greaterThan', percritenutaGreaterThan);
        }
        if (percritenutaGreaterThanOrEqual !== undefined && percritenutaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('percritenuta.greaterThanOrEqual', percritenutaGreaterThanOrEqual);
        }
        if (percritenutaIn) {
            percritenutaIn.forEach(function (element) {
                queryParameters = queryParameters.append('percritenuta.in', element);
            });
        }
        if (percritenutaLessThan !== undefined && percritenutaLessThan !== null) {
            queryParameters = queryParameters.set('percritenuta.lessThan', percritenutaLessThan);
        }
        if (percritenutaLessThanOrEqual !== undefined && percritenutaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('percritenuta.lessThanOrEqual', percritenutaLessThanOrEqual);
        }
        if (percritenutaNotEquals !== undefined && percritenutaNotEquals !== null) {
            queryParameters = queryParameters.set('percritenuta.notEquals', percritenutaNotEquals);
        }
        if (percritenutaSpecified !== undefined && percritenutaSpecified !== null) {
            queryParameters = queryParameters.set('percritenuta.specified', percritenutaSpecified);
        }
        if (pivaContains !== undefined && pivaContains !== null) {
            queryParameters = queryParameters.set('piva.contains', pivaContains);
        }
        if (pivaDoesNotContain !== undefined && pivaDoesNotContain !== null) {
            queryParameters = queryParameters.set('piva.doesNotContain', pivaDoesNotContain);
        }
        if (pivaEquals !== undefined && pivaEquals !== null) {
            queryParameters = queryParameters.set('piva.equals', pivaEquals);
        }
        if (pivaIn) {
            pivaIn.forEach(function (element) {
                queryParameters = queryParameters.append('piva.in', element);
            });
        }
        if (pivaNotEquals !== undefined && pivaNotEquals !== null) {
            queryParameters = queryParameters.set('piva.notEquals', pivaNotEquals);
        }
        if (pivaSpecified !== undefined && pivaSpecified !== null) {
            queryParameters = queryParameters.set('piva.specified', pivaSpecified);
        }
        if (protSuffEquals !== undefined && protSuffEquals !== null) {
            queryParameters = queryParameters.set('protSuff.equals', protSuffEquals);
        }
        if (protSuffGreaterThan !== undefined && protSuffGreaterThan !== null) {
            queryParameters = queryParameters.set('protSuff.greaterThan', protSuffGreaterThan);
        }
        if (protSuffGreaterThanOrEqual !== undefined && protSuffGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('protSuff.greaterThanOrEqual', protSuffGreaterThanOrEqual);
        }
        if (protSuffIn) {
            protSuffIn.forEach(function (element) {
                queryParameters = queryParameters.append('protSuff.in', element);
            });
        }
        if (protSuffLessThan !== undefined && protSuffLessThan !== null) {
            queryParameters = queryParameters.set('protSuff.lessThan', protSuffLessThan);
        }
        if (protSuffLessThanOrEqual !== undefined && protSuffLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('protSuff.lessThanOrEqual', protSuffLessThanOrEqual);
        }
        if (protSuffNotEquals !== undefined && protSuffNotEquals !== null) {
            queryParameters = queryParameters.set('protSuff.notEquals', protSuffNotEquals);
        }
        if (protSuffSpecified !== undefined && protSuffSpecified !== null) {
            queryParameters = queryParameters.set('protSuff.specified', protSuffSpecified);
        }
        if (protocolloEquals !== undefined && protocolloEquals !== null) {
            queryParameters = queryParameters.set('protocollo.equals', protocolloEquals);
        }
        if (protocolloGreaterThan !== undefined && protocolloGreaterThan !== null) {
            queryParameters = queryParameters.set('protocollo.greaterThan', protocolloGreaterThan);
        }
        if (protocolloGreaterThanOrEqual !== undefined && protocolloGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('protocollo.greaterThanOrEqual', protocolloGreaterThanOrEqual);
        }
        if (protocolloIn) {
            protocolloIn.forEach(function (element) {
                queryParameters = queryParameters.append('protocollo.in', element);
            });
        }
        if (protocolloLessThan !== undefined && protocolloLessThan !== null) {
            queryParameters = queryParameters.set('protocollo.lessThan', protocolloLessThan);
        }
        if (protocolloLessThanOrEqual !== undefined && protocolloLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('protocollo.lessThanOrEqual', protocolloLessThanOrEqual);
        }
        if (protocolloNotEquals !== undefined && protocolloNotEquals !== null) {
            queryParameters = queryParameters.set('protocollo.notEquals', protocolloNotEquals);
        }
        if (protocolloSpecified !== undefined && protocolloSpecified !== null) {
            queryParameters = queryParameters.set('protocollo.specified', protocolloSpecified);
        }
        if (provContains !== undefined && provContains !== null) {
            queryParameters = queryParameters.set('prov.contains', provContains);
        }
        if (provDoesNotContain !== undefined && provDoesNotContain !== null) {
            queryParameters = queryParameters.set('prov.doesNotContain', provDoesNotContain);
        }
        if (provEquals !== undefined && provEquals !== null) {
            queryParameters = queryParameters.set('prov.equals', provEquals);
        }
        if (provIn) {
            provIn.forEach(function (element) {
                queryParameters = queryParameters.append('prov.in', element);
            });
        }
        if (provNotEquals !== undefined && provNotEquals !== null) {
            queryParameters = queryParameters.set('prov.notEquals', provNotEquals);
        }
        if (provSpecified !== undefined && provSpecified !== null) {
            queryParameters = queryParameters.set('prov.specified', provSpecified);
        }
        if (ritenutaEquals !== undefined && ritenutaEquals !== null) {
            queryParameters = queryParameters.set('ritenuta.equals', ritenutaEquals);
        }
        if (ritenutaGreaterThan !== undefined && ritenutaGreaterThan !== null) {
            queryParameters = queryParameters.set('ritenuta.greaterThan', ritenutaGreaterThan);
        }
        if (ritenutaGreaterThanOrEqual !== undefined && ritenutaGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('ritenuta.greaterThanOrEqual', ritenutaGreaterThanOrEqual);
        }
        if (ritenutaIn) {
            ritenutaIn.forEach(function (element) {
                queryParameters = queryParameters.append('ritenuta.in', element);
            });
        }
        if (ritenutaLessThan !== undefined && ritenutaLessThan !== null) {
            queryParameters = queryParameters.set('ritenuta.lessThan', ritenutaLessThan);
        }
        if (ritenutaLessThanOrEqual !== undefined && ritenutaLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('ritenuta.lessThanOrEqual', ritenutaLessThanOrEqual);
        }
        if (ritenutaNotEquals !== undefined && ritenutaNotEquals !== null) {
            queryParameters = queryParameters.set('ritenuta.notEquals', ritenutaNotEquals);
        }
        if (ritenutaSpecified !== undefined && ritenutaSpecified !== null) {
            queryParameters = queryParameters.set('ritenuta.specified', ritenutaSpecified);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        if (tipoContains !== undefined && tipoContains !== null) {
            queryParameters = queryParameters.set('tipo.contains', tipoContains);
        }
        if (tipoDoesNotContain !== undefined && tipoDoesNotContain !== null) {
            queryParameters = queryParameters.set('tipo.doesNotContain', tipoDoesNotContain);
        }
        if (tipoEquals !== undefined && tipoEquals !== null) {
            queryParameters = queryParameters.set('tipo.equals', tipoEquals);
        }
        if (tipoIn) {
            tipoIn.forEach(function (element) {
                queryParameters = queryParameters.append('tipo.in', element);
            });
        }
        if (tipoNotEquals !== undefined && tipoNotEquals !== null) {
            queryParameters = queryParameters.set('tipo.notEquals', tipoNotEquals);
        }
        if (tipoSpecified !== undefined && tipoSpecified !== null) {
            queryParameters = queryParameters.set('tipo.specified', tipoSpecified);
        }
        if (totaleEquals !== undefined && totaleEquals !== null) {
            queryParameters = queryParameters.set('totale.equals', totaleEquals);
        }
        if (totaleGreaterThan !== undefined && totaleGreaterThan !== null) {
            queryParameters = queryParameters.set('totale.greaterThan', totaleGreaterThan);
        }
        if (totaleGreaterThanOrEqual !== undefined && totaleGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('totale.greaterThanOrEqual', totaleGreaterThanOrEqual);
        }
        if (totaleIn) {
            totaleIn.forEach(function (element) {
                queryParameters = queryParameters.append('totale.in', element);
            });
        }
        if (totaleLessThan !== undefined && totaleLessThan !== null) {
            queryParameters = queryParameters.set('totale.lessThan', totaleLessThan);
        }
        if (totaleLessThanOrEqual !== undefined && totaleLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('totale.lessThanOrEqual', totaleLessThanOrEqual);
        }
        if (totaleNotEquals !== undefined && totaleNotEquals !== null) {
            queryParameters = queryParameters.set('totale.notEquals', totaleNotEquals);
        }
        if (totaleSpecified !== undefined && totaleSpecified !== null) {
            queryParameters = queryParameters.set('totale.specified', totaleSpecified);
        }
        if (totimponibileEquals !== undefined && totimponibileEquals !== null) {
            queryParameters = queryParameters.set('totimponibile.equals', totimponibileEquals);
        }
        if (totimponibileGreaterThan !== undefined && totimponibileGreaterThan !== null) {
            queryParameters = queryParameters.set('totimponibile.greaterThan', totimponibileGreaterThan);
        }
        if (totimponibileGreaterThanOrEqual !== undefined && totimponibileGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('totimponibile.greaterThanOrEqual', totimponibileGreaterThanOrEqual);
        }
        if (totimponibileIn) {
            totimponibileIn.forEach(function (element) {
                queryParameters = queryParameters.append('totimponibile.in', element);
            });
        }
        if (totimponibileLessThan !== undefined && totimponibileLessThan !== null) {
            queryParameters = queryParameters.set('totimponibile.lessThan', totimponibileLessThan);
        }
        if (totimponibileLessThanOrEqual !== undefined && totimponibileLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('totimponibile.lessThanOrEqual', totimponibileLessThanOrEqual);
        }
        if (totimponibileNotEquals !== undefined && totimponibileNotEquals !== null) {
            queryParameters = queryParameters.set('totimponibile.notEquals', totimponibileNotEquals);
        }
        if (totimponibileSpecified !== undefined && totimponibileSpecified !== null) {
            queryParameters = queryParameters.set('totimponibile.specified', totimponibileSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/apollo-documents", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentResourceService.prototype.getApolloDocumentUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getApolloDocumentUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/apollo-documents/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentResourceService.prototype.updateApolloDocumentUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateApolloDocumentUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/apollo-documents", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApolloDocumentResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ApolloDocumentResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ApolloDocumentResourceService);
    return ApolloDocumentResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ApplicationModuleResourceService = /** @class */ (function () {
    function ApplicationModuleResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ApplicationModuleResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ApplicationModuleResourceService.prototype.countApplicationModulesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/application-modules/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationModuleResourceService.prototype.createApplicationModuleUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createApplicationModuleUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/application-modules", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationModuleResourceService.prototype.deleteApplicationModuleUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteApplicationModuleUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/application-modules/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationModuleResourceService.prototype.getAllApplicationModulesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, page, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/application-modules", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationModuleResourceService.prototype.getApplicationModuleUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getApplicationModuleUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/application-modules/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationModuleResourceService.prototype.updateApplicationModuleUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateApplicationModuleUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/application-modules", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ApplicationModuleResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ApplicationModuleResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ApplicationModuleResourceService);
    return ApplicationModuleResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ContextGroupResourceService = /** @class */ (function () {
    function ContextGroupResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ContextGroupResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ContextGroupResourceService.prototype.countContextGroupsUsingGET = function (groupMemberOfIdEquals, groupMemberOfIdGreaterThan, groupMemberOfIdGreaterThanOrEqual, groupMemberOfIdIn, groupMemberOfIdLessThan, groupMemberOfIdLessThanOrEqual, groupMemberOfIdNotEquals, groupMemberOfIdSpecified, groupMembersIdEquals, groupMembersIdGreaterThan, groupMembersIdGreaterThanOrEqual, groupMembersIdIn, groupMembersIdLessThan, groupMembersIdLessThanOrEqual, groupMembersIdNotEquals, groupMembersIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, userMembersIdEquals, userMembersIdGreaterThan, userMembersIdGreaterThanOrEqual, userMembersIdIn, userMembersIdLessThan, userMembersIdLessThanOrEqual, userMembersIdNotEquals, userMembersIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (groupMemberOfIdEquals !== undefined && groupMemberOfIdEquals !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.equals', groupMemberOfIdEquals);
        }
        if (groupMemberOfIdGreaterThan !== undefined && groupMemberOfIdGreaterThan !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.greaterThan', groupMemberOfIdGreaterThan);
        }
        if (groupMemberOfIdGreaterThanOrEqual !== undefined && groupMemberOfIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.greaterThanOrEqual', groupMemberOfIdGreaterThanOrEqual);
        }
        if (groupMemberOfIdIn) {
            groupMemberOfIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('groupMemberOfId.in', element);
            });
        }
        if (groupMemberOfIdLessThan !== undefined && groupMemberOfIdLessThan !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.lessThan', groupMemberOfIdLessThan);
        }
        if (groupMemberOfIdLessThanOrEqual !== undefined && groupMemberOfIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.lessThanOrEqual', groupMemberOfIdLessThanOrEqual);
        }
        if (groupMemberOfIdNotEquals !== undefined && groupMemberOfIdNotEquals !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.notEquals', groupMemberOfIdNotEquals);
        }
        if (groupMemberOfIdSpecified !== undefined && groupMemberOfIdSpecified !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.specified', groupMemberOfIdSpecified);
        }
        if (groupMembersIdEquals !== undefined && groupMembersIdEquals !== null) {
            queryParameters = queryParameters.set('groupMembersId.equals', groupMembersIdEquals);
        }
        if (groupMembersIdGreaterThan !== undefined && groupMembersIdGreaterThan !== null) {
            queryParameters = queryParameters.set('groupMembersId.greaterThan', groupMembersIdGreaterThan);
        }
        if (groupMembersIdGreaterThanOrEqual !== undefined && groupMembersIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMembersId.greaterThanOrEqual', groupMembersIdGreaterThanOrEqual);
        }
        if (groupMembersIdIn) {
            groupMembersIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('groupMembersId.in', element);
            });
        }
        if (groupMembersIdLessThan !== undefined && groupMembersIdLessThan !== null) {
            queryParameters = queryParameters.set('groupMembersId.lessThan', groupMembersIdLessThan);
        }
        if (groupMembersIdLessThanOrEqual !== undefined && groupMembersIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMembersId.lessThanOrEqual', groupMembersIdLessThanOrEqual);
        }
        if (groupMembersIdNotEquals !== undefined && groupMembersIdNotEquals !== null) {
            queryParameters = queryParameters.set('groupMembersId.notEquals', groupMembersIdNotEquals);
        }
        if (groupMembersIdSpecified !== undefined && groupMembersIdSpecified !== null) {
            queryParameters = queryParameters.set('groupMembersId.specified', groupMembersIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (userMembersIdEquals !== undefined && userMembersIdEquals !== null) {
            queryParameters = queryParameters.set('userMembersId.equals', userMembersIdEquals);
        }
        if (userMembersIdGreaterThan !== undefined && userMembersIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userMembersId.greaterThan', userMembersIdGreaterThan);
        }
        if (userMembersIdGreaterThanOrEqual !== undefined && userMembersIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMembersId.greaterThanOrEqual', userMembersIdGreaterThanOrEqual);
        }
        if (userMembersIdIn) {
            userMembersIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userMembersId.in', element);
            });
        }
        if (userMembersIdLessThan !== undefined && userMembersIdLessThan !== null) {
            queryParameters = queryParameters.set('userMembersId.lessThan', userMembersIdLessThan);
        }
        if (userMembersIdLessThanOrEqual !== undefined && userMembersIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMembersId.lessThanOrEqual', userMembersIdLessThanOrEqual);
        }
        if (userMembersIdNotEquals !== undefined && userMembersIdNotEquals !== null) {
            queryParameters = queryParameters.set('userMembersId.notEquals', userMembersIdNotEquals);
        }
        if (userMembersIdSpecified !== undefined && userMembersIdSpecified !== null) {
            queryParameters = queryParameters.set('userMembersId.specified', userMembersIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-groups/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextGroupResourceService.prototype.createContextGroupUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createContextGroupUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/context-groups", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextGroupResourceService.prototype.deleteContextGroupUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteContextGroupUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/context-groups/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextGroupResourceService.prototype.getAllContextGroupsUsingGET = function (groupMemberOfIdEquals, groupMemberOfIdGreaterThan, groupMemberOfIdGreaterThanOrEqual, groupMemberOfIdIn, groupMemberOfIdLessThan, groupMemberOfIdLessThanOrEqual, groupMemberOfIdNotEquals, groupMemberOfIdSpecified, groupMembersIdEquals, groupMembersIdGreaterThan, groupMembersIdGreaterThanOrEqual, groupMembersIdIn, groupMembersIdLessThan, groupMembersIdLessThanOrEqual, groupMembersIdNotEquals, groupMembersIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, page, size, sort, userMembersIdEquals, userMembersIdGreaterThan, userMembersIdGreaterThanOrEqual, userMembersIdIn, userMembersIdLessThan, userMembersIdLessThanOrEqual, userMembersIdNotEquals, userMembersIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (groupMemberOfIdEquals !== undefined && groupMemberOfIdEquals !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.equals', groupMemberOfIdEquals);
        }
        if (groupMemberOfIdGreaterThan !== undefined && groupMemberOfIdGreaterThan !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.greaterThan', groupMemberOfIdGreaterThan);
        }
        if (groupMemberOfIdGreaterThanOrEqual !== undefined && groupMemberOfIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.greaterThanOrEqual', groupMemberOfIdGreaterThanOrEqual);
        }
        if (groupMemberOfIdIn) {
            groupMemberOfIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('groupMemberOfId.in', element);
            });
        }
        if (groupMemberOfIdLessThan !== undefined && groupMemberOfIdLessThan !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.lessThan', groupMemberOfIdLessThan);
        }
        if (groupMemberOfIdLessThanOrEqual !== undefined && groupMemberOfIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.lessThanOrEqual', groupMemberOfIdLessThanOrEqual);
        }
        if (groupMemberOfIdNotEquals !== undefined && groupMemberOfIdNotEquals !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.notEquals', groupMemberOfIdNotEquals);
        }
        if (groupMemberOfIdSpecified !== undefined && groupMemberOfIdSpecified !== null) {
            queryParameters = queryParameters.set('groupMemberOfId.specified', groupMemberOfIdSpecified);
        }
        if (groupMembersIdEquals !== undefined && groupMembersIdEquals !== null) {
            queryParameters = queryParameters.set('groupMembersId.equals', groupMembersIdEquals);
        }
        if (groupMembersIdGreaterThan !== undefined && groupMembersIdGreaterThan !== null) {
            queryParameters = queryParameters.set('groupMembersId.greaterThan', groupMembersIdGreaterThan);
        }
        if (groupMembersIdGreaterThanOrEqual !== undefined && groupMembersIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMembersId.greaterThanOrEqual', groupMembersIdGreaterThanOrEqual);
        }
        if (groupMembersIdIn) {
            groupMembersIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('groupMembersId.in', element);
            });
        }
        if (groupMembersIdLessThan !== undefined && groupMembersIdLessThan !== null) {
            queryParameters = queryParameters.set('groupMembersId.lessThan', groupMembersIdLessThan);
        }
        if (groupMembersIdLessThanOrEqual !== undefined && groupMembersIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupMembersId.lessThanOrEqual', groupMembersIdLessThanOrEqual);
        }
        if (groupMembersIdNotEquals !== undefined && groupMembersIdNotEquals !== null) {
            queryParameters = queryParameters.set('groupMembersId.notEquals', groupMembersIdNotEquals);
        }
        if (groupMembersIdSpecified !== undefined && groupMembersIdSpecified !== null) {
            queryParameters = queryParameters.set('groupMembersId.specified', groupMembersIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        if (userMembersIdEquals !== undefined && userMembersIdEquals !== null) {
            queryParameters = queryParameters.set('userMembersId.equals', userMembersIdEquals);
        }
        if (userMembersIdGreaterThan !== undefined && userMembersIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userMembersId.greaterThan', userMembersIdGreaterThan);
        }
        if (userMembersIdGreaterThanOrEqual !== undefined && userMembersIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMembersId.greaterThanOrEqual', userMembersIdGreaterThanOrEqual);
        }
        if (userMembersIdIn) {
            userMembersIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userMembersId.in', element);
            });
        }
        if (userMembersIdLessThan !== undefined && userMembersIdLessThan !== null) {
            queryParameters = queryParameters.set('userMembersId.lessThan', userMembersIdLessThan);
        }
        if (userMembersIdLessThanOrEqual !== undefined && userMembersIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMembersId.lessThanOrEqual', userMembersIdLessThanOrEqual);
        }
        if (userMembersIdNotEquals !== undefined && userMembersIdNotEquals !== null) {
            queryParameters = queryParameters.set('userMembersId.notEquals', userMembersIdNotEquals);
        }
        if (userMembersIdSpecified !== undefined && userMembersIdSpecified !== null) {
            queryParameters = queryParameters.set('userMembersId.specified', userMembersIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-groups", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextGroupResourceService.prototype.getContextGroupUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getContextGroupUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-groups/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextGroupResourceService.prototype.updateContextGroupUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateContextGroupUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/context-groups", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextGroupResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ContextGroupResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ContextGroupResourceService);
    return ContextGroupResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ContextModuleResourceService = /** @class */ (function () {
    function ContextModuleResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ContextModuleResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ContextModuleResourceService.prototype.countContextModulesUsingGET = function (activeEquals, activeIn, activeNotEquals, activeSpecified, contextIdEquals, contextIdGreaterThan, contextIdGreaterThanOrEqual, contextIdIn, contextIdLessThan, contextIdLessThanOrEqual, contextIdNotEquals, contextIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, moduleIdEquals, moduleIdGreaterThan, moduleIdGreaterThanOrEqual, moduleIdIn, moduleIdLessThan, moduleIdLessThanOrEqual, moduleIdNotEquals, moduleIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (activeEquals !== undefined && activeEquals !== null) {
            queryParameters = queryParameters.set('active.equals', activeEquals);
        }
        if (activeIn) {
            activeIn.forEach(function (element) {
                queryParameters = queryParameters.append('active.in', element);
            });
        }
        if (activeNotEquals !== undefined && activeNotEquals !== null) {
            queryParameters = queryParameters.set('active.notEquals', activeNotEquals);
        }
        if (activeSpecified !== undefined && activeSpecified !== null) {
            queryParameters = queryParameters.set('active.specified', activeSpecified);
        }
        if (contextIdEquals !== undefined && contextIdEquals !== null) {
            queryParameters = queryParameters.set('contextId.equals', contextIdEquals);
        }
        if (contextIdGreaterThan !== undefined && contextIdGreaterThan !== null) {
            queryParameters = queryParameters.set('contextId.greaterThan', contextIdGreaterThan);
        }
        if (contextIdGreaterThanOrEqual !== undefined && contextIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.greaterThanOrEqual', contextIdGreaterThanOrEqual);
        }
        if (contextIdIn) {
            contextIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextId.in', element);
            });
        }
        if (contextIdLessThan !== undefined && contextIdLessThan !== null) {
            queryParameters = queryParameters.set('contextId.lessThan', contextIdLessThan);
        }
        if (contextIdLessThanOrEqual !== undefined && contextIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.lessThanOrEqual', contextIdLessThanOrEqual);
        }
        if (contextIdNotEquals !== undefined && contextIdNotEquals !== null) {
            queryParameters = queryParameters.set('contextId.notEquals', contextIdNotEquals);
        }
        if (contextIdSpecified !== undefined && contextIdSpecified !== null) {
            queryParameters = queryParameters.set('contextId.specified', contextIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (moduleIdEquals !== undefined && moduleIdEquals !== null) {
            queryParameters = queryParameters.set('moduleId.equals', moduleIdEquals);
        }
        if (moduleIdGreaterThan !== undefined && moduleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThan', moduleIdGreaterThan);
        }
        if (moduleIdGreaterThanOrEqual !== undefined && moduleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThanOrEqual', moduleIdGreaterThanOrEqual);
        }
        if (moduleIdIn) {
            moduleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('moduleId.in', element);
            });
        }
        if (moduleIdLessThan !== undefined && moduleIdLessThan !== null) {
            queryParameters = queryParameters.set('moduleId.lessThan', moduleIdLessThan);
        }
        if (moduleIdLessThanOrEqual !== undefined && moduleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.lessThanOrEqual', moduleIdLessThanOrEqual);
        }
        if (moduleIdNotEquals !== undefined && moduleIdNotEquals !== null) {
            queryParameters = queryParameters.set('moduleId.notEquals', moduleIdNotEquals);
        }
        if (moduleIdSpecified !== undefined && moduleIdSpecified !== null) {
            queryParameters = queryParameters.set('moduleId.specified', moduleIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/context-modules/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextModuleResourceService.prototype.createContextModuleUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createContextModuleUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/context-modules", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextModuleResourceService.prototype.deleteContextModuleUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteContextModuleUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/context-modules/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextModuleResourceService.prototype.getAllContextModulesUsingGET = function (activeEquals, activeIn, activeNotEquals, activeSpecified, contextIdEquals, contextIdGreaterThan, contextIdGreaterThanOrEqual, contextIdIn, contextIdLessThan, contextIdLessThanOrEqual, contextIdNotEquals, contextIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, moduleIdEquals, moduleIdGreaterThan, moduleIdGreaterThanOrEqual, moduleIdIn, moduleIdLessThan, moduleIdLessThanOrEqual, moduleIdNotEquals, moduleIdSpecified, page, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (activeEquals !== undefined && activeEquals !== null) {
            queryParameters = queryParameters.set('active.equals', activeEquals);
        }
        if (activeIn) {
            activeIn.forEach(function (element) {
                queryParameters = queryParameters.append('active.in', element);
            });
        }
        if (activeNotEquals !== undefined && activeNotEquals !== null) {
            queryParameters = queryParameters.set('active.notEquals', activeNotEquals);
        }
        if (activeSpecified !== undefined && activeSpecified !== null) {
            queryParameters = queryParameters.set('active.specified', activeSpecified);
        }
        if (contextIdEquals !== undefined && contextIdEquals !== null) {
            queryParameters = queryParameters.set('contextId.equals', contextIdEquals);
        }
        if (contextIdGreaterThan !== undefined && contextIdGreaterThan !== null) {
            queryParameters = queryParameters.set('contextId.greaterThan', contextIdGreaterThan);
        }
        if (contextIdGreaterThanOrEqual !== undefined && contextIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.greaterThanOrEqual', contextIdGreaterThanOrEqual);
        }
        if (contextIdIn) {
            contextIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextId.in', element);
            });
        }
        if (contextIdLessThan !== undefined && contextIdLessThan !== null) {
            queryParameters = queryParameters.set('contextId.lessThan', contextIdLessThan);
        }
        if (contextIdLessThanOrEqual !== undefined && contextIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.lessThanOrEqual', contextIdLessThanOrEqual);
        }
        if (contextIdNotEquals !== undefined && contextIdNotEquals !== null) {
            queryParameters = queryParameters.set('contextId.notEquals', contextIdNotEquals);
        }
        if (contextIdSpecified !== undefined && contextIdSpecified !== null) {
            queryParameters = queryParameters.set('contextId.specified', contextIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (moduleIdEquals !== undefined && moduleIdEquals !== null) {
            queryParameters = queryParameters.set('moduleId.equals', moduleIdEquals);
        }
        if (moduleIdGreaterThan !== undefined && moduleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThan', moduleIdGreaterThan);
        }
        if (moduleIdGreaterThanOrEqual !== undefined && moduleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThanOrEqual', moduleIdGreaterThanOrEqual);
        }
        if (moduleIdIn) {
            moduleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('moduleId.in', element);
            });
        }
        if (moduleIdLessThan !== undefined && moduleIdLessThan !== null) {
            queryParameters = queryParameters.set('moduleId.lessThan', moduleIdLessThan);
        }
        if (moduleIdLessThanOrEqual !== undefined && moduleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.lessThanOrEqual', moduleIdLessThanOrEqual);
        }
        if (moduleIdNotEquals !== undefined && moduleIdNotEquals !== null) {
            queryParameters = queryParameters.set('moduleId.notEquals', moduleIdNotEquals);
        }
        if (moduleIdSpecified !== undefined && moduleIdSpecified !== null) {
            queryParameters = queryParameters.set('moduleId.specified', moduleIdSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/context-modules", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextModuleResourceService.prototype.getContextModuleUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getContextModuleUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/context-modules/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextModuleResourceService.prototype.updateContextModuleUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateContextModuleUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/context-modules", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextModuleResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ContextModuleResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ContextModuleResourceService);
    return ContextModuleResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ContextUserEopooResourceService = /** @class */ (function () {
    function ContextUserEopooResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ContextUserEopooResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ContextUserEopooResourceService.prototype.countContextUserEopoosUsingGET = function (contextUserIdEquals, contextUserIdGreaterThan, contextUserIdGreaterThanOrEqual, contextUserIdIn, contextUserIdLessThan, contextUserIdLessThanOrEqual, contextUserIdNotEquals, contextUserIdSpecified, eopooCodeContains, eopooCodeDoesNotContain, eopooCodeEquals, eopooCodeIn, eopooCodeNotEquals, eopooCodeSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextUserIdEquals !== undefined && contextUserIdEquals !== null) {
            queryParameters = queryParameters.set('contextUserId.equals', contextUserIdEquals);
        }
        if (contextUserIdGreaterThan !== undefined && contextUserIdGreaterThan !== null) {
            queryParameters = queryParameters.set('contextUserId.greaterThan', contextUserIdGreaterThan);
        }
        if (contextUserIdGreaterThanOrEqual !== undefined && contextUserIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextUserId.greaterThanOrEqual', contextUserIdGreaterThanOrEqual);
        }
        if (contextUserIdIn) {
            contextUserIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextUserId.in', element);
            });
        }
        if (contextUserIdLessThan !== undefined && contextUserIdLessThan !== null) {
            queryParameters = queryParameters.set('contextUserId.lessThan', contextUserIdLessThan);
        }
        if (contextUserIdLessThanOrEqual !== undefined && contextUserIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextUserId.lessThanOrEqual', contextUserIdLessThanOrEqual);
        }
        if (contextUserIdNotEquals !== undefined && contextUserIdNotEquals !== null) {
            queryParameters = queryParameters.set('contextUserId.notEquals', contextUserIdNotEquals);
        }
        if (contextUserIdSpecified !== undefined && contextUserIdSpecified !== null) {
            queryParameters = queryParameters.set('contextUserId.specified', contextUserIdSpecified);
        }
        if (eopooCodeContains !== undefined && eopooCodeContains !== null) {
            queryParameters = queryParameters.set('eopooCode.contains', eopooCodeContains);
        }
        if (eopooCodeDoesNotContain !== undefined && eopooCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('eopooCode.doesNotContain', eopooCodeDoesNotContain);
        }
        if (eopooCodeEquals !== undefined && eopooCodeEquals !== null) {
            queryParameters = queryParameters.set('eopooCode.equals', eopooCodeEquals);
        }
        if (eopooCodeIn) {
            eopooCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('eopooCode.in', element);
            });
        }
        if (eopooCodeNotEquals !== undefined && eopooCodeNotEquals !== null) {
            queryParameters = queryParameters.set('eopooCode.notEquals', eopooCodeNotEquals);
        }
        if (eopooCodeSpecified !== undefined && eopooCodeSpecified !== null) {
            queryParameters = queryParameters.set('eopooCode.specified', eopooCodeSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-user-eopoos/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserEopooResourceService.prototype.createContextUserEopooUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createContextUserEopooUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/context-user-eopoos", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserEopooResourceService.prototype.deleteContextUserEopooUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteContextUserEopooUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/context-user-eopoos/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserEopooResourceService.prototype.getAllContextUserEopoosUsingGET = function (contextUserIdEquals, contextUserIdGreaterThan, contextUserIdGreaterThanOrEqual, contextUserIdIn, contextUserIdLessThan, contextUserIdLessThanOrEqual, contextUserIdNotEquals, contextUserIdSpecified, eopooCodeContains, eopooCodeDoesNotContain, eopooCodeEquals, eopooCodeIn, eopooCodeNotEquals, eopooCodeSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, page, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextUserIdEquals !== undefined && contextUserIdEquals !== null) {
            queryParameters = queryParameters.set('contextUserId.equals', contextUserIdEquals);
        }
        if (contextUserIdGreaterThan !== undefined && contextUserIdGreaterThan !== null) {
            queryParameters = queryParameters.set('contextUserId.greaterThan', contextUserIdGreaterThan);
        }
        if (contextUserIdGreaterThanOrEqual !== undefined && contextUserIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextUserId.greaterThanOrEqual', contextUserIdGreaterThanOrEqual);
        }
        if (contextUserIdIn) {
            contextUserIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextUserId.in', element);
            });
        }
        if (contextUserIdLessThan !== undefined && contextUserIdLessThan !== null) {
            queryParameters = queryParameters.set('contextUserId.lessThan', contextUserIdLessThan);
        }
        if (contextUserIdLessThanOrEqual !== undefined && contextUserIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextUserId.lessThanOrEqual', contextUserIdLessThanOrEqual);
        }
        if (contextUserIdNotEquals !== undefined && contextUserIdNotEquals !== null) {
            queryParameters = queryParameters.set('contextUserId.notEquals', contextUserIdNotEquals);
        }
        if (contextUserIdSpecified !== undefined && contextUserIdSpecified !== null) {
            queryParameters = queryParameters.set('contextUserId.specified', contextUserIdSpecified);
        }
        if (eopooCodeContains !== undefined && eopooCodeContains !== null) {
            queryParameters = queryParameters.set('eopooCode.contains', eopooCodeContains);
        }
        if (eopooCodeDoesNotContain !== undefined && eopooCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('eopooCode.doesNotContain', eopooCodeDoesNotContain);
        }
        if (eopooCodeEquals !== undefined && eopooCodeEquals !== null) {
            queryParameters = queryParameters.set('eopooCode.equals', eopooCodeEquals);
        }
        if (eopooCodeIn) {
            eopooCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('eopooCode.in', element);
            });
        }
        if (eopooCodeNotEquals !== undefined && eopooCodeNotEquals !== null) {
            queryParameters = queryParameters.set('eopooCode.notEquals', eopooCodeNotEquals);
        }
        if (eopooCodeSpecified !== undefined && eopooCodeSpecified !== null) {
            queryParameters = queryParameters.set('eopooCode.specified', eopooCodeSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-user-eopoos", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserEopooResourceService.prototype.getContextUserEopooUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getContextUserEopooUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-user-eopoos/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserEopooResourceService.prototype.updateContextUserEopooUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateContextUserEopooUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/context-user-eopoos", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserEopooResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ContextUserEopooResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ContextUserEopooResourceService);
    return ContextUserEopooResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var ContextUserResourceService = /** @class */ (function () {
    function ContextUserResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    ContextUserResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    ContextUserResourceService.prototype.countContextUsersUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, statusEquals, statusIn, statusNotEquals, statusSpecified, typeEquals, typeIn, typeNotEquals, typeSpecified, userCodeContains, userCodeDoesNotContain, userCodeEquals, userCodeIn, userCodeNotEquals, userCodeSpecified, userMemberOfIdEquals, userMemberOfIdGreaterThan, userMemberOfIdGreaterThanOrEqual, userMemberOfIdIn, userMemberOfIdLessThan, userMemberOfIdLessThanOrEqual, userMemberOfIdNotEquals, userMemberOfIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (statusEquals !== undefined && statusEquals !== null) {
            queryParameters = queryParameters.set('status.equals', statusEquals);
        }
        if (statusIn) {
            statusIn.forEach(function (element) {
                queryParameters = queryParameters.append('status.in', element);
            });
        }
        if (statusNotEquals !== undefined && statusNotEquals !== null) {
            queryParameters = queryParameters.set('status.notEquals', statusNotEquals);
        }
        if (statusSpecified !== undefined && statusSpecified !== null) {
            queryParameters = queryParameters.set('status.specified', statusSpecified);
        }
        if (typeEquals !== undefined && typeEquals !== null) {
            queryParameters = queryParameters.set('type.equals', typeEquals);
        }
        if (typeIn) {
            typeIn.forEach(function (element) {
                queryParameters = queryParameters.append('type.in', element);
            });
        }
        if (typeNotEquals !== undefined && typeNotEquals !== null) {
            queryParameters = queryParameters.set('type.notEquals', typeNotEquals);
        }
        if (typeSpecified !== undefined && typeSpecified !== null) {
            queryParameters = queryParameters.set('type.specified', typeSpecified);
        }
        if (userCodeContains !== undefined && userCodeContains !== null) {
            queryParameters = queryParameters.set('userCode.contains', userCodeContains);
        }
        if (userCodeDoesNotContain !== undefined && userCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('userCode.doesNotContain', userCodeDoesNotContain);
        }
        if (userCodeEquals !== undefined && userCodeEquals !== null) {
            queryParameters = queryParameters.set('userCode.equals', userCodeEquals);
        }
        if (userCodeIn) {
            userCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('userCode.in', element);
            });
        }
        if (userCodeNotEquals !== undefined && userCodeNotEquals !== null) {
            queryParameters = queryParameters.set('userCode.notEquals', userCodeNotEquals);
        }
        if (userCodeSpecified !== undefined && userCodeSpecified !== null) {
            queryParameters = queryParameters.set('userCode.specified', userCodeSpecified);
        }
        if (userMemberOfIdEquals !== undefined && userMemberOfIdEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.equals', userMemberOfIdEquals);
        }
        if (userMemberOfIdGreaterThan !== undefined && userMemberOfIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThan', userMemberOfIdGreaterThan);
        }
        if (userMemberOfIdGreaterThanOrEqual !== undefined && userMemberOfIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThanOrEqual', userMemberOfIdGreaterThanOrEqual);
        }
        if (userMemberOfIdIn) {
            userMemberOfIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userMemberOfId.in', element);
            });
        }
        if (userMemberOfIdLessThan !== undefined && userMemberOfIdLessThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThan', userMemberOfIdLessThan);
        }
        if (userMemberOfIdLessThanOrEqual !== undefined && userMemberOfIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThanOrEqual', userMemberOfIdLessThanOrEqual);
        }
        if (userMemberOfIdNotEquals !== undefined && userMemberOfIdNotEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.notEquals', userMemberOfIdNotEquals);
        }
        if (userMemberOfIdSpecified !== undefined && userMemberOfIdSpecified !== null) {
            queryParameters = queryParameters.set('userMemberOfId.specified', userMemberOfIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-users/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserResourceService.prototype.createContextUserUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createContextUserUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/context-users", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserResourceService.prototype.deleteContextUserUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteContextUserUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/context-users/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserResourceService.prototype.getAllContextUsersUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, page, size, sort, statusEquals, statusIn, statusNotEquals, statusSpecified, typeEquals, typeIn, typeNotEquals, typeSpecified, userCodeContains, userCodeDoesNotContain, userCodeEquals, userCodeIn, userCodeNotEquals, userCodeSpecified, userMemberOfIdEquals, userMemberOfIdGreaterThan, userMemberOfIdGreaterThanOrEqual, userMemberOfIdIn, userMemberOfIdLessThan, userMemberOfIdLessThanOrEqual, userMemberOfIdNotEquals, userMemberOfIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        if (statusEquals !== undefined && statusEquals !== null) {
            queryParameters = queryParameters.set('status.equals', statusEquals);
        }
        if (statusIn) {
            statusIn.forEach(function (element) {
                queryParameters = queryParameters.append('status.in', element);
            });
        }
        if (statusNotEquals !== undefined && statusNotEquals !== null) {
            queryParameters = queryParameters.set('status.notEquals', statusNotEquals);
        }
        if (statusSpecified !== undefined && statusSpecified !== null) {
            queryParameters = queryParameters.set('status.specified', statusSpecified);
        }
        if (typeEquals !== undefined && typeEquals !== null) {
            queryParameters = queryParameters.set('type.equals', typeEquals);
        }
        if (typeIn) {
            typeIn.forEach(function (element) {
                queryParameters = queryParameters.append('type.in', element);
            });
        }
        if (typeNotEquals !== undefined && typeNotEquals !== null) {
            queryParameters = queryParameters.set('type.notEquals', typeNotEquals);
        }
        if (typeSpecified !== undefined && typeSpecified !== null) {
            queryParameters = queryParameters.set('type.specified', typeSpecified);
        }
        if (userCodeContains !== undefined && userCodeContains !== null) {
            queryParameters = queryParameters.set('userCode.contains', userCodeContains);
        }
        if (userCodeDoesNotContain !== undefined && userCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('userCode.doesNotContain', userCodeDoesNotContain);
        }
        if (userCodeEquals !== undefined && userCodeEquals !== null) {
            queryParameters = queryParameters.set('userCode.equals', userCodeEquals);
        }
        if (userCodeIn) {
            userCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('userCode.in', element);
            });
        }
        if (userCodeNotEquals !== undefined && userCodeNotEquals !== null) {
            queryParameters = queryParameters.set('userCode.notEquals', userCodeNotEquals);
        }
        if (userCodeSpecified !== undefined && userCodeSpecified !== null) {
            queryParameters = queryParameters.set('userCode.specified', userCodeSpecified);
        }
        if (userMemberOfIdEquals !== undefined && userMemberOfIdEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.equals', userMemberOfIdEquals);
        }
        if (userMemberOfIdGreaterThan !== undefined && userMemberOfIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThan', userMemberOfIdGreaterThan);
        }
        if (userMemberOfIdGreaterThanOrEqual !== undefined && userMemberOfIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThanOrEqual', userMemberOfIdGreaterThanOrEqual);
        }
        if (userMemberOfIdIn) {
            userMemberOfIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userMemberOfId.in', element);
            });
        }
        if (userMemberOfIdLessThan !== undefined && userMemberOfIdLessThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThan', userMemberOfIdLessThan);
        }
        if (userMemberOfIdLessThanOrEqual !== undefined && userMemberOfIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThanOrEqual', userMemberOfIdLessThanOrEqual);
        }
        if (userMemberOfIdNotEquals !== undefined && userMemberOfIdNotEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.notEquals', userMemberOfIdNotEquals);
        }
        if (userMemberOfIdSpecified !== undefined && userMemberOfIdSpecified !== null) {
            queryParameters = queryParameters.set('userMemberOfId.specified', userMemberOfIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-users", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserResourceService.prototype.getContextUserUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getContextUserUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-users/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserResourceService.prototype.updateContextUserUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateContextUserUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/context-users", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    ContextUserResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    ContextUserResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], ContextUserResourceService);
    return ContextUserResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var CustomRolePermissionResourceService = /** @class */ (function () {
    function CustomRolePermissionResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    CustomRolePermissionResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    CustomRolePermissionResourceService.prototype.countCustomRolePermissionsUsingGET = function (allViewEquals, allViewIn, allViewNotEquals, allViewSpecified, filteredEquals, filteredIn, filteredNotEquals, filteredSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, permissionCodeContains, permissionCodeDoesNotContain, permissionCodeEquals, permissionCodeIn, permissionCodeNotEquals, permissionCodeSpecified, roleIdEquals, roleIdGreaterThan, roleIdGreaterThanOrEqual, roleIdIn, roleIdLessThan, roleIdLessThanOrEqual, roleIdNotEquals, roleIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (allViewEquals !== undefined && allViewEquals !== null) {
            queryParameters = queryParameters.set('allView.equals', allViewEquals);
        }
        if (allViewIn) {
            allViewIn.forEach(function (element) {
                queryParameters = queryParameters.append('allView.in', element);
            });
        }
        if (allViewNotEquals !== undefined && allViewNotEquals !== null) {
            queryParameters = queryParameters.set('allView.notEquals', allViewNotEquals);
        }
        if (allViewSpecified !== undefined && allViewSpecified !== null) {
            queryParameters = queryParameters.set('allView.specified', allViewSpecified);
        }
        if (filteredEquals !== undefined && filteredEquals !== null) {
            queryParameters = queryParameters.set('filtered.equals', filteredEquals);
        }
        if (filteredIn) {
            filteredIn.forEach(function (element) {
                queryParameters = queryParameters.append('filtered.in', element);
            });
        }
        if (filteredNotEquals !== undefined && filteredNotEquals !== null) {
            queryParameters = queryParameters.set('filtered.notEquals', filteredNotEquals);
        }
        if (filteredSpecified !== undefined && filteredSpecified !== null) {
            queryParameters = queryParameters.set('filtered.specified', filteredSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (permissionCodeContains !== undefined && permissionCodeContains !== null) {
            queryParameters = queryParameters.set('permissionCode.contains', permissionCodeContains);
        }
        if (permissionCodeDoesNotContain !== undefined && permissionCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('permissionCode.doesNotContain', permissionCodeDoesNotContain);
        }
        if (permissionCodeEquals !== undefined && permissionCodeEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.equals', permissionCodeEquals);
        }
        if (permissionCodeIn) {
            permissionCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('permissionCode.in', element);
            });
        }
        if (permissionCodeNotEquals !== undefined && permissionCodeNotEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.notEquals', permissionCodeNotEquals);
        }
        if (permissionCodeSpecified !== undefined && permissionCodeSpecified !== null) {
            queryParameters = queryParameters.set('permissionCode.specified', permissionCodeSpecified);
        }
        if (roleIdEquals !== undefined && roleIdEquals !== null) {
            queryParameters = queryParameters.set('roleId.equals', roleIdEquals);
        }
        if (roleIdGreaterThan !== undefined && roleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('roleId.greaterThan', roleIdGreaterThan);
        }
        if (roleIdGreaterThanOrEqual !== undefined && roleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.greaterThanOrEqual', roleIdGreaterThanOrEqual);
        }
        if (roleIdIn) {
            roleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleId.in', element);
            });
        }
        if (roleIdLessThan !== undefined && roleIdLessThan !== null) {
            queryParameters = queryParameters.set('roleId.lessThan', roleIdLessThan);
        }
        if (roleIdLessThanOrEqual !== undefined && roleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.lessThanOrEqual', roleIdLessThanOrEqual);
        }
        if (roleIdNotEquals !== undefined && roleIdNotEquals !== null) {
            queryParameters = queryParameters.set('roleId.notEquals', roleIdNotEquals);
        }
        if (roleIdSpecified !== undefined && roleIdSpecified !== null) {
            queryParameters = queryParameters.set('roleId.specified', roleIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/custom-role-permissions/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRolePermissionResourceService.prototype.createCustomRolePermissionUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createCustomRolePermissionUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/custom-role-permissions", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRolePermissionResourceService.prototype.deleteCustomRolePermissionUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteCustomRolePermissionUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/custom-role-permissions/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRolePermissionResourceService.prototype.getAllCustomRolePermissionsUsingGET = function (allViewEquals, allViewIn, allViewNotEquals, allViewSpecified, filteredEquals, filteredIn, filteredNotEquals, filteredSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, page, permissionCodeContains, permissionCodeDoesNotContain, permissionCodeEquals, permissionCodeIn, permissionCodeNotEquals, permissionCodeSpecified, roleIdEquals, roleIdGreaterThan, roleIdGreaterThanOrEqual, roleIdIn, roleIdLessThan, roleIdLessThanOrEqual, roleIdNotEquals, roleIdSpecified, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (allViewEquals !== undefined && allViewEquals !== null) {
            queryParameters = queryParameters.set('allView.equals', allViewEquals);
        }
        if (allViewIn) {
            allViewIn.forEach(function (element) {
                queryParameters = queryParameters.append('allView.in', element);
            });
        }
        if (allViewNotEquals !== undefined && allViewNotEquals !== null) {
            queryParameters = queryParameters.set('allView.notEquals', allViewNotEquals);
        }
        if (allViewSpecified !== undefined && allViewSpecified !== null) {
            queryParameters = queryParameters.set('allView.specified', allViewSpecified);
        }
        if (filteredEquals !== undefined && filteredEquals !== null) {
            queryParameters = queryParameters.set('filtered.equals', filteredEquals);
        }
        if (filteredIn) {
            filteredIn.forEach(function (element) {
                queryParameters = queryParameters.append('filtered.in', element);
            });
        }
        if (filteredNotEquals !== undefined && filteredNotEquals !== null) {
            queryParameters = queryParameters.set('filtered.notEquals', filteredNotEquals);
        }
        if (filteredSpecified !== undefined && filteredSpecified !== null) {
            queryParameters = queryParameters.set('filtered.specified', filteredSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (permissionCodeContains !== undefined && permissionCodeContains !== null) {
            queryParameters = queryParameters.set('permissionCode.contains', permissionCodeContains);
        }
        if (permissionCodeDoesNotContain !== undefined && permissionCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('permissionCode.doesNotContain', permissionCodeDoesNotContain);
        }
        if (permissionCodeEquals !== undefined && permissionCodeEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.equals', permissionCodeEquals);
        }
        if (permissionCodeIn) {
            permissionCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('permissionCode.in', element);
            });
        }
        if (permissionCodeNotEquals !== undefined && permissionCodeNotEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.notEquals', permissionCodeNotEquals);
        }
        if (permissionCodeSpecified !== undefined && permissionCodeSpecified !== null) {
            queryParameters = queryParameters.set('permissionCode.specified', permissionCodeSpecified);
        }
        if (roleIdEquals !== undefined && roleIdEquals !== null) {
            queryParameters = queryParameters.set('roleId.equals', roleIdEquals);
        }
        if (roleIdGreaterThan !== undefined && roleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('roleId.greaterThan', roleIdGreaterThan);
        }
        if (roleIdGreaterThanOrEqual !== undefined && roleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.greaterThanOrEqual', roleIdGreaterThanOrEqual);
        }
        if (roleIdIn) {
            roleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleId.in', element);
            });
        }
        if (roleIdLessThan !== undefined && roleIdLessThan !== null) {
            queryParameters = queryParameters.set('roleId.lessThan', roleIdLessThan);
        }
        if (roleIdLessThanOrEqual !== undefined && roleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.lessThanOrEqual', roleIdLessThanOrEqual);
        }
        if (roleIdNotEquals !== undefined && roleIdNotEquals !== null) {
            queryParameters = queryParameters.set('roleId.notEquals', roleIdNotEquals);
        }
        if (roleIdSpecified !== undefined && roleIdSpecified !== null) {
            queryParameters = queryParameters.set('roleId.specified', roleIdSpecified);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/custom-role-permissions", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRolePermissionResourceService.prototype.getCustomRolePermissionUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomRolePermissionUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/custom-role-permissions/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRolePermissionResourceService.prototype.updateCustomRolePermissionUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateCustomRolePermissionUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/custom-role-permissions", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRolePermissionResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    CustomRolePermissionResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], CustomRolePermissionResourceService);
    return CustomRolePermissionResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var CustomRoleResourceService = /** @class */ (function () {
    function CustomRoleResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    CustomRoleResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    CustomRoleResourceService.prototype.countCustomRolesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/custom-roles/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRoleResourceService.prototype.createCustomRoleUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createCustomRoleUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/custom-roles", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRoleResourceService.prototype.deleteCustomRoleUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteCustomRoleUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/custom-roles/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRoleResourceService.prototype.getAllCustomRolesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, page, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/custom-roles", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRoleResourceService.prototype.getCustomRoleUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomRoleUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/custom-roles/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRoleResourceService.prototype.updateCustomRoleUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateCustomRoleUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/custom-roles", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    CustomRoleResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    CustomRoleResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], CustomRoleResourceService);
    return CustomRoleResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var EntityReferenceResourceService = /** @class */ (function () {
    function EntityReferenceResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    EntityReferenceResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    EntityReferenceResourceService.prototype.countEntityReferencesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, moduleIdEquals, moduleIdGreaterThan, moduleIdGreaterThanOrEqual, moduleIdIn, moduleIdLessThan, moduleIdLessThanOrEqual, moduleIdNotEquals, moduleIdSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (moduleIdEquals !== undefined && moduleIdEquals !== null) {
            queryParameters = queryParameters.set('moduleId.equals', moduleIdEquals);
        }
        if (moduleIdGreaterThan !== undefined && moduleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThan', moduleIdGreaterThan);
        }
        if (moduleIdGreaterThanOrEqual !== undefined && moduleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThanOrEqual', moduleIdGreaterThanOrEqual);
        }
        if (moduleIdIn) {
            moduleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('moduleId.in', element);
            });
        }
        if (moduleIdLessThan !== undefined && moduleIdLessThan !== null) {
            queryParameters = queryParameters.set('moduleId.lessThan', moduleIdLessThan);
        }
        if (moduleIdLessThanOrEqual !== undefined && moduleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.lessThanOrEqual', moduleIdLessThanOrEqual);
        }
        if (moduleIdNotEquals !== undefined && moduleIdNotEquals !== null) {
            queryParameters = queryParameters.set('moduleId.notEquals', moduleIdNotEquals);
        }
        if (moduleIdSpecified !== undefined && moduleIdSpecified !== null) {
            queryParameters = queryParameters.set('moduleId.specified', moduleIdSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/entity-references/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EntityReferenceResourceService.prototype.createEntityReferenceUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createEntityReferenceUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/entity-references", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EntityReferenceResourceService.prototype.deleteEntityReferenceUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteEntityReferenceUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/entity-references/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EntityReferenceResourceService.prototype.getAllEntityReferencesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, moduleIdEquals, moduleIdGreaterThan, moduleIdGreaterThanOrEqual, moduleIdIn, moduleIdLessThan, moduleIdLessThanOrEqual, moduleIdNotEquals, moduleIdSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, page, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (moduleIdEquals !== undefined && moduleIdEquals !== null) {
            queryParameters = queryParameters.set('moduleId.equals', moduleIdEquals);
        }
        if (moduleIdGreaterThan !== undefined && moduleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThan', moduleIdGreaterThan);
        }
        if (moduleIdGreaterThanOrEqual !== undefined && moduleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThanOrEqual', moduleIdGreaterThanOrEqual);
        }
        if (moduleIdIn) {
            moduleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('moduleId.in', element);
            });
        }
        if (moduleIdLessThan !== undefined && moduleIdLessThan !== null) {
            queryParameters = queryParameters.set('moduleId.lessThan', moduleIdLessThan);
        }
        if (moduleIdLessThanOrEqual !== undefined && moduleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.lessThanOrEqual', moduleIdLessThanOrEqual);
        }
        if (moduleIdNotEquals !== undefined && moduleIdNotEquals !== null) {
            queryParameters = queryParameters.set('moduleId.notEquals', moduleIdNotEquals);
        }
        if (moduleIdSpecified !== undefined && moduleIdSpecified !== null) {
            queryParameters = queryParameters.set('moduleId.specified', moduleIdSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/entity-references", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EntityReferenceResourceService.prototype.getEntityReferenceUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getEntityReferenceUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/entity-references/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EntityReferenceResourceService.prototype.updateEntityReferenceUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateEntityReferenceUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/entity-references", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EntityReferenceResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    EntityReferenceResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], EntityReferenceResourceService);
    return EntityReferenceResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var EopooApiControllerService = /** @class */ (function () {
    function EopooApiControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    EopooApiControllerService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    EopooApiControllerService.prototype.addEopoo = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling addEopoo.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/ws/eopoo", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    EopooApiControllerService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    EopooApiControllerService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], EopooApiControllerService);
    return EopooApiControllerService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var FatturaPaService = /** @class */ (function () {
    function FatturaPaService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    FatturaPaService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    FatturaPaService.prototype.generateFatturaPa = function (id, type, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling generateFatturaPa.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling generateFatturaPa.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (id !== undefined && id !== null) {
            queryParameters = queryParameters.set('id', id);
        }
        if (type !== undefined && type !== null) {
            queryParameters = queryParameters.set('type', type);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/ws/generate-fattura-pa", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    FatturaPaService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    FatturaPaService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], FatturaPaService);
    return FatturaPaService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var PermissionResourceService = /** @class */ (function () {
    function PermissionResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    PermissionResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    PermissionResourceService.prototype.countPermissionsUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, moduleIdEquals, moduleIdGreaterThan, moduleIdGreaterThanOrEqual, moduleIdIn, moduleIdLessThan, moduleIdLessThanOrEqual, moduleIdNotEquals, moduleIdSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, permissionCodeContains, permissionCodeDoesNotContain, permissionCodeEquals, permissionCodeIn, permissionCodeNotEquals, permissionCodeSpecified, roleIdEquals, roleIdGreaterThan, roleIdGreaterThanOrEqual, roleIdIn, roleIdLessThan, roleIdLessThanOrEqual, roleIdNotEquals, roleIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (moduleIdEquals !== undefined && moduleIdEquals !== null) {
            queryParameters = queryParameters.set('moduleId.equals', moduleIdEquals);
        }
        if (moduleIdGreaterThan !== undefined && moduleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThan', moduleIdGreaterThan);
        }
        if (moduleIdGreaterThanOrEqual !== undefined && moduleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThanOrEqual', moduleIdGreaterThanOrEqual);
        }
        if (moduleIdIn) {
            moduleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('moduleId.in', element);
            });
        }
        if (moduleIdLessThan !== undefined && moduleIdLessThan !== null) {
            queryParameters = queryParameters.set('moduleId.lessThan', moduleIdLessThan);
        }
        if (moduleIdLessThanOrEqual !== undefined && moduleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.lessThanOrEqual', moduleIdLessThanOrEqual);
        }
        if (moduleIdNotEquals !== undefined && moduleIdNotEquals !== null) {
            queryParameters = queryParameters.set('moduleId.notEquals', moduleIdNotEquals);
        }
        if (moduleIdSpecified !== undefined && moduleIdSpecified !== null) {
            queryParameters = queryParameters.set('moduleId.specified', moduleIdSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (permissionCodeContains !== undefined && permissionCodeContains !== null) {
            queryParameters = queryParameters.set('permissionCode.contains', permissionCodeContains);
        }
        if (permissionCodeDoesNotContain !== undefined && permissionCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('permissionCode.doesNotContain', permissionCodeDoesNotContain);
        }
        if (permissionCodeEquals !== undefined && permissionCodeEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.equals', permissionCodeEquals);
        }
        if (permissionCodeIn) {
            permissionCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('permissionCode.in', element);
            });
        }
        if (permissionCodeNotEquals !== undefined && permissionCodeNotEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.notEquals', permissionCodeNotEquals);
        }
        if (permissionCodeSpecified !== undefined && permissionCodeSpecified !== null) {
            queryParameters = queryParameters.set('permissionCode.specified', permissionCodeSpecified);
        }
        if (roleIdEquals !== undefined && roleIdEquals !== null) {
            queryParameters = queryParameters.set('roleId.equals', roleIdEquals);
        }
        if (roleIdGreaterThan !== undefined && roleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('roleId.greaterThan', roleIdGreaterThan);
        }
        if (roleIdGreaterThanOrEqual !== undefined && roleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.greaterThanOrEqual', roleIdGreaterThanOrEqual);
        }
        if (roleIdIn) {
            roleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleId.in', element);
            });
        }
        if (roleIdLessThan !== undefined && roleIdLessThan !== null) {
            queryParameters = queryParameters.set('roleId.lessThan', roleIdLessThan);
        }
        if (roleIdLessThanOrEqual !== undefined && roleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.lessThanOrEqual', roleIdLessThanOrEqual);
        }
        if (roleIdNotEquals !== undefined && roleIdNotEquals !== null) {
            queryParameters = queryParameters.set('roleId.notEquals', roleIdNotEquals);
        }
        if (roleIdSpecified !== undefined && roleIdSpecified !== null) {
            queryParameters = queryParameters.set('roleId.specified', roleIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/permissions/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PermissionResourceService.prototype.createPermissionUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createPermissionUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/permissions", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PermissionResourceService.prototype.deletePermissionUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deletePermissionUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/permissions/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PermissionResourceService.prototype.getAllPermissionsUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, moduleIdEquals, moduleIdGreaterThan, moduleIdGreaterThanOrEqual, moduleIdIn, moduleIdLessThan, moduleIdLessThanOrEqual, moduleIdNotEquals, moduleIdSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, page, permissionCodeContains, permissionCodeDoesNotContain, permissionCodeEquals, permissionCodeIn, permissionCodeNotEquals, permissionCodeSpecified, roleIdEquals, roleIdGreaterThan, roleIdGreaterThanOrEqual, roleIdIn, roleIdLessThan, roleIdLessThanOrEqual, roleIdNotEquals, roleIdSpecified, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (moduleIdEquals !== undefined && moduleIdEquals !== null) {
            queryParameters = queryParameters.set('moduleId.equals', moduleIdEquals);
        }
        if (moduleIdGreaterThan !== undefined && moduleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThan', moduleIdGreaterThan);
        }
        if (moduleIdGreaterThanOrEqual !== undefined && moduleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.greaterThanOrEqual', moduleIdGreaterThanOrEqual);
        }
        if (moduleIdIn) {
            moduleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('moduleId.in', element);
            });
        }
        if (moduleIdLessThan !== undefined && moduleIdLessThan !== null) {
            queryParameters = queryParameters.set('moduleId.lessThan', moduleIdLessThan);
        }
        if (moduleIdLessThanOrEqual !== undefined && moduleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('moduleId.lessThanOrEqual', moduleIdLessThanOrEqual);
        }
        if (moduleIdNotEquals !== undefined && moduleIdNotEquals !== null) {
            queryParameters = queryParameters.set('moduleId.notEquals', moduleIdNotEquals);
        }
        if (moduleIdSpecified !== undefined && moduleIdSpecified !== null) {
            queryParameters = queryParameters.set('moduleId.specified', moduleIdSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (permissionCodeContains !== undefined && permissionCodeContains !== null) {
            queryParameters = queryParameters.set('permissionCode.contains', permissionCodeContains);
        }
        if (permissionCodeDoesNotContain !== undefined && permissionCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('permissionCode.doesNotContain', permissionCodeDoesNotContain);
        }
        if (permissionCodeEquals !== undefined && permissionCodeEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.equals', permissionCodeEquals);
        }
        if (permissionCodeIn) {
            permissionCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('permissionCode.in', element);
            });
        }
        if (permissionCodeNotEquals !== undefined && permissionCodeNotEquals !== null) {
            queryParameters = queryParameters.set('permissionCode.notEquals', permissionCodeNotEquals);
        }
        if (permissionCodeSpecified !== undefined && permissionCodeSpecified !== null) {
            queryParameters = queryParameters.set('permissionCode.specified', permissionCodeSpecified);
        }
        if (roleIdEquals !== undefined && roleIdEquals !== null) {
            queryParameters = queryParameters.set('roleId.equals', roleIdEquals);
        }
        if (roleIdGreaterThan !== undefined && roleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('roleId.greaterThan', roleIdGreaterThan);
        }
        if (roleIdGreaterThanOrEqual !== undefined && roleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.greaterThanOrEqual', roleIdGreaterThanOrEqual);
        }
        if (roleIdIn) {
            roleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleId.in', element);
            });
        }
        if (roleIdLessThan !== undefined && roleIdLessThan !== null) {
            queryParameters = queryParameters.set('roleId.lessThan', roleIdLessThan);
        }
        if (roleIdLessThanOrEqual !== undefined && roleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('roleId.lessThanOrEqual', roleIdLessThanOrEqual);
        }
        if (roleIdNotEquals !== undefined && roleIdNotEquals !== null) {
            queryParameters = queryParameters.set('roleId.notEquals', roleIdNotEquals);
        }
        if (roleIdSpecified !== undefined && roleIdSpecified !== null) {
            queryParameters = queryParameters.set('roleId.specified', roleIdSpecified);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/permissions", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PermissionResourceService.prototype.getPermissionUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getPermissionUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/permissions/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PermissionResourceService.prototype.updatePermissionUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updatePermissionUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/permissions", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    PermissionResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    PermissionResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], PermissionResourceService);
    return PermissionResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var RoleAssignationResourceService = /** @class */ (function () {
    function RoleAssignationResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    RoleAssignationResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    RoleAssignationResourceService.prototype.countRoleAssignationsUsingGET = function (customRoleIdEquals, customRoleIdGreaterThan, customRoleIdGreaterThanOrEqual, customRoleIdIn, customRoleIdLessThan, customRoleIdLessThanOrEqual, customRoleIdNotEquals, customRoleIdSpecified, groupIdEquals, groupIdGreaterThan, groupIdGreaterThanOrEqual, groupIdIn, groupIdLessThan, groupIdLessThanOrEqual, groupIdNotEquals, groupIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, roleCodeContains, roleCodeDoesNotContain, roleCodeEquals, roleCodeIn, roleCodeNotEquals, roleCodeSpecified, userIdEquals, userIdGreaterThan, userIdGreaterThanOrEqual, userIdIn, userIdLessThan, userIdLessThanOrEqual, userIdNotEquals, userIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (customRoleIdEquals !== undefined && customRoleIdEquals !== null) {
            queryParameters = queryParameters.set('customRoleId.equals', customRoleIdEquals);
        }
        if (customRoleIdGreaterThan !== undefined && customRoleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('customRoleId.greaterThan', customRoleIdGreaterThan);
        }
        if (customRoleIdGreaterThanOrEqual !== undefined && customRoleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('customRoleId.greaterThanOrEqual', customRoleIdGreaterThanOrEqual);
        }
        if (customRoleIdIn) {
            customRoleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('customRoleId.in', element);
            });
        }
        if (customRoleIdLessThan !== undefined && customRoleIdLessThan !== null) {
            queryParameters = queryParameters.set('customRoleId.lessThan', customRoleIdLessThan);
        }
        if (customRoleIdLessThanOrEqual !== undefined && customRoleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('customRoleId.lessThanOrEqual', customRoleIdLessThanOrEqual);
        }
        if (customRoleIdNotEquals !== undefined && customRoleIdNotEquals !== null) {
            queryParameters = queryParameters.set('customRoleId.notEquals', customRoleIdNotEquals);
        }
        if (customRoleIdSpecified !== undefined && customRoleIdSpecified !== null) {
            queryParameters = queryParameters.set('customRoleId.specified', customRoleIdSpecified);
        }
        if (groupIdEquals !== undefined && groupIdEquals !== null) {
            queryParameters = queryParameters.set('groupId.equals', groupIdEquals);
        }
        if (groupIdGreaterThan !== undefined && groupIdGreaterThan !== null) {
            queryParameters = queryParameters.set('groupId.greaterThan', groupIdGreaterThan);
        }
        if (groupIdGreaterThanOrEqual !== undefined && groupIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupId.greaterThanOrEqual', groupIdGreaterThanOrEqual);
        }
        if (groupIdIn) {
            groupIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('groupId.in', element);
            });
        }
        if (groupIdLessThan !== undefined && groupIdLessThan !== null) {
            queryParameters = queryParameters.set('groupId.lessThan', groupIdLessThan);
        }
        if (groupIdLessThanOrEqual !== undefined && groupIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupId.lessThanOrEqual', groupIdLessThanOrEqual);
        }
        if (groupIdNotEquals !== undefined && groupIdNotEquals !== null) {
            queryParameters = queryParameters.set('groupId.notEquals', groupIdNotEquals);
        }
        if (groupIdSpecified !== undefined && groupIdSpecified !== null) {
            queryParameters = queryParameters.set('groupId.specified', groupIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (roleCodeContains !== undefined && roleCodeContains !== null) {
            queryParameters = queryParameters.set('roleCode.contains', roleCodeContains);
        }
        if (roleCodeDoesNotContain !== undefined && roleCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('roleCode.doesNotContain', roleCodeDoesNotContain);
        }
        if (roleCodeEquals !== undefined && roleCodeEquals !== null) {
            queryParameters = queryParameters.set('roleCode.equals', roleCodeEquals);
        }
        if (roleCodeIn) {
            roleCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleCode.in', element);
            });
        }
        if (roleCodeNotEquals !== undefined && roleCodeNotEquals !== null) {
            queryParameters = queryParameters.set('roleCode.notEquals', roleCodeNotEquals);
        }
        if (roleCodeSpecified !== undefined && roleCodeSpecified !== null) {
            queryParameters = queryParameters.set('roleCode.specified', roleCodeSpecified);
        }
        if (userIdEquals !== undefined && userIdEquals !== null) {
            queryParameters = queryParameters.set('userId.equals', userIdEquals);
        }
        if (userIdGreaterThan !== undefined && userIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userId.greaterThan', userIdGreaterThan);
        }
        if (userIdGreaterThanOrEqual !== undefined && userIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userId.greaterThanOrEqual', userIdGreaterThanOrEqual);
        }
        if (userIdIn) {
            userIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userId.in', element);
            });
        }
        if (userIdLessThan !== undefined && userIdLessThan !== null) {
            queryParameters = queryParameters.set('userId.lessThan', userIdLessThan);
        }
        if (userIdLessThanOrEqual !== undefined && userIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userId.lessThanOrEqual', userIdLessThanOrEqual);
        }
        if (userIdNotEquals !== undefined && userIdNotEquals !== null) {
            queryParameters = queryParameters.set('userId.notEquals', userIdNotEquals);
        }
        if (userIdSpecified !== undefined && userIdSpecified !== null) {
            queryParameters = queryParameters.set('userId.specified', userIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/role-assignations/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleAssignationResourceService.prototype.createRoleAssignationUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createRoleAssignationUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/role-assignations", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleAssignationResourceService.prototype.deleteRoleAssignationUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteRoleAssignationUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/role-assignations/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleAssignationResourceService.prototype.getAllRoleAssignationsUsingGET = function (customRoleIdEquals, customRoleIdGreaterThan, customRoleIdGreaterThanOrEqual, customRoleIdIn, customRoleIdLessThan, customRoleIdLessThanOrEqual, customRoleIdNotEquals, customRoleIdSpecified, groupIdEquals, groupIdGreaterThan, groupIdGreaterThanOrEqual, groupIdIn, groupIdLessThan, groupIdLessThanOrEqual, groupIdNotEquals, groupIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, page, roleCodeContains, roleCodeDoesNotContain, roleCodeEquals, roleCodeIn, roleCodeNotEquals, roleCodeSpecified, size, sort, userIdEquals, userIdGreaterThan, userIdGreaterThanOrEqual, userIdIn, userIdLessThan, userIdLessThanOrEqual, userIdNotEquals, userIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (customRoleIdEquals !== undefined && customRoleIdEquals !== null) {
            queryParameters = queryParameters.set('customRoleId.equals', customRoleIdEquals);
        }
        if (customRoleIdGreaterThan !== undefined && customRoleIdGreaterThan !== null) {
            queryParameters = queryParameters.set('customRoleId.greaterThan', customRoleIdGreaterThan);
        }
        if (customRoleIdGreaterThanOrEqual !== undefined && customRoleIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('customRoleId.greaterThanOrEqual', customRoleIdGreaterThanOrEqual);
        }
        if (customRoleIdIn) {
            customRoleIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('customRoleId.in', element);
            });
        }
        if (customRoleIdLessThan !== undefined && customRoleIdLessThan !== null) {
            queryParameters = queryParameters.set('customRoleId.lessThan', customRoleIdLessThan);
        }
        if (customRoleIdLessThanOrEqual !== undefined && customRoleIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('customRoleId.lessThanOrEqual', customRoleIdLessThanOrEqual);
        }
        if (customRoleIdNotEquals !== undefined && customRoleIdNotEquals !== null) {
            queryParameters = queryParameters.set('customRoleId.notEquals', customRoleIdNotEquals);
        }
        if (customRoleIdSpecified !== undefined && customRoleIdSpecified !== null) {
            queryParameters = queryParameters.set('customRoleId.specified', customRoleIdSpecified);
        }
        if (groupIdEquals !== undefined && groupIdEquals !== null) {
            queryParameters = queryParameters.set('groupId.equals', groupIdEquals);
        }
        if (groupIdGreaterThan !== undefined && groupIdGreaterThan !== null) {
            queryParameters = queryParameters.set('groupId.greaterThan', groupIdGreaterThan);
        }
        if (groupIdGreaterThanOrEqual !== undefined && groupIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupId.greaterThanOrEqual', groupIdGreaterThanOrEqual);
        }
        if (groupIdIn) {
            groupIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('groupId.in', element);
            });
        }
        if (groupIdLessThan !== undefined && groupIdLessThan !== null) {
            queryParameters = queryParameters.set('groupId.lessThan', groupIdLessThan);
        }
        if (groupIdLessThanOrEqual !== undefined && groupIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('groupId.lessThanOrEqual', groupIdLessThanOrEqual);
        }
        if (groupIdNotEquals !== undefined && groupIdNotEquals !== null) {
            queryParameters = queryParameters.set('groupId.notEquals', groupIdNotEquals);
        }
        if (groupIdSpecified !== undefined && groupIdSpecified !== null) {
            queryParameters = queryParameters.set('groupId.specified', groupIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (roleCodeContains !== undefined && roleCodeContains !== null) {
            queryParameters = queryParameters.set('roleCode.contains', roleCodeContains);
        }
        if (roleCodeDoesNotContain !== undefined && roleCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('roleCode.doesNotContain', roleCodeDoesNotContain);
        }
        if (roleCodeEquals !== undefined && roleCodeEquals !== null) {
            queryParameters = queryParameters.set('roleCode.equals', roleCodeEquals);
        }
        if (roleCodeIn) {
            roleCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleCode.in', element);
            });
        }
        if (roleCodeNotEquals !== undefined && roleCodeNotEquals !== null) {
            queryParameters = queryParameters.set('roleCode.notEquals', roleCodeNotEquals);
        }
        if (roleCodeSpecified !== undefined && roleCodeSpecified !== null) {
            queryParameters = queryParameters.set('roleCode.specified', roleCodeSpecified);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        if (userIdEquals !== undefined && userIdEquals !== null) {
            queryParameters = queryParameters.set('userId.equals', userIdEquals);
        }
        if (userIdGreaterThan !== undefined && userIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userId.greaterThan', userIdGreaterThan);
        }
        if (userIdGreaterThanOrEqual !== undefined && userIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userId.greaterThanOrEqual', userIdGreaterThanOrEqual);
        }
        if (userIdIn) {
            userIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userId.in', element);
            });
        }
        if (userIdLessThan !== undefined && userIdLessThan !== null) {
            queryParameters = queryParameters.set('userId.lessThan', userIdLessThan);
        }
        if (userIdLessThanOrEqual !== undefined && userIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userId.lessThanOrEqual', userIdLessThanOrEqual);
        }
        if (userIdNotEquals !== undefined && userIdNotEquals !== null) {
            queryParameters = queryParameters.set('userId.notEquals', userIdNotEquals);
        }
        if (userIdSpecified !== undefined && userIdSpecified !== null) {
            queryParameters = queryParameters.set('userId.specified', userIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/role-assignations", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleAssignationResourceService.prototype.getRoleAssignationUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getRoleAssignationUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/role-assignations/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleAssignationResourceService.prototype.updateRoleAssignationUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateRoleAssignationUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/role-assignations", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleAssignationResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    RoleAssignationResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], RoleAssignationResourceService);
    return RoleAssignationResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var RoleResourceService = /** @class */ (function () {
    function RoleResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    RoleResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    RoleResourceService.prototype.countRolesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, permissionIdEquals, permissionIdGreaterThan, permissionIdGreaterThanOrEqual, permissionIdIn, permissionIdLessThan, permissionIdLessThanOrEqual, permissionIdNotEquals, permissionIdSpecified, roleCodeContains, roleCodeDoesNotContain, roleCodeEquals, roleCodeIn, roleCodeNotEquals, roleCodeSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (permissionIdEquals !== undefined && permissionIdEquals !== null) {
            queryParameters = queryParameters.set('permissionId.equals', permissionIdEquals);
        }
        if (permissionIdGreaterThan !== undefined && permissionIdGreaterThan !== null) {
            queryParameters = queryParameters.set('permissionId.greaterThan', permissionIdGreaterThan);
        }
        if (permissionIdGreaterThanOrEqual !== undefined && permissionIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('permissionId.greaterThanOrEqual', permissionIdGreaterThanOrEqual);
        }
        if (permissionIdIn) {
            permissionIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('permissionId.in', element);
            });
        }
        if (permissionIdLessThan !== undefined && permissionIdLessThan !== null) {
            queryParameters = queryParameters.set('permissionId.lessThan', permissionIdLessThan);
        }
        if (permissionIdLessThanOrEqual !== undefined && permissionIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('permissionId.lessThanOrEqual', permissionIdLessThanOrEqual);
        }
        if (permissionIdNotEquals !== undefined && permissionIdNotEquals !== null) {
            queryParameters = queryParameters.set('permissionId.notEquals', permissionIdNotEquals);
        }
        if (permissionIdSpecified !== undefined && permissionIdSpecified !== null) {
            queryParameters = queryParameters.set('permissionId.specified', permissionIdSpecified);
        }
        if (roleCodeContains !== undefined && roleCodeContains !== null) {
            queryParameters = queryParameters.set('roleCode.contains', roleCodeContains);
        }
        if (roleCodeDoesNotContain !== undefined && roleCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('roleCode.doesNotContain', roleCodeDoesNotContain);
        }
        if (roleCodeEquals !== undefined && roleCodeEquals !== null) {
            queryParameters = queryParameters.set('roleCode.equals', roleCodeEquals);
        }
        if (roleCodeIn) {
            roleCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleCode.in', element);
            });
        }
        if (roleCodeNotEquals !== undefined && roleCodeNotEquals !== null) {
            queryParameters = queryParameters.set('roleCode.notEquals', roleCodeNotEquals);
        }
        if (roleCodeSpecified !== undefined && roleCodeSpecified !== null) {
            queryParameters = queryParameters.set('roleCode.specified', roleCodeSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/roles/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleResourceService.prototype.createRoleUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createRoleUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/roles", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleResourceService.prototype.deleteRoleUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteRoleUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/roles/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleResourceService.prototype.getAllRolesUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, page, permissionIdEquals, permissionIdGreaterThan, permissionIdGreaterThanOrEqual, permissionIdIn, permissionIdLessThan, permissionIdLessThanOrEqual, permissionIdNotEquals, permissionIdSpecified, roleCodeContains, roleCodeDoesNotContain, roleCodeEquals, roleCodeIn, roleCodeNotEquals, roleCodeSpecified, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (permissionIdEquals !== undefined && permissionIdEquals !== null) {
            queryParameters = queryParameters.set('permissionId.equals', permissionIdEquals);
        }
        if (permissionIdGreaterThan !== undefined && permissionIdGreaterThan !== null) {
            queryParameters = queryParameters.set('permissionId.greaterThan', permissionIdGreaterThan);
        }
        if (permissionIdGreaterThanOrEqual !== undefined && permissionIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('permissionId.greaterThanOrEqual', permissionIdGreaterThanOrEqual);
        }
        if (permissionIdIn) {
            permissionIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('permissionId.in', element);
            });
        }
        if (permissionIdLessThan !== undefined && permissionIdLessThan !== null) {
            queryParameters = queryParameters.set('permissionId.lessThan', permissionIdLessThan);
        }
        if (permissionIdLessThanOrEqual !== undefined && permissionIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('permissionId.lessThanOrEqual', permissionIdLessThanOrEqual);
        }
        if (permissionIdNotEquals !== undefined && permissionIdNotEquals !== null) {
            queryParameters = queryParameters.set('permissionId.notEquals', permissionIdNotEquals);
        }
        if (permissionIdSpecified !== undefined && permissionIdSpecified !== null) {
            queryParameters = queryParameters.set('permissionId.specified', permissionIdSpecified);
        }
        if (roleCodeContains !== undefined && roleCodeContains !== null) {
            queryParameters = queryParameters.set('roleCode.contains', roleCodeContains);
        }
        if (roleCodeDoesNotContain !== undefined && roleCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('roleCode.doesNotContain', roleCodeDoesNotContain);
        }
        if (roleCodeEquals !== undefined && roleCodeEquals !== null) {
            queryParameters = queryParameters.set('roleCode.equals', roleCodeEquals);
        }
        if (roleCodeIn) {
            roleCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('roleCode.in', element);
            });
        }
        if (roleCodeNotEquals !== undefined && roleCodeNotEquals !== null) {
            queryParameters = queryParameters.set('roleCode.notEquals', roleCodeNotEquals);
        }
        if (roleCodeSpecified !== undefined && roleCodeSpecified !== null) {
            queryParameters = queryParameters.set('roleCode.specified', roleCodeSpecified);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/roles", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleResourceService.prototype.getRoleUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getRoleUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/roles/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleResourceService.prototype.updateRoleUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateRoleUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/roles", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    RoleResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    RoleResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], RoleResourceService);
    return RoleResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var TenantContextResourceService = /** @class */ (function () {
    function TenantContextResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    TenantContextResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    TenantContextResourceService.prototype.countTenantContextsUsingGET = function (contextCodeContains, contextCodeDoesNotContain, contextCodeEquals, contextCodeIn, contextCodeNotEquals, contextCodeSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, logoImageContains, logoImageDoesNotContain, logoImageEquals, logoImageIn, logoImageNotEquals, logoImageSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, nameDatabaseContains, nameDatabaseDoesNotContain, nameDatabaseEquals, nameDatabaseIn, nameDatabaseNotEquals, nameDatabaseSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextCodeContains !== undefined && contextCodeContains !== null) {
            queryParameters = queryParameters.set('contextCode.contains', contextCodeContains);
        }
        if (contextCodeDoesNotContain !== undefined && contextCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('contextCode.doesNotContain', contextCodeDoesNotContain);
        }
        if (contextCodeEquals !== undefined && contextCodeEquals !== null) {
            queryParameters = queryParameters.set('contextCode.equals', contextCodeEquals);
        }
        if (contextCodeIn) {
            contextCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextCode.in', element);
            });
        }
        if (contextCodeNotEquals !== undefined && contextCodeNotEquals !== null) {
            queryParameters = queryParameters.set('contextCode.notEquals', contextCodeNotEquals);
        }
        if (contextCodeSpecified !== undefined && contextCodeSpecified !== null) {
            queryParameters = queryParameters.set('contextCode.specified', contextCodeSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (logoImageContains !== undefined && logoImageContains !== null) {
            queryParameters = queryParameters.set('logoImage.contains', logoImageContains);
        }
        if (logoImageDoesNotContain !== undefined && logoImageDoesNotContain !== null) {
            queryParameters = queryParameters.set('logoImage.doesNotContain', logoImageDoesNotContain);
        }
        if (logoImageEquals !== undefined && logoImageEquals !== null) {
            queryParameters = queryParameters.set('logoImage.equals', logoImageEquals);
        }
        if (logoImageIn) {
            logoImageIn.forEach(function (element) {
                queryParameters = queryParameters.append('logoImage.in', element);
            });
        }
        if (logoImageNotEquals !== undefined && logoImageNotEquals !== null) {
            queryParameters = queryParameters.set('logoImage.notEquals', logoImageNotEquals);
        }
        if (logoImageSpecified !== undefined && logoImageSpecified !== null) {
            queryParameters = queryParameters.set('logoImage.specified', logoImageSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (nameDatabaseContains !== undefined && nameDatabaseContains !== null) {
            queryParameters = queryParameters.set('nameDatabase.contains', nameDatabaseContains);
        }
        if (nameDatabaseDoesNotContain !== undefined && nameDatabaseDoesNotContain !== null) {
            queryParameters = queryParameters.set('nameDatabase.doesNotContain', nameDatabaseDoesNotContain);
        }
        if (nameDatabaseEquals !== undefined && nameDatabaseEquals !== null) {
            queryParameters = queryParameters.set('nameDatabase.equals', nameDatabaseEquals);
        }
        if (nameDatabaseIn) {
            nameDatabaseIn.forEach(function (element) {
                queryParameters = queryParameters.append('nameDatabase.in', element);
            });
        }
        if (nameDatabaseNotEquals !== undefined && nameDatabaseNotEquals !== null) {
            queryParameters = queryParameters.set('nameDatabase.notEquals', nameDatabaseNotEquals);
        }
        if (nameDatabaseSpecified !== undefined && nameDatabaseSpecified !== null) {
            queryParameters = queryParameters.set('nameDatabase.specified', nameDatabaseSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/tenant-contexts/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TenantContextResourceService.prototype.createTenantContextUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createTenantContextUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/tenant-contexts", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TenantContextResourceService.prototype.deleteTenantContextUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteTenantContextUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/tenant-contexts/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TenantContextResourceService.prototype.getAllTenantContextsUsingGET = function (contextCodeContains, contextCodeDoesNotContain, contextCodeEquals, contextCodeIn, contextCodeNotEquals, contextCodeSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, logoImageContains, logoImageDoesNotContain, logoImageEquals, logoImageIn, logoImageNotEquals, logoImageSpecified, nameContains, nameDoesNotContain, nameEquals, nameIn, nameNotEquals, nameSpecified, nameDatabaseContains, nameDatabaseDoesNotContain, nameDatabaseEquals, nameDatabaseIn, nameDatabaseNotEquals, nameDatabaseSpecified, page, size, sort, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextCodeContains !== undefined && contextCodeContains !== null) {
            queryParameters = queryParameters.set('contextCode.contains', contextCodeContains);
        }
        if (contextCodeDoesNotContain !== undefined && contextCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('contextCode.doesNotContain', contextCodeDoesNotContain);
        }
        if (contextCodeEquals !== undefined && contextCodeEquals !== null) {
            queryParameters = queryParameters.set('contextCode.equals', contextCodeEquals);
        }
        if (contextCodeIn) {
            contextCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextCode.in', element);
            });
        }
        if (contextCodeNotEquals !== undefined && contextCodeNotEquals !== null) {
            queryParameters = queryParameters.set('contextCode.notEquals', contextCodeNotEquals);
        }
        if (contextCodeSpecified !== undefined && contextCodeSpecified !== null) {
            queryParameters = queryParameters.set('contextCode.specified', contextCodeSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (logoImageContains !== undefined && logoImageContains !== null) {
            queryParameters = queryParameters.set('logoImage.contains', logoImageContains);
        }
        if (logoImageDoesNotContain !== undefined && logoImageDoesNotContain !== null) {
            queryParameters = queryParameters.set('logoImage.doesNotContain', logoImageDoesNotContain);
        }
        if (logoImageEquals !== undefined && logoImageEquals !== null) {
            queryParameters = queryParameters.set('logoImage.equals', logoImageEquals);
        }
        if (logoImageIn) {
            logoImageIn.forEach(function (element) {
                queryParameters = queryParameters.append('logoImage.in', element);
            });
        }
        if (logoImageNotEquals !== undefined && logoImageNotEquals !== null) {
            queryParameters = queryParameters.set('logoImage.notEquals', logoImageNotEquals);
        }
        if (logoImageSpecified !== undefined && logoImageSpecified !== null) {
            queryParameters = queryParameters.set('logoImage.specified', logoImageSpecified);
        }
        if (nameContains !== undefined && nameContains !== null) {
            queryParameters = queryParameters.set('name.contains', nameContains);
        }
        if (nameDoesNotContain !== undefined && nameDoesNotContain !== null) {
            queryParameters = queryParameters.set('name.doesNotContain', nameDoesNotContain);
        }
        if (nameEquals !== undefined && nameEquals !== null) {
            queryParameters = queryParameters.set('name.equals', nameEquals);
        }
        if (nameIn) {
            nameIn.forEach(function (element) {
                queryParameters = queryParameters.append('name.in', element);
            });
        }
        if (nameNotEquals !== undefined && nameNotEquals !== null) {
            queryParameters = queryParameters.set('name.notEquals', nameNotEquals);
        }
        if (nameSpecified !== undefined && nameSpecified !== null) {
            queryParameters = queryParameters.set('name.specified', nameSpecified);
        }
        if (nameDatabaseContains !== undefined && nameDatabaseContains !== null) {
            queryParameters = queryParameters.set('nameDatabase.contains', nameDatabaseContains);
        }
        if (nameDatabaseDoesNotContain !== undefined && nameDatabaseDoesNotContain !== null) {
            queryParameters = queryParameters.set('nameDatabase.doesNotContain', nameDatabaseDoesNotContain);
        }
        if (nameDatabaseEquals !== undefined && nameDatabaseEquals !== null) {
            queryParameters = queryParameters.set('nameDatabase.equals', nameDatabaseEquals);
        }
        if (nameDatabaseIn) {
            nameDatabaseIn.forEach(function (element) {
                queryParameters = queryParameters.append('nameDatabase.in', element);
            });
        }
        if (nameDatabaseNotEquals !== undefined && nameDatabaseNotEquals !== null) {
            queryParameters = queryParameters.set('nameDatabase.notEquals', nameDatabaseNotEquals);
        }
        if (nameDatabaseSpecified !== undefined && nameDatabaseSpecified !== null) {
            queryParameters = queryParameters.set('nameDatabase.specified', nameDatabaseSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/tenant-contexts", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TenantContextResourceService.prototype.getTenantContextUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getTenantContextUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/tenant-contexts/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TenantContextResourceService.prototype.updateTenantContextUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateTenantContextUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/tenant-contexts", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    TenantContextResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    TenantContextResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], TenantContextResourceService);
    return TenantContextResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var UserPermissionMemoryResourceService = /** @class */ (function () {
    function UserPermissionMemoryResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    UserPermissionMemoryResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    UserPermissionMemoryResourceService.prototype.cleanUserPermission = function (userCode, contextCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling cleanUserPermission.');
        }
        if (contextCode === null || contextCode === undefined) {
            throw new Error('Required parameter contextCode was null or undefined when calling cleanUserPermission.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/ag/api/rest/permission-memory/" + encodeURIComponent(String(userCode)) + "/" + encodeURIComponent(String(contextCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserPermissionMemoryResourceService.prototype.cleanUserPermission1 = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/ag/api/rest/permission-memory", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserPermissionMemoryResourceService.prototype.getUserPermission = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/ag/api/rest/permission-memory", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserPermissionMemoryResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    UserPermissionMemoryResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], UserPermissionMemoryResourceService);
    return UserPermissionMemoryResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var UserResourceService = /** @class */ (function () {
    function UserResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    UserResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    UserResourceService.prototype.countUsersUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, statusEquals, statusIn, statusNotEquals, statusSpecified, typeEquals, typeIn, typeNotEquals, typeSpecified, userCodeContains, userCodeDoesNotContain, userCodeEquals, userCodeIn, userCodeNotEquals, userCodeSpecified, userMemberOfIdEquals, userMemberOfIdGreaterThan, userMemberOfIdGreaterThanOrEqual, userMemberOfIdIn, userMemberOfIdLessThan, userMemberOfIdLessThanOrEqual, userMemberOfIdNotEquals, userMemberOfIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (statusEquals !== undefined && statusEquals !== null) {
            queryParameters = queryParameters.set('status.equals', statusEquals);
        }
        if (statusIn) {
            statusIn.forEach(function (element) {
                queryParameters = queryParameters.append('status.in', element);
            });
        }
        if (statusNotEquals !== undefined && statusNotEquals !== null) {
            queryParameters = queryParameters.set('status.notEquals', statusNotEquals);
        }
        if (statusSpecified !== undefined && statusSpecified !== null) {
            queryParameters = queryParameters.set('status.specified', statusSpecified);
        }
        if (typeEquals !== undefined && typeEquals !== null) {
            queryParameters = queryParameters.set('type.equals', typeEquals);
        }
        if (typeIn) {
            typeIn.forEach(function (element) {
                queryParameters = queryParameters.append('type.in', element);
            });
        }
        if (typeNotEquals !== undefined && typeNotEquals !== null) {
            queryParameters = queryParameters.set('type.notEquals', typeNotEquals);
        }
        if (typeSpecified !== undefined && typeSpecified !== null) {
            queryParameters = queryParameters.set('type.specified', typeSpecified);
        }
        if (userCodeContains !== undefined && userCodeContains !== null) {
            queryParameters = queryParameters.set('userCode.contains', userCodeContains);
        }
        if (userCodeDoesNotContain !== undefined && userCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('userCode.doesNotContain', userCodeDoesNotContain);
        }
        if (userCodeEquals !== undefined && userCodeEquals !== null) {
            queryParameters = queryParameters.set('userCode.equals', userCodeEquals);
        }
        if (userCodeIn) {
            userCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('userCode.in', element);
            });
        }
        if (userCodeNotEquals !== undefined && userCodeNotEquals !== null) {
            queryParameters = queryParameters.set('userCode.notEquals', userCodeNotEquals);
        }
        if (userCodeSpecified !== undefined && userCodeSpecified !== null) {
            queryParameters = queryParameters.set('userCode.specified', userCodeSpecified);
        }
        if (userMemberOfIdEquals !== undefined && userMemberOfIdEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.equals', userMemberOfIdEquals);
        }
        if (userMemberOfIdGreaterThan !== undefined && userMemberOfIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThan', userMemberOfIdGreaterThan);
        }
        if (userMemberOfIdGreaterThanOrEqual !== undefined && userMemberOfIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThanOrEqual', userMemberOfIdGreaterThanOrEqual);
        }
        if (userMemberOfIdIn) {
            userMemberOfIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userMemberOfId.in', element);
            });
        }
        if (userMemberOfIdLessThan !== undefined && userMemberOfIdLessThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThan', userMemberOfIdLessThan);
        }
        if (userMemberOfIdLessThanOrEqual !== undefined && userMemberOfIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThanOrEqual', userMemberOfIdLessThanOrEqual);
        }
        if (userMemberOfIdNotEquals !== undefined && userMemberOfIdNotEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.notEquals', userMemberOfIdNotEquals);
        }
        if (userMemberOfIdSpecified !== undefined && userMemberOfIdSpecified !== null) {
            queryParameters = queryParameters.set('userMemberOfId.specified', userMemberOfIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/rest/users/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.createUserUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createUserUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/api/rest/users", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.deactivateUserUsingDELETE = function (userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling deactivateUserUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/rest/users/" + encodeURIComponent(String(userCode)) + "/deactivate", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.deleteUserUsingDELETE = function (userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling deleteUserUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/api/rest/users/" + encodeURIComponent(String(userCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.getAllUsersUsingGET = function (idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, page, size, sort, statusEquals, statusIn, statusNotEquals, statusSpecified, typeEquals, typeIn, typeNotEquals, typeSpecified, userCodeContains, userCodeDoesNotContain, userCodeEquals, userCodeIn, userCodeNotEquals, userCodeSpecified, userMemberOfIdEquals, userMemberOfIdGreaterThan, userMemberOfIdGreaterThanOrEqual, userMemberOfIdIn, userMemberOfIdLessThan, userMemberOfIdLessThanOrEqual, userMemberOfIdNotEquals, userMemberOfIdSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        if (statusEquals !== undefined && statusEquals !== null) {
            queryParameters = queryParameters.set('status.equals', statusEquals);
        }
        if (statusIn) {
            statusIn.forEach(function (element) {
                queryParameters = queryParameters.append('status.in', element);
            });
        }
        if (statusNotEquals !== undefined && statusNotEquals !== null) {
            queryParameters = queryParameters.set('status.notEquals', statusNotEquals);
        }
        if (statusSpecified !== undefined && statusSpecified !== null) {
            queryParameters = queryParameters.set('status.specified', statusSpecified);
        }
        if (typeEquals !== undefined && typeEquals !== null) {
            queryParameters = queryParameters.set('type.equals', typeEquals);
        }
        if (typeIn) {
            typeIn.forEach(function (element) {
                queryParameters = queryParameters.append('type.in', element);
            });
        }
        if (typeNotEquals !== undefined && typeNotEquals !== null) {
            queryParameters = queryParameters.set('type.notEquals', typeNotEquals);
        }
        if (typeSpecified !== undefined && typeSpecified !== null) {
            queryParameters = queryParameters.set('type.specified', typeSpecified);
        }
        if (userCodeContains !== undefined && userCodeContains !== null) {
            queryParameters = queryParameters.set('userCode.contains', userCodeContains);
        }
        if (userCodeDoesNotContain !== undefined && userCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('userCode.doesNotContain', userCodeDoesNotContain);
        }
        if (userCodeEquals !== undefined && userCodeEquals !== null) {
            queryParameters = queryParameters.set('userCode.equals', userCodeEquals);
        }
        if (userCodeIn) {
            userCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('userCode.in', element);
            });
        }
        if (userCodeNotEquals !== undefined && userCodeNotEquals !== null) {
            queryParameters = queryParameters.set('userCode.notEquals', userCodeNotEquals);
        }
        if (userCodeSpecified !== undefined && userCodeSpecified !== null) {
            queryParameters = queryParameters.set('userCode.specified', userCodeSpecified);
        }
        if (userMemberOfIdEquals !== undefined && userMemberOfIdEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.equals', userMemberOfIdEquals);
        }
        if (userMemberOfIdGreaterThan !== undefined && userMemberOfIdGreaterThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThan', userMemberOfIdGreaterThan);
        }
        if (userMemberOfIdGreaterThanOrEqual !== undefined && userMemberOfIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.greaterThanOrEqual', userMemberOfIdGreaterThanOrEqual);
        }
        if (userMemberOfIdIn) {
            userMemberOfIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('userMemberOfId.in', element);
            });
        }
        if (userMemberOfIdLessThan !== undefined && userMemberOfIdLessThan !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThan', userMemberOfIdLessThan);
        }
        if (userMemberOfIdLessThanOrEqual !== undefined && userMemberOfIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('userMemberOfId.lessThanOrEqual', userMemberOfIdLessThanOrEqual);
        }
        if (userMemberOfIdNotEquals !== undefined && userMemberOfIdNotEquals !== null) {
            queryParameters = queryParameters.set('userMemberOfId.notEquals', userMemberOfIdNotEquals);
        }
        if (userMemberOfIdSpecified !== undefined && userMemberOfIdSpecified !== null) {
            queryParameters = queryParameters.set('userMemberOfId.specified', userMemberOfIdSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/rest/users", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.getUserPermissionUsingGET = function (userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling getUserPermissionUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/rest/users/" + encodeURIComponent(String(userCode)) + "/code-permissions", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.getUserUsingGET = function (userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling getUserUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/rest/users/" + encodeURIComponent(String(userCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.reactivateUserUsingPUT = function (userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling reactivateUserUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('put', this.basePath + "/api/rest/users/" + encodeURIComponent(String(userCode)) + "/reactivate", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.prototype.updateUserUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateUserUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/api/rest/users", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    UserResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], UserResourceService);
    return UserResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var UserToContextResourceService = /** @class */ (function () {
    function UserToContextResourceService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    UserToContextResourceService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    UserToContextResourceService.prototype.countUsersOfContextsUsingGET = function (contextIdEquals, contextIdGreaterThan, contextIdGreaterThanOrEqual, contextIdIn, contextIdLessThan, contextIdLessThanOrEqual, contextIdNotEquals, contextIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, userCodeContains, userCodeDoesNotContain, userCodeEquals, userCodeIn, userCodeNotEquals, userCodeSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextIdEquals !== undefined && contextIdEquals !== null) {
            queryParameters = queryParameters.set('contextId.equals', contextIdEquals);
        }
        if (contextIdGreaterThan !== undefined && contextIdGreaterThan !== null) {
            queryParameters = queryParameters.set('contextId.greaterThan', contextIdGreaterThan);
        }
        if (contextIdGreaterThanOrEqual !== undefined && contextIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.greaterThanOrEqual', contextIdGreaterThanOrEqual);
        }
        if (contextIdIn) {
            contextIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextId.in', element);
            });
        }
        if (contextIdLessThan !== undefined && contextIdLessThan !== null) {
            queryParameters = queryParameters.set('contextId.lessThan', contextIdLessThan);
        }
        if (contextIdLessThanOrEqual !== undefined && contextIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.lessThanOrEqual', contextIdLessThanOrEqual);
        }
        if (contextIdNotEquals !== undefined && contextIdNotEquals !== null) {
            queryParameters = queryParameters.set('contextId.notEquals', contextIdNotEquals);
        }
        if (contextIdSpecified !== undefined && contextIdSpecified !== null) {
            queryParameters = queryParameters.set('contextId.specified', contextIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (userCodeContains !== undefined && userCodeContains !== null) {
            queryParameters = queryParameters.set('userCode.contains', userCodeContains);
        }
        if (userCodeDoesNotContain !== undefined && userCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('userCode.doesNotContain', userCodeDoesNotContain);
        }
        if (userCodeEquals !== undefined && userCodeEquals !== null) {
            queryParameters = queryParameters.set('userCode.equals', userCodeEquals);
        }
        if (userCodeIn) {
            userCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('userCode.in', element);
            });
        }
        if (userCodeNotEquals !== undefined && userCodeNotEquals !== null) {
            queryParameters = queryParameters.set('userCode.notEquals', userCodeNotEquals);
        }
        if (userCodeSpecified !== undefined && userCodeSpecified !== null) {
            queryParameters = queryParameters.set('userCode.specified', userCodeSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/context-users/count", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.prototype.createUserOfContextUsingPOST = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling createUserOfContextUsingPOST.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/context-users", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.prototype.deleteUserOfContextUsingDELETE = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteUserOfContextUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/context-users/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.prototype.getAllUsersOfContextsUsingGET = function (contextIdEquals, contextIdGreaterThan, contextIdGreaterThanOrEqual, contextIdIn, contextIdLessThan, contextIdLessThanOrEqual, contextIdNotEquals, contextIdSpecified, idEquals, idGreaterThan, idGreaterThanOrEqual, idIn, idLessThan, idLessThanOrEqual, idNotEquals, idSpecified, page, size, sort, userCodeContains, userCodeDoesNotContain, userCodeEquals, userCodeIn, userCodeNotEquals, userCodeSpecified, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextIdEquals !== undefined && contextIdEquals !== null) {
            queryParameters = queryParameters.set('contextId.equals', contextIdEquals);
        }
        if (contextIdGreaterThan !== undefined && contextIdGreaterThan !== null) {
            queryParameters = queryParameters.set('contextId.greaterThan', contextIdGreaterThan);
        }
        if (contextIdGreaterThanOrEqual !== undefined && contextIdGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.greaterThanOrEqual', contextIdGreaterThanOrEqual);
        }
        if (contextIdIn) {
            contextIdIn.forEach(function (element) {
                queryParameters = queryParameters.append('contextId.in', element);
            });
        }
        if (contextIdLessThan !== undefined && contextIdLessThan !== null) {
            queryParameters = queryParameters.set('contextId.lessThan', contextIdLessThan);
        }
        if (contextIdLessThanOrEqual !== undefined && contextIdLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('contextId.lessThanOrEqual', contextIdLessThanOrEqual);
        }
        if (contextIdNotEquals !== undefined && contextIdNotEquals !== null) {
            queryParameters = queryParameters.set('contextId.notEquals', contextIdNotEquals);
        }
        if (contextIdSpecified !== undefined && contextIdSpecified !== null) {
            queryParameters = queryParameters.set('contextId.specified', contextIdSpecified);
        }
        if (idEquals !== undefined && idEquals !== null) {
            queryParameters = queryParameters.set('id.equals', idEquals);
        }
        if (idGreaterThan !== undefined && idGreaterThan !== null) {
            queryParameters = queryParameters.set('id.greaterThan', idGreaterThan);
        }
        if (idGreaterThanOrEqual !== undefined && idGreaterThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.greaterThanOrEqual', idGreaterThanOrEqual);
        }
        if (idIn) {
            idIn.forEach(function (element) {
                queryParameters = queryParameters.append('id.in', element);
            });
        }
        if (idLessThan !== undefined && idLessThan !== null) {
            queryParameters = queryParameters.set('id.lessThan', idLessThan);
        }
        if (idLessThanOrEqual !== undefined && idLessThanOrEqual !== null) {
            queryParameters = queryParameters.set('id.lessThanOrEqual', idLessThanOrEqual);
        }
        if (idNotEquals !== undefined && idNotEquals !== null) {
            queryParameters = queryParameters.set('id.notEquals', idNotEquals);
        }
        if (idSpecified !== undefined && idSpecified !== null) {
            queryParameters = queryParameters.set('id.specified', idSpecified);
        }
        if (page !== undefined && page !== null) {
            queryParameters = queryParameters.set('page', page);
        }
        if (size !== undefined && size !== null) {
            queryParameters = queryParameters.set('size', size);
        }
        if (sort) {
            sort.forEach(function (element) {
                queryParameters = queryParameters.append('sort', element);
            });
        }
        if (userCodeContains !== undefined && userCodeContains !== null) {
            queryParameters = queryParameters.set('userCode.contains', userCodeContains);
        }
        if (userCodeDoesNotContain !== undefined && userCodeDoesNotContain !== null) {
            queryParameters = queryParameters.set('userCode.doesNotContain', userCodeDoesNotContain);
        }
        if (userCodeEquals !== undefined && userCodeEquals !== null) {
            queryParameters = queryParameters.set('userCode.equals', userCodeEquals);
        }
        if (userCodeIn) {
            userCodeIn.forEach(function (element) {
                queryParameters = queryParameters.append('userCode.in', element);
            });
        }
        if (userCodeNotEquals !== undefined && userCodeNotEquals !== null) {
            queryParameters = queryParameters.set('userCode.notEquals', userCodeNotEquals);
        }
        if (userCodeSpecified !== undefined && userCodeSpecified !== null) {
            queryParameters = queryParameters.set('userCode.specified', userCodeSpecified);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/context-users", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.prototype.getContextsOfUserByContextUsingGET = function (contextCode, userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (contextCode === null || contextCode === undefined) {
            throw new Error('Required parameter contextCode was null or undefined when calling getContextsOfUserByContextUsingGET.');
        }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling getContextsOfUserByContextUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/api/context-users/" + encodeURIComponent(String(userCode)) + "/context/" + encodeURIComponent(String(contextCode)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.prototype.getUserOfContextUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getUserOfContextUsingGET.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/context-users/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.prototype.updateUserOfContextUsingPUT = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling updateUserOfContextUsingPUT.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('put', this.basePath + "/m8t/api/context-users", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    UserToContextResourceService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    UserToContextResourceService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], UserToContextResourceService);
    return UserToContextResourceService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var VerifyUserPermissionApiControllerService = /** @class */ (function () {
    function VerifyUserPermissionApiControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    VerifyUserPermissionApiControllerService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    VerifyUserPermissionApiControllerService.prototype.verifyUserPermissionPost = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling verifyUserPermissionPost.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/ws/verify-user-permission", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    VerifyUserPermissionApiControllerService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    VerifyUserPermissionApiControllerService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], VerifyUserPermissionApiControllerService);
    return VerifyUserPermissionApiControllerService;
}());

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */ /* tslint:disable:no-unused-variable member-ordering */
var WsUserContextService = /** @class */ (function () {
    function WsUserContextService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://api-gest.eneasys.net';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    WsUserContextService.prototype.canConsumeForm = function (consumes) {
        var e_1, _a;
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    };
    WsUserContextService.prototype.addUserToContext = function (body, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling addUserToContext.');
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.request('post', this.basePath + "/m8t/api/ws/user-context", {
            body: body,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    WsUserContextService.prototype.deleteUserFromContext = function (contextCode, userCode, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (contextCode === null || contextCode === undefined) {
            throw new Error('Required parameter contextCode was null or undefined when calling deleteUserFromContext.');
        }
        if (userCode === null || userCode === undefined) {
            throw new Error('Required parameter userCode was null or undefined when calling deleteUserFromContext.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (contextCode !== undefined && contextCode !== null) {
            queryParameters = queryParameters.set('context-code', contextCode);
        }
        if (userCode !== undefined && userCode !== null) {
            queryParameters = queryParameters.set('user-code', userCode);
        }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('delete', this.basePath + "/m8t/api/ws/user-context", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    WsUserContextService.prototype.getMyContexts = function (observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        var headers = this.defaultHeaders;
        // authentication (ServiceAccount) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // authentication (UserInterface) required
        if (this.configuration.accessToken) {
            var accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        var httpHeaderAccepts = [
            'application/json'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        var consumes = [];
        return this.httpClient.request('get', this.basePath + "/m8t/api/ws/my-contexts", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    WsUserContextService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: String, decorators: [{ type: Optional }, { type: Inject, args: [AIG_PATH,] }] },
        { type: Configuration, decorators: [{ type: Optional }] }
    ]; };
    WsUserContextService = __decorate([
        Injectable(),
        __param(1, Optional()), __param(1, Inject(AIG_PATH)), __param(2, Optional())
    ], WsUserContextService);
    return WsUserContextService;
}());

var APIS = [ApolloDocumentService, ApolloDocumentLineResourceService, ApolloDocumentResourceService, ApplicationModuleResourceService, ContextGroupResourceService, ContextModuleResourceService, ContextUserEopooResourceService, ContextUserResourceService, CustomRolePermissionResourceService, CustomRoleResourceService, EntityReferenceResourceService, EopooApiControllerService, FatturaPaService, PermissionResourceService, RoleAssignationResourceService, RoleResourceService, TenantContextResourceService, UserPermissionMemoryResourceService, UserResourceService, UserToContextResourceService, VerifyUserPermissionApiControllerService, WsUserContextService];

var ContextUserDTO;
(function (ContextUserDTO) {
    ContextUserDTO.StatusEnum = {
        ACTIVE: 'ACTIVE',
        DISABLED: 'DISABLED',
        ACCEPTANCE: 'ACCEPTANCE'
    };
    ContextUserDTO.TypeEnum = {
        PERSON: 'PERSON',
        SERVICE: 'SERVICE'
    };
})(ContextUserDTO || (ContextUserDTO = {}));

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var EopooCreationRequestPerson;
(function (EopooCreationRequestPerson) {
    EopooCreationRequestPerson.SexEnum = {
        MALE: 'MALE',
        FEMALE: 'FEMALE'
    };
})(EopooCreationRequestPerson || (EopooCreationRequestPerson = {}));

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ResponseEopooTypeDTO;
(function (ResponseEopooTypeDTO) {
    ResponseEopooTypeDTO.EopooCategoryEnum = {
        GENERIC: 'GENERIC',
        PERSON: 'PERSON'
    };
})(ResponseEopooTypeDTO || (ResponseEopooTypeDTO = {}));

/**
 * ApiGest API
 * ApiGest API documentation
 *
 * OpenAPI spec version: 1.0.0
 * Contact: info@eneasys.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ResponsePersonDTO;
(function (ResponsePersonDTO) {
    ResponsePersonDTO.SexEnum = {
        MALE: 'MALE',
        FEMALE: 'FEMALE'
    };
})(ResponsePersonDTO || (ResponsePersonDTO = {}));

var UserDTO;
(function (UserDTO) {
    UserDTO.StatusEnum = {
        ACTIVE: 'ACTIVE',
        DISABLED: 'DISABLED',
        ACCEPTANCE: 'ACCEPTANCE'
    };
    UserDTO.TypeEnum = {
        PERSON: 'PERSON',
        SERVICE: 'SERVICE'
    };
})(UserDTO || (UserDTO = {}));

var ApiGestModule = /** @class */ (function () {
    function ApiGestModule(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    ApiGestModule_1 = ApiGestModule;
    ApiGestModule.forRoot = function (configurationFactory) {
        return {
            ngModule: ApiGestModule_1,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    };
    var ApiGestModule_1;
    ApiGestModule.ctorParameters = function () { return [
        { type: ApiGestModule, decorators: [{ type: Optional }, { type: SkipSelf }] },
        { type: HttpClient, decorators: [{ type: Optional }] }
    ]; };
    ApiGestModule = ApiGestModule_1 = __decorate([
        NgModule({
            imports: [],
            declarations: [],
            exports: [],
            providers: [
                ApolloDocumentService,
                ApolloDocumentLineResourceService,
                ApolloDocumentResourceService,
                ApplicationModuleResourceService,
                ContextGroupResourceService,
                ContextModuleResourceService,
                ContextUserEopooResourceService,
                ContextUserResourceService,
                CustomRolePermissionResourceService,
                CustomRoleResourceService,
                EntityReferenceResourceService,
                EopooApiControllerService,
                FatturaPaService,
                PermissionResourceService,
                RoleAssignationResourceService,
                RoleResourceService,
                TenantContextResourceService,
                UserPermissionMemoryResourceService,
                UserResourceService,
                UserToContextResourceService,
                VerifyUserPermissionApiControllerService,
                WsUserContextService
            ]
        }),
        __param(0, Optional()), __param(0, SkipSelf()),
        __param(1, Optional())
    ], ApiGestModule);
    return ApiGestModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { AIG_PATH, APIS, ApiGestModule, ApolloDocumentLineResourceService, ApolloDocumentResourceService, ApolloDocumentService, ApplicationModuleResourceService, COLLECTION_FORMATS, Configuration, ContextGroupResourceService, ContextModuleResourceService, ContextUserDTO, ContextUserEopooResourceService, ContextUserResourceService, CustomRolePermissionResourceService, CustomRoleResourceService, EntityReferenceResourceService, EopooApiControllerService, EopooCreationRequestPerson, FatturaPaService, PermissionResourceService, ResponseEopooTypeDTO, ResponsePersonDTO, RoleAssignationResourceService, RoleResourceService, TenantContextResourceService, UserDTO, UserPermissionMemoryResourceService, UserResourceService, UserToContextResourceService, VerifyUserPermissionApiControllerService, WsUserContextService };
//# sourceMappingURL=api-gest.js.map
